### Data preparation script for the study                                                  ###
### "Nouns slow down speech across structurally and culturally diverse languages"          ###
### by Frank Seifart, Jan Strunk, Swintha Danielsen, Iren Hartmann, Brigitte Pakendorf,    ###
### Søren Wichmann, Alena Witzlack-Makarevich, Nivja H. de Jong, and Balthasar Bickel,     ###
### Proceedings of the National Academy of Sciences 115(22). 5720-5725, 2018.              ###
### doi: 10.1073/pnas.1800708115.                                                          ###

### Note: This script is for reference only and cannot be run on the data distributed      ###                                                                                                                     
### with the paper. The distributed data do not contain the original text files (in        ###                                                                                                                     
### Toolbox format) and also only contain the fields relevant to the studies reported in   ###                                                                                                                     
### the paper. Moreover, the data had to be completely anonymized by renaming text and     ###                                                                                                                     
### recording session IDs, as well as by omitting all actual word forms. We did this in    ###                                                                                                                     
### compliance with ethical and legal rules that protect the personal and private content  ###                                                                                                                     
### of the conversations and narratives in most of the corpora.                            ###                                                                                                                     

### Written by Jan Strunk                                                                  ###


### Data preparation and corpus annotation functions

# The initial data is read into R from Toolbox format (https://software.sil.org/toolbox/) using Taras Zakharko's ToolboxSearch (https://bitbucket.org/tzakharko/toolboxsearch).
# The resulting data frames contain unique IDs for each Toolbox record, each word, and each morpheme (called record.id, word.id, and morpheme.id,
# which were renamed to utterance_id, word_id, and morpheme_id, respectively).

## Deletes punctuation before counting word types
delete.final_punctuation = function (word) {
  return(gsub("[-=,?¿¡.:;\"]$", "", word))
}

## Concatenates information about individual morphemes together to create a variable about the whole word
combine.morphemes.into.words = function(corpus, tiers) {

  # Safety check
  if (is.data.frame(corpus)) {

    corpus.data.frame = corpus
 
  } else {

    corpus.data.frame = as.data.frame(corpus)
  }

  morpheme.ids = corpus.data.frame$morpheme.id
  word.ids = corpus.data.frame$word.id

  result = c()

  if (length(tiers) > 0) {

    # For each tier / column given as argument to the function
    for (tier in tiers) {

      rebuilt.words = c()

      # For every word
      for (word.id in word.ids) {

        rebuilt.word = ""

        # Collect all morphemes of the respective word together and concatenate them
        for (morpheme in as.vector(na.omit(corpus.data.frame[corpus.data.frame$word.id==word.id, tier]))) {

          if (rebuilt.word == "") {

            rebuilt.word = morpheme

          } else {

            rebuilt.word = paste(rebuilt.word, morpheme)
          }
        }

        # Collect all words for the current tier / column
        rebuilt.words = c(rebuilt.words, rebuilt.word)
      }

      # Collect all tiers / columns together
      result = cbind(result, rebuilt.words)
    }
  }

  offset = 1

  # Create new columns named like the input tiers with the additional prefix "whole_word_"
  for (tier in tiers) {

    colnames(result)[offset] = paste("whole_word", tier, sep="_")
    offset = offset + 1
  }

  # Return the result as a data frame
  result = as.data.frame(result,stringsAsFactors=F)
  result = cbind(corpus.data.frame, result)
  return(result)
}


## Count the number of morphemes per word
count.morphemes.perword = function (corpus, morph_tier, compound_marker="-") {
  
  results = c()  

  # For each word in the corpus
  for (word_id in corpus$word_id) {
  
    cur_number_of_morphemes = 0

    # For all morphemes in this word
    for (morpheme in corpus[corpus$word_id==word_id, morph_tier]) {
    
      if (!is.na(morpheme)) {

	  # If this morpheme is not the compound marker, count it
        if (morpheme != compound_marker) {
        
          cur_number_of_morphemes = cur_number_of_morphemes + 1
        }
      }
    }

    # Collect the results for all words
    results = c(results, cur_number_of_morphemes)
  }

  return(results)
}


## Determine a word's position within the utterance (annotation unit)
## (Optionally ignore filled pauses and/or false starts (as annotated on the disfluency tier) in the count)
position.within.annotation.unit = function (corpus, ignore_filled_pauses=FALSE, ignore_false_starts=FALSE) {
  
  positions = corpus$morpheme_id
  
  # For each utterance (annotation unit / record)
  for (utterance_id in unique(corpus$utterance_id)) {
  
    position = 0

    # For each word in that utterance
    for (word_id in unique(na.omit(corpus$word_id[corpus$utterance_id==utterance_id]))) {

      fldps = FALSE

      # Is this word a filled pause (such as "uhm")
      if (unique(na.omit(corpus$disfluency[corpus$word_id==word_id])) %in% c("fldps","fldps_new")) {

        # Should we ignore filled pauses? If not, increase word position
        if (ignore_filled_pauses==FALSE) {
        
          position = position + 1
          
        } else {
        
          fldps = TRUE

        }
      
      } else {

	  # Is this word a false start?
        if (unique(na.omit(corpus$disfluency[corpus$word_id==word_id])) %in% c("flst","flst_new")) {
      
	    # Should we ignore false starts? If not, increase word position
          if (ignore_false_starts==FALSE) {
        
            position = position + 1
            
          } else {
        
            disfluency = TRUE

          }
        
        # Increase word position for all ordinary words
        } else {

          position = position + 1
        }
      }

      # If the current word is a filled pause or false start that is to be ignored,
      # set its position value to NA
      if (fldps == TRUE) {
      
        positions[corpus$utterance_id==utterance_id & corpus$word_id == word_id] = NA
      
      # Otherwise set the current word's position to the current position in the utterance
      } else {
      
        positions[corpus$utterance_id==utterance_id & corpus$word_id == word_id] = position
        
      }
    }
  }
  
  return(positions)
}


## Determine a word's relative position within the utterance (annotation unit) (values ranging from 0 to 1)
## (Optionally ignore filled pauses and/or false starts (as annotated on the disfluency tier) in the count)
position.within.annotation.unit.percentage = function (corpus, ignore_filled_pauses=FALSE, ignore_false_starts=FALSE) {
  
  positions = corpus$morpheme_id
  
  # For each utterance (annotation unit / record)
  for (utterance_id in unique(corpus$utterance_id)) {

    position = 0
    max_position = 0

    # For each word in that utterance
    for (word_id in unique(na.omit(corpus$word_id[corpus$utterance_id==utterance_id]))) {

      fldps = FALSE

      # Is this word a filled pause (such as "uhm")
      if (unique(na.omit(corpus$disfluency[corpus$word_id==word_id])) %in% c("fldps","fldps_new")) {
      
        # Should we ignore filled pauses? If not, increase word position
        if (ignore_filled_pauses==FALSE) {
        
          position = position + 1
          
        } else {
        
          fldps = TRUE
        
        }
      
      } else {
      
	  # Is this word a false start?
        if (unique(na.omit(corpus$disfluency[corpus$word_id==word_id])) %in% c("flst","flst_new")) {
      
	    # Should we ignore false starts? If not, increase word position
          if (ignore_false_starts==FALSE) {
        
            position = position + 1
            
          } else {
        
            fldps = TRUE
        
          }
        
        # Increase word position for all ordinary words
        } else {

          position = position + 1
        }
      }
      
      # If the current word is a filled pause or false start that is to be ignored,
      # set its position value to NA
      if (fldps == TRUE) {
      
        positions[corpus$utterance_id==utterance_id & corpus$word_id == word_id] = NA
        
      # Otherwise set the current word's position to the current position in the utterance
      # And remember the maximal position number
      } else {
      
        positions[corpus$utterance_id==utterance_id & corpus$word_id == word_id] = position
        max_position = position
      }
    }
    
    # For each word in the current utterance
    for (word_id in unique(na.omit(corpus$word_id[corpus$utterance_id==utterance_id]))) {
    
      # If its position value is NA, keep it as NA
      if (is.na(unique(positions[corpus$utterance_id==utterance_id & corpus$word_id == word_id]))) {
      
        positions[corpus$utterance_id==utterance_id & corpus$word_id == word_id] = NA
        
      } else {
      
	 # Otherwise recalculate its position as a relative position (with values ranging from 0 to 1) as (word position - 1) / (number of words in utterance - 1)
        positions[corpus$utterance_id==utterance_id & corpus$word_id == word_id] = (unique(na.omit(positions[corpus$utterance_id==utterance_id & corpus$word_id == word_id])) - 1) / (max_position - 1)
        
        # If there is only one word in an utterance, set its position value arbitrarily to 1 (end of utterance) instead of 0 (start of utterance)
        if (max_position == 1) {
        
          positions[corpus$utterance_id==utterance_id & corpus$word_id == word_id] = 1
        }
      }
    }
  }
  
  return(positions)
}


## Calculate the length of an utterance (annotation unit) in words (optionally ignoring filled pauses and/or false starts)
length.of.annotation.units.in.words = function (corpus, ignore_filled_pauses=FALSE, ignore_false_starts=FALSE) {

  lengths = corpus$morpheme_id
  
  # For each utterance (annotation unit / record) in the corpus
  for (utterance_id in unique(corpus$utterance_id)) {

    # Determine the number of unique word IDs in that utterance
    length = length(unique(na.omit(corpus$word_id[corpus$utterance_id==utterance_id])))

    # Subtract the number of words that are filled pauses (according to the disfluency tier) if they are to be ignored
    if (ignore_filled_pauses==T) {
    
      length = length - length(unique(na.omit(corpus$word_id[corpus$utterance_id==utterance_id & corpus$disfluency %in% c("fldps","fldps_new")])))
    }

    # Subtract the number of words that are false starts (according to the disfluency tier) if they are to be ignored
    if (ignore_false_starts==T) {
    
      length = length - length(unique(na.omit(corpus$word_id[corpus$utterance_id==utterance_id & corpus$disfluency %in% c("flst","flst_new")])))
    }

    lengths[corpus$utterance_id == utterance_id] = length
  }
  
  return(lengths)
}


## Normalize the UTF-8 representation of Bora for the purpose of determining word length
normalize_bora = function(words) {

   result = c()
   
   # For each word, replace ɨ or Ɨ with a combing accute accent with Unicode characters already containing the diacritic
   for (cur_word in words) {
   
     cur_word = gsub("\U0268\U0301", "\U0268", cur_word)
     cur_word = gsub("\U0197\U0301", "\U0197", cur_word)
   
     result = c(result, cur_word)
   }
   
   return(result)
}


## Normalize the UTF-8 representation of Chintang for the purpose of determining word length
normalize_chintang = function(words) {

   result = c()
   
   # For each word, replace a vowel combined with a diacritic tilde with Unicode characters already containing the diacritic tilde
   for (cur_word in words) {
   
     cur_word = gsub("a\U0303", "\U00E3", cur_word)
     cur_word = gsub("e\U0303", "\U1EBD", cur_word)
     cur_word = gsub("i\U0303", "\U0129", cur_word)
     cur_word = gsub("o\U0303", "\U00F5", cur_word)
     cur_word = gsub("u\U0303", "\U0169", cur_word)
     cur_word = gsub("A\U0303", "\U00C3", cur_word)
     cur_word = gsub("E\U0303", "\U1EBC", cur_word)
     cur_word = gsub("I\U0303", "\U0128", cur_word)
     cur_word = gsub("O\U0303", "\U00D5", cur_word)
     cur_word = gsub("U\U0303", "\U0168", cur_word)
     
     result = c(result, cur_word)
   }
   
   return(result)
}


## Normalize the UTF-8 representation of Hoocąk for the purpose of determining word length
normalize_hoocak = function(words) {

   result = c()
   
   # For each word, replace a character combined with a diacritic ogonek or caron with Unicode characters already containing the respective diacritic
   for (cur_word in words) {
   
     cur_word = gsub("a\U0328", "\U0105", cur_word)
     cur_word = gsub("e\U0328", "\U0119", cur_word)
     cur_word = gsub("i\U0328", "\U012F", cur_word)
     cur_word = gsub("o\U0328", "\U01EB", cur_word)
     cur_word = gsub("u\U0328", "\U0173", cur_word)
     cur_word = gsub("A\U0328", "\U0104", cur_word)
     cur_word = gsub("E\U0328", "\U0118", cur_word)
     cur_word = gsub("I\U0328", "\U012E", cur_word)
     cur_word = gsub("O\U0328", "\U01EA", cur_word)
     cur_word = gsub("U\U0328", "\U0172", cur_word)
     cur_word = gsub("g\U030C", "\U01E7", cur_word)
     cur_word = gsub("s\U030C", "\U0161", cur_word)
     cur_word = gsub("z\U030C", "\U017E", cur_word)
     cur_word = gsub("G\U030C", "\U01E6", cur_word)
     cur_word = gsub("S\U030C", "\U0160", cur_word)
     cur_word = gsub("Z\U030C", "\U017D", cur_word)
        
     result = c(result, cur_word)
   }
   
   return(result)
}


## Normalize the orthography of Nǁng words for the purpose of determining word length
normalize_nuu = function(words) {

   result = c()

   # Delete square brackets marking unclear / unintelligible words
   for (cur_word in words) {
   
     cur_word = gsub("[", "", cur_word, fixed=T)
     cur_word = gsub("]", "", cur_word, fixed=T)
   
     result = c(result, cur_word)
   }
   
   return(result)
}


## List of punctuation characters to ignore in determining word lengths
ignore_chars="[])-=,?!¿¡.:;\"\'([]"


## Determine the length of the orthographic form of a word in characters (not bytes)
count.characterlength.perword = function (corpus, text_tier, word_tier="word_id", ignore_chars="[])=,?!¿¡.*:;\"\'([-]", type="chars", normalize=FALSE) {
  
  length_results = c()

  # For each word's orthographic form
  for (cur_word in corpus[,text_tier]) {

    # Set word length to 0 for empty words (NA)
    if (is.na(cur_word)) {
      
      length_results = c(length_results, as.integer(0))
    
    } else {

      # Optionally apply a normalization function prior to counting characters (see function definitions starting with normalize_*)
      if (is.function(normalize)) {
        cur_word = normalize(cur_word)
      }

      # Delete punctuation characters prior to counting characters
      cur_word = gsub(ignore_chars, "", cur_word)
      
      # Determine the number of characters in the current word's orthographic form
      cur_word_length = nchar(cur_word, type=type)      
      length_results = c(length_results, as.integer(cur_word_length))
    }
  }

  return(length_results)
}


## Determine the length of a text (recording session) in words
length.of.sessions.in.words = function (corpus) {

  lengths = corpus$morpheme_id

  # For each unique session / text in the corpus
  for (text in unique(corpus$text)) {
  
    # Determine the number of unique word IDs
    length = length(unique(na.omit(corpus$word_id[corpus$text])))
    
    lengths[corpus$text == text] = length
  }
  
  return(lengths)
}


## Calculate the extent of code switching in an utterance (by counting the percentage of nonnative words)
calculate.code.switching.per.annotation.unit = function (corpus, language_tier, language_code) {

  code_switchings = corpus$morpheme_id
  
  # For each utterance (annotation unit) in the corpus
  for (utterance_id in unique(corpus$utterance_id)) {
  
    # Calculate the extent of code switching as the portion of nonnative words in the utterance
    code_switching = length(corpus$morpheme_id[(corpus[,language_tier] %in% language_code & corpus$utterance_id == utterance_id)]) / length(corpus$morpheme_id[corpus$utterance_id == utterance_id])

    code_switchings[corpus$utterance_id == utterance_id] = code_switching
  }

  return(code_switchings)
}


## Count the number of false starts in a pre-word context window (of target length window_length)
false.starts.per.preword.window = function (corpus, window_length) {

  false_starts = corpus$word_id
  false_starts = 0

  # For each utterance (annotation unit) in the corpus
  for (utterance_id in unique(na.omit(corpus$utterance_id))) {

    # If there is no information about word times in the current utterance, record the number of false starts as NA
    if (all(is.na(corpus$word_start_time[corpus$utterance_id==utterance_id]))) {
      
      false_starts[corpus$utterance_id==utterance_id] = NA

    } else {

      # Determine the start time of the first word in the current utterance
      cur_record_start = min(na.omit(corpus$word_start_time[corpus$utterance_id==utterance_id]))

      # For each word in the current utterance
      for (word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
      
        # If it is the first word, there is no valid utterance-internal pre-word context window for this word
        if (word_id == min(na.omit(corpus$word_id[corpus$utterance_id == utterance_id]))) {
        
          false_starts[corpus$word_id == word_id] = NA
          
        } else {

          seen_false_start = 0

          # If the current word does not have a start time, record the number of false starts in its pre-word context window as NA
          if (length(unique(na.omit(corpus$word_start_time[corpus$word_id == word_id]))) == 0) {
          
            false_starts[corpus$word_id == word_id] = NA

          } else {
            
            # Determine the current word's start time
            cur_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==word_id]))
          
            # Calculate the current pre-word context window's start time using the parameter window_length
            cur_prewindow_start = cur_word_start - window_length

            # If the current pre-word window's start time would extent to before the start of the utterance,
            # set it to the start of the utterance (shorting the pre-word context window)
            if (cur_prewindow_start < cur_record_start) {
            
              cur_prewindow_start = cur_record_start
            
            }
            
            # For each other word in the utterance
            for (other_word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
              
              # Determine its word start and end times
              other_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==other_word_id]))
              other_word_end = unique(na.omit(corpus$word_end_time[corpus$word_id==other_word_id]))

              # If there are valid start and end times for the current word
              if ((length(other_word_start) > 0) && (length(other_word_end) > 0)) {
               
               # Calculate its midpoint
               other_word_middle = other_word_start + ((other_word_end - other_word_start) / 2 )

               # If the other word's midpoint lies within the current pre-word context window
               if ((other_word_middle >= cur_prewindow_start) && (other_word_middle <= cur_word_start)) {
                 
                 # Count it as a false start, if it is annotated as "flst" or "flst_new" on the flds tier
                 if (unique(na.omit(corpus$disfluency[corpus$word_id==other_word_id])) %in% c("flst","flst_new")) {
                   
                   seen_false_start = seen_false_start + 1
                 }
               }
              }
            }
            
            false_starts[corpus$word_id == word_id] = seen_false_start
          }
        }
      }      
    }
  }
  
  return(false_starts)
}


## Count the number of filled pauses (such as "uhm") in a pre-word context window (of target length window_length)
filled.pauses.per.preword.window = function (corpus, window_length) {

  filled_pauses = corpus$word_id
  filled_pauses = 0
  
  # For each utterance (annotation unit) in the corpus
  for (utterance_id in unique(na.omit(corpus$utterance_id))) {
  
    # If there is no information about word times in the current record, record the number of filled pauses as NA
    if (all(is.na(corpus$word_start_time[corpus$utterance_id==utterance_id]))) {
      
      filled_pauses[corpus$utterance_id==utterance_id] = NA

    } else {

      # Determine the start time of the first word in the current utterance
      cur_record_start = min(na.omit(corpus$word_start_time[corpus$utterance_id==utterance_id]))
      
      # For each word in the current utterance
      for (word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
      
        # If it is the first word, there is no valid utterance-internal pre-word context window for this word
        if (word_id == min(na.omit(corpus$word_id[corpus$utterance_id == utterance_id]))) {
        
          filled_pauses[corpus$word_id == word_id] = NA
          
        } else {

          seen_filled_pause = 0

          # If the current word does not have a start time, record the number of filled pauses in its pre-word context window as NA
          if (length(unique(na.omit(corpus$word_start_time[corpus$word_id == word_id]))) == 0) {
          
            filled_pauses[corpus$word_id == word_id] = NA

          } else {
                    
            # Determine the current word's start time
            cur_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==word_id]))
          
            # Calculate the current pre-word context window's start time using the parameter window_length
            cur_prewindow_start = cur_word_start - window_length

            # If the current pre-word window's start time would extent to before the start of the utterance,
            # set it to the start of the utterance (shorting the pre-word context window)
            if (cur_prewindow_start < cur_record_start) {
            
              cur_prewindow_start = cur_record_start
            }
              
            # For each other word in the utterance
            for (other_word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
              
              # Determine its word start and end times
              other_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==other_word_id]))
              other_word_end = unique(na.omit(corpus$word_end_time[corpus$word_id==other_word_id]))
                
              # If there are valid start and end times for the current word
              if ((length(other_word_start) > 0) && (length(other_word_end) > 0)) {
                
               # Calculate its midpoint
               other_word_middle = other_word_start + ((other_word_end - other_word_start) / 2 )
                 
               # If the other word's midpoint lies within the current pre-word context window
               if ((other_word_middle >= cur_prewindow_start) && (other_word_middle <= cur_word_start)) {
                 
                 # Count it as a filled pause, if it is annotated as "fldps" or "fldps_new" on the disfluency tier
                 if (unique(na.omit(corpus$disfluency[corpus$word_id==other_word_id])) %in% c("fldps","fldps_new")) {
                   
                   seen_filled_pause = seen_filled_pause + 1
                 }
               }
              }
            }
            
            filled_pauses[corpus$word_id == word_id] = seen_filled_pause
          }
        }
      }      
    }
  }
  
  return(filled_pauses)
}


## Determine the length of pre-word context windows in words (optionally ignoring filled pauses (such as "uhm") and/or false starts)
length.of.preword.window.in.words = function (corpus, window_length, ignore_filled_pauses=FALSE, ignore_false_starts=FALSE) {

  lengths = corpus$word_id
  lengths = NA
  
  # For each utterance (annotation unit) in the corpus
  for (utterance_id in unique(na.omit(corpus$utterance_id))) {
  
    # If there is no information about word times in the current utterance, record the number of words as NA
    if (all(is.na(corpus$word_start_time[corpus$utterance_id==utterance_id]))) {
      
      lengths[corpus$utterance_id==utterance_id] = NA

    } else {

      # Determine the start time of the first word in the current utterance
      cur_record_start = min(na.omit(corpus$word_start_time[corpus$utterance_id==utterance_id]))
      
      # For each word in the current utterance
      for (word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
      
        # If it is the first word, there is no valid utterance-internal pre-word context window for this word
        if (word_id == min(na.omit(corpus$word_id[corpus$utterance_id == utterance_id]))) {
        
          lengths[corpus$word_id == word_id] = NA
          
        } else {

          # If the current word does not have a start time, record the number of words in its pre-word context window as NA
          if (length(unique(na.omit(corpus$word_start_time[corpus$word_id == word_id]))) == 0) {
          
            lengths[corpus$word_id == word_id] = NA

          } else {
                    
            # Determine the current word's start time
            cur_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==word_id]))
          
            # Calculate the current pre-word context window's start time using the parameter window_length
            cur_prewindow_start = cur_word_start - window_length

            # If the current pre-word window's start time would extent to before the start of the utterance,
            # set it to the start of the utterance (shorting the pre-word context window)
            if (cur_prewindow_start < cur_record_start) {
            
              cur_prewindow_start = cur_record_start            
            }

            # Vector to collect the IDs of relevant words
            cur_relevant_word_ids = c()
              
            # For each other word in the utterance
            for (other_word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
              
              # Determine its word start and end times
              other_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==other_word_id]))
              other_word_end = unique(na.omit(corpus$word_end_time[corpus$word_id==other_word_id]))
                
              # If there are valid start and end times for the current word
              if ((length(other_word_start) > 0) && (length(other_word_end) > 0)) {
                
                # Calculate its midpoint
                other_word_middle = other_word_start + ((other_word_end - other_word_start) / 2 )
                 
                # If the other word's midpoint lies within the current pre-word context window
                if ((other_word_middle >= cur_prewindow_start) && (other_word_middle <= cur_word_start)) {
                  
                  # Optionally ignore filled pauses (such as "uhm") and/or false starts according to the parameter settings
                  if ((!((unique(na.omit(corpus$disfluency[corpus$word_id==other_word_id])) %in% c("fldps","fldps_new")) && (ignore_filled_pauses==TRUE))) && (!((unique(na.omit(corpus$disfluency[corpus$word_id==other_word_id])) %in% c("flst","flst_new")) && (ignore_false_starts==TRUE)))) {
                 
                    # Remember the words falling inside the current word's pre-word context window
                    cur_relevant_word_ids = c(cur_relevant_word_ids, other_word_id)
                  }                 
                }
              }
            }
            
            # Count the number of words falling within the current word's pre-word context window
            word_length = length(unique(na.omit(corpus$word_id[corpus$word_id %in% cur_relevant_word_ids])))
            lengths[corpus$word_id == word_id] = word_length
          }
        }
      }      
    }
  }
  
  return(lengths)
}


## Determine the length of pre-word context windows in orthographic characters (optionally ignoring filled pauses (such as "uhm") and/or false starts)
length.of.preword.window.in.characters = function (corpus, window_length, ignore_filled_pauses=FALSE, ignore_false_starts=FALSE) {

  lengths = corpus$word_id
  lengths = NA
  
  # For each utterance (annotation unit) in the corpus
  for (utterance_id in unique(na.omit(corpus$utterance_id))) {
  
    # If there is no information about word times in the current utterance, record the number of orthographic characters as NA
    if (all(is.na(corpus$word_start_time[corpus$utterance_id==utterance_id]))) {
      
      lengths[corpus$utterance_id==utterance_id] = NA

    } else {
    
      # Determine the start time of the first word in the current utterance
      cur_record_start = min(na.omit(corpus$word_start_time[corpus$utterance_id==utterance_id]))
      
      # For each word in the current utterance
      for (word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
      
        # If it is the first word, there is no valid utterance-internal pre-word context window for this word
        if (word_id == min(na.omit(corpus$word_id[corpus$utterance_id == utterance_id]))) {
        
          lengths[corpus$word_id == word_id] = NA
          
        } else {

          # If the current word does not have a start time, record the number of morphemes in its pre-word context window as NA
          if (length(unique(na.omit(corpus$word_start_time[corpus$word_id == word_id]))) == 0) {
          
            lengths[corpus$word_id == word_id] = NA

          } else {
          
            # Determine the current word's start time
            cur_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==word_id]))
          
            # Calculate the current pre-word context window's start time using the parameter window_length
            cur_prewindow_start = cur_word_start - window_length

            # If the current pre-word window's start time would extent to before the start of the utterance,
            # set it to the start of the utterance (shorting the pre-word context window)
            if (cur_prewindow_start < cur_record_start) {
            
              cur_prewindow_start = cur_record_start            
            }
            
            # Vector to collect the IDs of relevant words
            cur_relevant_word_ids = c()
              
            # For each other word in the utterance
            for (other_word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
              
              # Determine its word start and end times
              other_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==other_word_id]))
              other_word_end = unique(na.omit(corpus$word_end_time[corpus$word_id==other_word_id]))
                
              # If there are valid start and end times for the current word
              if ((length(other_word_start) > 0) && (length(other_word_end) > 0)) {
                
                # Calculate its midpoint
                other_word_middle = other_word_start + ((other_word_end - other_word_start) / 2 )
                 
                # If the other word's midpoint lies within the current pre-word context window
                if ((other_word_middle >= cur_prewindow_start) && (other_word_middle <= cur_word_start)) {

                  # Optionally ignore filled pauses (such as "uhm") and/or false starts according to the parameter settings
                  if ((!((unique(na.omit(corpus$disfluency[corpus$word_id==other_word_id])) %in% c("fldps","fldps_new")) && (ignore_filled_pauses==TRUE))) && (!((unique(na.omit(corpus$disfluency[corpus$word_id==other_word_id])) %in% c("flst","flst_new")) && (ignore_false_starts==TRUE)))) {

                    # Remember the words falling inside the current word's pre-word context window
                    cur_relevant_word_ids = c(cur_relevant_word_ids, other_word_id)
                  }
                }
              }
            }

            # Sum the number of orthographic characters of all words in the current word's pre-word context window
            char_length = 0            
            for (other_word in cur_relevant_word_ids) {
              
              char_length = char_length + unique(na.omit(corpus$word_length_characters[corpus$word_id==other_word]))
            }

            lengths[corpus$word_id == word_id] = char_length
          }
        }
      }      
    }
  }
  
  return(lengths)
}


## Determine the duration of pre-word context windows in seconds (optionally ignoring filled pauses (such as "uhm") and/or false starts)
length.of.preword.window.in.seconds = function (corpus, window_length, ignore_filled_pauses=FALSE, ignore_false_starts=FALSE) {

  lengths = corpus$word_id
  lengths = NA
  
  # For each utterance (annotation unit) in the corpus
  for (utterance_id in unique(na.omit(corpus$utterance_id))) {
  
    # If there is no information about word times in the current utterance, record the duration as NA
    if (all(is.na(corpus$word_start_time[corpus$utterance_id==utterance_id]))) {
      
      lengths[corpus$utterance_id==utterance_id] = NA

    } else {
    
      # Determine the start time of the first word in the current utterance
      cur_record_start = min(na.omit(corpus$word_start_time[corpus$utterance_id==utterance_id]))
      
      # For each word in the current utterance
      for (word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
      
        # If it is the first word, there is no valid utterance-internal pre-word context window for this word
        if (word_id == min(na.omit(corpus$word_id[corpus$utterance_id == utterance_id]))) {
        
          lengths[corpus$word_id == word_id] = NA
          
        } else {

          # If the current word does not have a start time, record the number of morphemes in its pre-word context window as NA
          if (length(unique(na.omit(corpus$word_start_time[corpus$word_id == word_id]))) == 0) {
          
            lengths[corpus$word_id == word_id] = NA

          } else {
          
            # Determine the current word's start time
            cur_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==word_id]))
          
            # Calculate the current pre-word context window's start time using the parameter window_length
            cur_prewindow_start = cur_word_start - window_length

            # If the current pre-word window's start time would extent to before the start of the utterance,
            # set it to the start of the utterance (shorting the pre-word context window)
            if (cur_prewindow_start < cur_record_start) {
            
              cur_prewindow_start = cur_record_start
            }

            # Vectors to collect the IDs of relevant words and words to be ignored
            cur_relevant_word_ids = c()
            cur_irrelevant_word_ids = c()
              
            # For each other word in the utterance
            for (other_word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
              
              # Determine its word start and end times
              other_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==other_word_id]))
              other_word_end = unique(na.omit(corpus$word_end_time[corpus$word_id==other_word_id]))
                
              # If there are valid start and end times for the current word
              if ((length(other_word_start) > 0) && (length(other_word_end) > 0)) {
                
                # Calculate its midpoint
                other_word_middle = other_word_start + ((other_word_end - other_word_start) / 2 )
                 
                # If the other word's midpoint lies within the current pre-word context window
                if ((other_word_middle >= cur_prewindow_start) && (other_word_middle <= cur_word_start)) {

                  # Optionally ignore filled pauses (such as "uhm") and/or false starts according to the parameter settings
                  if ((!((unique(na.omit(corpus$disfluency[corpus$word_id==other_word_id])) %in% c("fldps","fldps_new")) && (ignore_filled_pauses==TRUE))) && (!((unique(na.omit(corpus$disfluency[corpus$word_id==other_word_id])) %in% c("flst","flst_new")) && (ignore_false_starts==TRUE)))) {

                    # Remember the words falling inside the current word's pre-word context window
                    cur_relevant_word_ids = c(cur_relevant_word_ids, other_word_id)
                  }

                } else {

                  # Remember words whose midpoint falls outside the current word's pre-word context window,
                  # but whose end point false inside the current word's pre-word window
                  if ((other_word_start < cur_prewindow_start) && (other_word_end > cur_prewindow_start)) {

                    cur_irrelevant_word_ids = c(cur_irrelevant_word_ids, other_word_id)
                  }
                }
              }
            }

            # If there are no words inside the current word's pre-word context window
            if (length(cur_relevant_word_ids) == 0) {
            
              # If there are no words partly inside the current word's pre-word context window
              if (length(cur_irrelevant_word_ids) == 0) {
            
                # The start time of the pre-word window is the actual target length before the current word's start time
                first_word_start = cur_prewindow_start
              
              # If there are words partly but not properly inside the current word's pre-word context window
              } else {
              
                # Determine the end time of the last word partly inside the current word's pre-word context window
                last_word_end = max(na.omit(corpus$word_end_time[corpus$word_id %in% cur_irrelevant_word_ids]))

                # Safety check
                if (last_word_end >= cur_prewindow_start) {
                
                  # Set the start time of the pre-word context window to the end time of the last word not properly included
                  # in this pre-word context window (shortening the pre-word context window)
                  first_word_start = last_word_end

                } else {
                    
                  print("Something's wrong with prewindow, utterance_id:")
                  print(utterance_id)
                  print("Word id:")
                  print(word_id)
                }
              }
            
            # If there are words inside the current word's pre-word context window
            } else {
            
              # Determine the start time of the first word inside the current word's pre-word context window
              first_word_start = min(na.omit(corpus$word_start_time[corpus$word_id %in% cur_relevant_word_ids]))

              # If the target pre-word window length is before the start of the first word included in the pre-word context window
              if (cur_prewindow_start < first_word_start) {
                              
                # And there are no words partly but not properly included in the pre-word context window
                if (length(cur_irrelevant_word_ids) == 0) {
              
                  # Use the actual target pre-word window length as the start of the pre-word window
                  first_word_start = cur_prewindow_start
                
                # If there are words only partly but not properly included in the pre-word context window
                } else {
                
                  # Determine the end time of the last word partly but not properly included in the current word's pre-word context window
                  last_word_end = max(na.omit(corpus$word_end_time[corpus$word_id %in% cur_irrelevant_word_ids]))
                  
                  # If this word's endpoint occurs inside the current word's pre-word context window
                  if (last_word_end > cur_prewindow_start) {
                  
                    # Safety check
                    if (last_word_end <= first_word_start) {
                  
                      # Set the start time of the pre-word context window to the end time of the last word not properly included
                      # in this pre-word context window (shortening the pre-word context window)
                      first_word_start = last_word_end
                      
                    } else {
                    
                      print("Something's wrong with prewindow, utterance_id:")
                      print(utterance_id)
                      print("Word id:")
                      print(word_id)
                    }
                  }                  
                }
              }
            }

            lengths[corpus$word_id == word_id] = cur_word_start - first_word_start
          }
        }
      }      
    }
  }
  
  return(lengths)
}


## Determine the start time of pre-word context windows (optionally ignoring filled pauses (such as "uhm") and/or false starts)
begin.of.preword.window = function (corpus, window_length, ignore_filled_pauses=FALSE, ignore_false_starts=FALSE) {

  begins = corpus$word_id
  begins = NA
  
  # For each utterance (annotation unit) in the corpus
  for (utterance_id in unique(na.omit(corpus$utterance_id))) {
  
    # If there is no information about word times in the current utterance, record the pre-word window start time as NA
    if (all(is.na(corpus$word_start_time[corpus$utterance_id==utterance_id]))) {
      
      begins[corpus$utterance_id==utterance_id] = NA

    } else {
    
      # Determine the start time of the first word in the current utterance
      cur_record_start = min(na.omit(corpus$word_start_time[corpus$utterance_id==utterance_id]))
      
      # For each word in the current utterance
      for (word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
      
        # If it is the first word, there is no valid utterance-internal pre-word context window for this word
        if (word_id == min(na.omit(corpus$word_id[corpus$utterance_id == utterance_id]))) {
        
          begins[corpus$word_id == word_id] = NA
          
        } else {

          # If the current word does not have a start time, record the number of morphemes in its pre-word context window as NA
          if (length(unique(na.omit(corpus$word_start_time[corpus$word_id == word_id]))) == 0) {
          
            begins[corpus$word_id == word_id] = NA

          } else {
          
            # Determine the current word's start time
            cur_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==word_id]))
          
            # Calculate the current pre-word context window's start time using the parameter window_length
            cur_prewindow_start = cur_word_start - window_length

            # If the current pre-word window's start time would extent to before the start of the utterance,
            # set it to the start of the utterance (shorting the pre-word context window)
            if (cur_prewindow_start < cur_record_start) {
            
              cur_prewindow_start = cur_record_start            
            }
            
            # Vectors to collect the IDs of relevant words and words to be ignored
            cur_relevant_word_ids = c()
            cur_irrelevant_word_ids = c()
              
            # For each other word in the utterance
            for (other_word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
              
              # Determine its word start and end times
              other_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==other_word_id]))
              other_word_end = unique(na.omit(corpus$word_end_time[corpus$word_id==other_word_id]))
                
              # If there are valid start and end times for the current word
              if ((length(other_word_start) > 0) && (length(other_word_end) > 0)) {
                
                # Calculate its midpoint
                other_word_middle = other_word_start + ((other_word_end - other_word_start) / 2 )
                 
                # If the other word's midpoint lies within the current pre-word context window
                if ((other_word_middle >= cur_prewindow_start) && (other_word_middle <= cur_word_start)) {

                  # Optionally ignore filled pauses (such as "uhm") and/or false starts according to the parameter settings
                  if ((!((unique(na.omit(corpus$disfluency[corpus$word_id==other_word_id])) %in% c("fldps","fldps_new")) && (ignore_filled_pauses==TRUE))) && (!((unique(na.omit(corpus$disfluency[corpus$word_id==other_word_id])) %in% c("flst","flst_new")) && (ignore_false_starts==TRUE)))) {

                    # Remember the words falling inside the current word's pre-word context window
                    cur_relevant_word_ids = c(cur_relevant_word_ids, other_word_id)
                  }

                } else {
               
                  # Remember words whose midpoint falls outside the current word's pre-word context window,
                  # but whose end point false inside the current word's pre-word window
                  if ((other_word_start < cur_prewindow_start) && (other_word_end > cur_prewindow_start)) {

                    cur_irrelevant_word_ids = c(cur_irrelevant_word_ids, other_word_id)
                  }
                }
              }
            }
            
            # If there are no words inside the current word's pre-word context window
            if (length(cur_relevant_word_ids) == 0) {
            
              # If there are no words partly inside the current word's pre-word context window
              if (length(cur_irrelevant_word_ids) == 0) {
            
                # The start time of the pre-word window is the actual target length before the current word's start time
                first_word_start = cur_prewindow_start
              
              # If there are words partly but not properly inside the current word's pre-word context window
              } else {
 
                # Determine the end time of the last word partly inside the current word's pre-word context window
                last_word_end = max(na.omit(corpus$word_end_time[corpus$word_id %in% cur_irrelevant_word_ids]))
                
                # Safety check
                if (last_word_end >= cur_prewindow_start) {
                                    
                  # Set the start time of the pre-word context window to the end time of the last word not properly included
                  # in this pre-word context window (shortening the pre-word context window)
                  first_word_start = last_word_end
                      
                } else {
                    
                  print("Something's wrong with prewindow, utterance_id:")
                  print(utterance_id)
                  print("Word id:")
                  print(word_id)
                }
              }
            
            # If there are words inside the current word's pre-word context window
            } else {
            
              # Determine the start time of the first word inside the current word's pre-word context window
              first_word_start = min(na.omit(corpus$word_start_time[corpus$word_id %in% cur_relevant_word_ids]))
              
              # If the target pre-word window length is before the start of the first word included in the pre-word context window
              if (cur_prewindow_start < first_word_start) {
                              
                # And there are no words partly but not properly included in the pre-word context window
                if (length(cur_irrelevant_word_ids) == 0) {
              
                  # Use the actual target pre-word window length as the start of the pre-word window
                  first_word_start = cur_prewindow_start
                
                # If there are words only partly but not properly included in the pre-word context window
                } else {
                
                  # Determine the end time of the last word partly but not properly included in the current word's pre-word context window
                  last_word_end = max(na.omit(corpus$word_end_time[corpus$word_id %in% cur_irrelevant_word_ids]))

                  # If this word's endpoint occurs inside the current word's pre-word context window
                  if (last_word_end > cur_prewindow_start) {
                  
                    # Safety check
                    if (last_word_end <= first_word_start) {
                  
                      # Set the start time of the pre-word context window to the end time of the last word not properly included
                      # in this pre-word context window (shortening the pre-word context window)
                      first_word_start = last_word_end
                      
                    } else {
                    
                      print("Something's wrong with prewindow, utterance_id:")
                      print(utterance_id)
                      print("Word id:")
                      print(word_id)
                    }
                  }                  
                }
              }
            }

            begins[corpus$word_id == word_id] = first_word_start
          }
        }
      }      
    }
  }
  
  return(begins)
}


## Calculate the duration of pre-word context windows in seconds ignoring pauses as the sum of the durations of the words
## included in the pre-word context window (optionally ignoring filled pauses (such as "uhm") and/or false starts)
length.of.preword.window.from.wordtimes = function (corpus, window_length, ignore_filled_pauses=FALSE, ignore_false_starts=FALSE) {

  lengths = corpus$word_id
  lengths = NA
  
  # For each utterance (annotation unit) in the corpus
  for (utterance_id in unique(na.omit(corpus$utterance_id))) {
  
    # If there is no information about word times in the current utterance, record the pre-word window start time as NA
    if (all(is.na(corpus$word_start_time[corpus$utterance_id==utterance_id]))) {
      
      lengths[corpus$utterance_id==utterance_id] = NA

    } else {
    
      # Determine the start time of the first word in the current utterance
      cur_record_start = min(na.omit(corpus$word_start_time[corpus$utterance_id==utterance_id]))
      
      # For each word in the current utterance
      for (word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
      
        # If it is the first word, there is no valid utterance-internal pre-word context window for this word
        if (word_id == min(na.omit(corpus$word_id[corpus$utterance_id == utterance_id]))) {
        
          lengths[corpus$word_id == word_id] = NA
          
        } else {

          # If the current word does not have a start time, record the number of morphemes in its pre-word context window as NA
          if (length(unique(na.omit(corpus$word_start_time[corpus$word_id == word_id]))) == 0) {
          
            lengths[corpus$word_id == word_id] = NA

          } else {
          
            # Determine the current word's start time
            cur_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==word_id]))
          
            # Calculate the current pre-word context window's start time using the parameter window_length
            cur_prewindow_start = cur_word_start - window_length

            # If the current pre-word window's start time would extent to before the start of the utterance,
            # set it to the start of the utterance (shorting the pre-word context window)
            if (cur_prewindow_start < cur_record_start) {
            
              cur_prewindow_start = cur_record_start            
            }
            
            # Vector to collect the IDs of relevant words included in the current word's pre-word window
            cur_relevant_word_ids = c()
              
            # For each other word in the utterance
            for (other_word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
              
              # Determine its word start and end times
              other_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==other_word_id]))
              other_word_end = unique(na.omit(corpus$word_end_time[corpus$word_id==other_word_id]))
                
              # If there are valid start and end times for the current word
              if ((length(other_word_start) > 0) && (length(other_word_end) > 0)) {
                
                # Calculate its midpoint
                other_word_middle = other_word_start + ((other_word_end - other_word_start) / 2 )
                 
                # If the other word's midpoint lies within the current pre-word context window
                if ((other_word_middle >= cur_prewindow_start) && (other_word_middle <= cur_word_start)) {

                  # Optionally ignore filled pauses (such as "uhm") and/or false starts according to the parameter settings
                  if ((!((unique(na.omit(corpus$disfluency[corpus$word_id==other_word_id])) %in% c("fldps","fldps_new")) && (ignore_filled_pauses==TRUE))) && (!((unique(na.omit(corpus$disfluency[corpus$word_id==other_word_id])) %in% c("flst","flst_new")) && (ignore_false_starts==TRUE)))) {

                    # Remember the words falling inside the current word's pre-word context window
                    cur_relevant_word_ids = c(cur_relevant_word_ids, other_word_id)
                  }                  
                }
              }
            }

            # Sum up the durations of all words inside the current word's pre-word context window
            seconds_length = 0
            for (other_word in cur_relevant_word_ids) {
              
              seconds_length = seconds_length + unique(na.omit(corpus$word_length_seconds[corpus$word_id==other_word]))
            }

            lengths[corpus$word_id == word_id] = seconds_length
          }
        }
      }      
    }
  }
  
  return(lengths)
}


## Check if preword window contains an empty word of length 0 characters
## (This may occur if a word only consisted of punctuation symbols, such as "[...]" marking an unclear word in the Nǁng corpus
check.preword.window.for.empty.words = function (corpus, window_length, additional_pattern = NA) {

  zeros = corpus$word_id
  zeros = NA
  
  # For each utterance (annotation unit) in the corpus
  for (utterance_id in unique(na.omit(corpus$utterance_id))) {
  
    # If there is no information about word times in the current utterance, record the pre-word window start time as NA
    if (all(is.na(corpus$word_start_time[corpus$utterance_id==utterance_id]))) {
      
      zeros[corpus$utterance_id==utterance_id] = NA

    } else {
    
      # Determine the start time of the first word in the current utterance
      cur_record_start = min(na.omit(corpus$word_start_time[corpus$utterance_id==utterance_id]))
      
      # For each word in the current utterance
      for (word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
      
        # If it is the first word, there is no valid utterance-internal pre-word context window for this word
        if (word_id == min(na.omit(corpus$word_id[corpus$utterance_id == utterance_id]))) {
        
          zeros[corpus$word_id == word_id] = NA
          
        } else {

          # If the current word does not have a start time, record the number of morphemes in its pre-word context window as NA
          if (length(unique(na.omit(corpus$word_start_time[corpus$word_id == word_id]))) == 0) {
          
            zeros[corpus$word_id == word_id] = NA

          } else {
          
            # Determine the current word's start time
            cur_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==word_id]))
          
            # Calculate the current pre-word context window's start time using the parameter window_length
            cur_prewindow_start = cur_word_start - window_length

            # If the current pre-word window's start time would extent to before the start of the utterance,
            # set it to the start of the utterance (shorting the pre-word context window)
            if (cur_prewindow_start < cur_record_start) {
            
              cur_prewindow_start = cur_record_start
            }
            
            # Vector to collect the IDs of relevant words included in the current word's pre-word window
            cur_relevant_word_ids = c()
              
            # For each other word in the utterance
            for (other_word_id in sort(unique(na.omit(corpus$word_id[corpus$utterance_id == utterance_id])))) {
              
              # Determine its word start and end times
              other_word_start = unique(na.omit(corpus$word_start_time[corpus$word_id==other_word_id]))
              other_word_end = unique(na.omit(corpus$word_end_time[corpus$word_id==other_word_id]))
                
              # If there are valid start and end times for the current word
              if ((length(other_word_start) > 0) && (length(other_word_end) > 0)) {
                
                # Calculate its midpoint
                other_word_middle = other_word_start + ((other_word_end - other_word_start) / 2 )
                 
                # If the other word's midpoint lies within the current pre-word context window
                if ((other_word_middle >= cur_prewindow_start) && (other_word_middle <= cur_word_start)) {

                  # Remember the words falling inside the current word's pre-word context window
                  cur_relevant_word_ids = c(cur_relevant_word_ids, other_word_id)
                }
              }
            }

            # Check whether any word included in the current word's pre-word window context has a length of zero characters
            zero = FALSE          
            for (other_word in cur_relevant_word_ids) {
              
              if (unique(na.omit(corpus$word_length_characters[corpus$word_id==other_word])) == 0) {
              
                zero = TRUE
                
              } else {
                
                # Possibly look for additional special words
                if (!is.na(additional_pattern)) {
                
                  if (grepl(additional_pattern, unique(na.omit(corpus$word[corpus$word_id==other_word]))) == TRUE) {
                  
                    zero = TRUE
                  }
                }
              }
            }

            zeros[corpus$word_id == word_id] = zero
          }
        }
      }      
    }
  }
  
  return(zeros)
}



### Import corpus data into R (only included here for reference only since the raw Toolbox files are not included
### in the published data for this study)

## Baure

# 61 files
#
# 10930 tokens found in tier ref
# 29771 tokens found in tier tx
# 28621 tokens found in tier WordBegin
# 28621 tokens found in tier WordEnd
# 29771 tokens found in tier fldps
# 29771 tokens found in tier le
# 29771 tokens found in tier root
# 52707 tokens found in tier mb
# 52707 tokens found in tier ge
# 52707 tokens found in tier ps
# 52707 tokens found in tier lg
# 52707 tokens found in tier ntvr_ps_root
# 52707 tokens found in tier mt

baure.fmt = toolboxFormat (
"record" = c("ntvr_ref", "ntvr_language", "ntvr_file", "ntvr_number", "ref", "ELANBegin", "ELANEnd", "ELANParticipant", "nt", "ft", "ftE", "tx2"),
"word" = c("tx", "WordBegin", "WordEnd", "ntvr_ps_word", "fldps", "le", "root"),
"morpheme" = c("mb", "ge", "ps", "lg", "ntvr_ps_root", "mt")
)

baure.corpus.pos.positiontracking = readToolbox(dir("Baure/UniqueRecordMarker/2016-01-06/", full.names=T), baure.fmt)

length.corpus(baure.corpus.pos.positiontracking, "record")
# [1] 7967

length.corpus(baure.corpus.pos.positiontracking, "word")
# [1] 29771

length.corpus(baure.corpus.pos.positiontracking, "morpheme")
# [1] 52707

# Problems detected in the corpus
baure.parselog.pos.positiontracking = parse.log(baure.corpus.pos.positiontracking)
write.parselog(baure.parselog.pos.positiontracking,"parse.positiontracking.log")

# Convert corpus object to data.frame
baure.corpus.pos.data.frame = as.data.frame(baure.corpus.pos.positiontracking)

# Set correct encoding
baure.corpus.pos.data.frame = set.encoding(baure.corpus.pos.data.frame)

# Combine morphemes into words
baure.corpus.pos.data.frame = combine.morphemes.into.words(baure.corpus.pos.data.frame, c("mb","ge","ps","lg","ntvr_ps_root","mt"))

table(baure.corpus.pos.data.frame$ps)
#
#          -       -adv -base.suff       -clf      -intj         -n       -num       -prn     -redup       -rep -root.suff -stem.suff      -suff    -v.suff        ***        ???         ?v
#        360         10       5879        645         13         70        118          1         97          1        161        647       2928        135        400          7          1
#   =cl.encl  =psn.encl        adj       adj-       adj?        adv        art        aux base.pref-    cl.encl        clf      compl       conj        dem        det expression       ideo
#       1263       2655        835        112          1       3283        167          1        108          1         12         48       1886       2851       1193         69          9
#       intj      intj?        loc          n         n-       name        neg        num       num-   particle      pref-       prep   prevpart        prn  psn.prcl=         qu     redup-
#       1622          1          2       4665          1         28        858        192        124       1415         23        143        944       1041       7392         31         21
#          v
#       8237
#
table(baure.corpus.pos.data.frame$ntvr_ps_root)
#
#      - -AFFIX   -BPN     -N -OTHER   =BPN =OTHER AFFIX-    AUX   BPN=      N     N-  OTHER    PRO      V
#    360  10624      1     70     10   2655   1263    388      1   7392   4693      1  15970   1041   8238


## Bora

# 37 files
#
# 4062 tokens found in tier ref
# 30140 tokens found in tier t
# 30140 tokens found in tier WordBegin
# 30140 tokens found in tier WordEnd
# 30140 tokens found in tier fldps
# 30002 tokens found in tier le              # Checked! Correct. Missing le and root tokens due to records without glosses
# 30002 tokens found in tier root
# 30140 tokens found in tier ntvr_ps_word
# 66470 tokens found in tier mb
# 66470 tokens found in tier gl
# 66470 tokens found in tier ps
# 66470 tokens found in tier ntvr_ps_root
# 66470 tokens found in tier mt

bora.fmt = toolboxFormat (
"record" = c("ntvr_ref", "ntvr_language", "ntvr_file", "ntvr_number", "ref", "ELANBegin", "ELANEnd", "ELANParticipant", "com", "com_RB", "com_MO", "f", "fe"),
"word" = c("t", "ntvr_ps_word", "WordBegin", "WordEnd", "fldps", "le", "root"),
"morpheme" = c("mb", "gl", "ps", "ntvr_ps_root", "mt")
)

bora.corpus.pos.positiontracking = readToolbox(dir("Bora/UniqueRecordMarker/2016-01-06/", full.names=T), bora.fmt)

length.corpus(bora.corpus.pos.positiontracking, "record")
# [1] 4062

length.corpus(bora.corpus.pos.positiontracking, "word")
# [1] 30140

length.corpus(bora.corpus.pos.positiontracking, "morpheme")
# [1] 66470

# Problems detected in the corpus
bora.parselog.pos.positiontracking = parse.log(bora.corpus.pos.positiontracking)
write.parselog(bora.parselog.pos.positiontracking,"parse.positiontracking.log")

# Convert corpus object to data.frame
bora.corpus.pos.data.frame = as.data.frame(bora.corpus.pos.positiontracking)

# Set correct encoding
bora.corpus.pos.data.frame = set.encoding(bora.corpus.pos.data.frame)

# Combine morphemes into words
bora.corpus.pos.data.frame = combine.morphemes.into.words(bora.corpus.pos.data.frame, c("mb","gl","ps","ntvr_ps_root","mt"))

table(bora.corpus.pos.data.frame$ps)
#
#       -    -***      -?    -clf    -cli     -nd     -ni     -vd     -vi     ***       ?      ?-       a     adv     con     det     itj      iv       n   n.abs   n.col   n.loc   n.pos
#      51       4      59    3084    6571     421   12136    2303    8934     597      95       1     946    3934    1210    1590     224    1928    3448     742     818     606      76
#     ni-      no     num    onom     p.n    part    pron sng_elm      tv       v   v.sta     vd-     vi-
#    1161    6149      20     343     285     619      14       5    4211    2017     170     267    1431
#
table(bora.corpus.pos.data.frame$ntvr_ps_root)
#
#      - -AFFIX   -BPN    *** AFFIX-    BPN   BPN-   BPP-  FLDPS      N  OTHER    PRO      V
#     51  30494   3018    364    274   1120   1431   1155    231   5967   9355   4686   8324
#
#
table(bora.corpus.pos.data.frame$ntvr_ps_word)
#
#     ***     BPN     BPP   FLDPS       N   OTHER     PRO UNKNOWN       V
#     138    1123      12     586   12293   17960   11327      17   23152


## Chintang

# 55 files
#
# 12364 tokens found in tier ref
# 47868 tokens found in tier gw
# 47868 tokens found in tier WordBegin
# 47868 tokens found in tier WordEnd
# 47868 tokens found in tier fldps
# 47868 tokens found in tier le
# 47868 tokens found in tier root
# 82417 tokens found in tier mph
# 82417 tokens found in tier mgl
# 82417 tokens found in tier ps
# 82417 tokens found in tier ntvr_ps_root
# 82417 tokens found in tier lg
# 61936 tokens found in tier id                # Not all tokens annotated with word type IDs
# 82417 tokens found in tier mt

chintang.fmt = toolboxFormat (
"record" = c("ntvr_ref", "ntvr_language", "ntvr_file", "ntvr_number", "ref", "ELANBegin", "ELANEnd", "ELANParticipant", "comment", "dt", "eng", "nep"),
"word" = c("gw", "WordBegin", "WordEnd", "ntvr_ps_word", "fldps", "le", "root"),
"morpheme" = c("mph", "mgl", "ps", "lg", "id", "ntvr_ps_root", "mt")
)

chintang.corpus.pos.positiontracking = readToolbox(dir("Chintang/UniqueRecordMarker/2016-01-06/", full.names=T), chintang.fmt)

length.corpus(chintang.corpus.pos.positiontracking, "record")
# [1] 12364

length.corpus(chintang.corpus.pos.positiontracking, "word")
# [1] 47868

length.corpus(chintang.corpus.pos.positiontracking, "morpheme")
# [1] 82417

# Problems detected in the corpus
chintang.parselog.pos.positiontracking = parse.log(chintang.corpus.pos.positiontracking)
write.parselog(chintang.parselog.pos.positiontracking,"parse.positiontracking.log")

# Convert corpus object to data.frame
chintang.corpus.pos.data.frame = as.data.frame(chintang.corpus.pos.positiontracking)

# Set correct encoding
chintang.corpus.pos.data.frame = set.encoding(chintang.corpus.pos.data.frame)

# Combine morphemes into words
chintang.corpus.pos.data.frame = combine.morphemes.into.words(chintang.corpus.pos.data.frame, c("mph","mgl","lg","ps","id","ntvr_ps_root","mt"))

table(chintang.corpus.pos.data.frame$ps)
#
#      -    -gm     -n   -pro    -v2    -vi    -vt     13     59   6870    adj    adv     gm    gm- interj      n   none    num    pro   pro-  sound     v-     vi    vi-     vt    vt-
#    169  27685     25      2   2611     27      7      2      1      2    944   4102  11036   3906   4209   9846    362   1132   6017      4     12      5   4052     15   6181     63
#
table(chintang.corpus.pos.data.frame$ntvr_ps_root)
#
#      - -AFFIX   -BPN     -N   -PRO     -V AFFIX-   BPN-   BPP-      N  OTHER    PRO   PRO-      V     V-
#    169  25588   4735     25      2      7    697   2082   1127   9846  21802   6017      4  10233     83


## Dutch (Corpus Gesproken Nederlands)

# 17 files
# fn000086.txt
# fn000106.txt
# fn000137.txt
# fn000140.txt
# fn000254.txt
# fn000265.txt
# fn000280.txt
# fn000415.txt
# fn000446.txt
# fn000485.txt
# fn000505.txt
# fn000559.txt
# fn000570.txt
# fn000573.txt
# fn000587.txt
# fn000594.txt
# fn000674.txt
#
# 5822 tokens found in tier ref
# 39720 tokens found in tier tx
# 39720 tokens found in tier WordBegin
# 39720 tokens found in tier WordEnd
# 39720 tokens found in tier fldps
# 39720 tokens found in tier ph
# 39720 tokens found in tier le
# 39720 tokens found in tier mr
# 39720 tokens found in tier mg
# 39720 tokens found in tier ps
# 39720 tokens found in tier sl
# 39720 tokens found in tier rl
# 39720 tokens found in tier ntvr_ps_root_old
# 48738 tokens found in tier mb
# 48738 tokens found in tier ml
# 48738 tokens found in tier mt
# 0 tokens found in tier ntvr_ps_root

# Ignore morphemes for now until morphological annotation is complete
dutch.fmt = toolboxFormat (
"record" = c("ntvr_ref", "ntvr_language", "ntvr_file", "ntvr_number", "ref", "ELANBegin", "ELANEnd", "ELANParticipant"),
"word" = c("tx", "ph", "le", "WordBegin", "WordEnd", "ntvr_ps_word", "fldps"),
"morpheme" = c("mr","mg","ps","ntvr_ps_root_old")
)

dutch.corpus.pos.positiontracking = readToolbox(dir("Dutch/UniqueRecordMarker/2016-01-06/", full.names=T), dutch.fmt)

length.corpus(dutch.corpus.pos.positiontracking, "record")
# [1] 5822

length.corpus(dutch.corpus.pos.positiontracking, "word")
# [1] 39720

length.corpus(dutch.corpus.pos.positiontracking, "morpheme")
# [1] 39720

# Problems detected in the corpus
dutch.parselog.pos.positiontracking = parse.log(dutch.corpus.pos.positiontracking)
write.parselog(dutch.parselog.pos.positiontracking,"parse.positiontracking.log")

# Convert corpus object to data.frame
dutch.corpus.pos.data.frame = as.data.frame(dutch.corpus.pos.positiontracking)

# Set correct encoding
dutch.corpus.pos.data.frame = set.encoding(dutch.corpus.pos.data.frame)

# Combine morphemes into words
dutch.corpus.pos.data.frame = combine.morphemes.into.words(dutch.corpus.pos.data.frame, c("mb","ml","ntvr_ps_root","mt"))

table(dutch.corpus.pos.data.frame$ps)
# 
#  ADJ   BW  LID    N SPEC  TSW   TW   VG  VNW   VZ   WW
# 2735 5437 1799 4005 1586 3882  475 2583 7598 2901 6719

table(dutch.corpus.pos.data.frame$ntvr_ps_root_old)
#
# FLDPS     N OTHER   PRO     V V-BPN
#  1798  4005 21405  5793  1733  4986

table(dutch.corpus.pos.data.frame$ntvr_ps_word)
#
# FLDPS     N OTHER   PRO     V
#  1798  4176 21319  5793  6634

# Add an empty translation column
dutch.corpus.pos.data.frame$translation = ""


## English (Switchboard)

# 47 files
# sw2104.txt
# sw2295.txt
# sw2305.txt
# sw2540.txt
# sw2546.txt
# sw2558.txt
# sw2589.txt
# sw2628.txt
# sw2667.txt
# sw2743.txt
# sw2749.txt
# sw2761.txt
# sw2800.txt
# sw2837.txt
# sw3012.txt
# sw3062.txt
# sw3072.txt
# sw3080.txt
# sw3085.txt
# sw3097.txt
# sw3120.txt
# sw3154.txt
# sw3174.txt
# sw3182.txt
# sw3187.txt
# sw3219.txt
# sw3223.txt
# sw3227.txt
# sw3239.txt
# sw3246.txt
# sw3343.txt
# sw3360.txt
# sw3409.txt
# sw3435.txt
# sw3476.txt
# sw3495.txt
# sw3515.txt
# sw3658.txt
# sw3697.txt
# sw3707.txt
# sw4033.txt
# sw4049.txt
# sw4153.txt
# sw4159.txt
# sw4358.txt
# sw4733.txt
# sw4784.txt
#
# 6941 tokens found in tier ref
# 56138 tokens found in tier tx
# 56138 tokens found in tier WordBegin
# 56138 tokens found in tier WordEnd
# 56138 tokens found in tier PhonesBegin
# 56138 tokens found in tier PhonesEnd
# 56138 tokens found in tier ph
# 56138 tokens found in tier st
# 56138 tokens found in tier ps
# 56138 tokens found in tier fldps
# 56138 tokens found in tier le
# 56138 tokens found in tier root
# 56138 tokens found in tier ntvr_ps_word_old
# 56138 tokens found in tier ntvr_ps_root_old
# 61564 tokens found in tier mb
# 61564 tokens found in tier mg
# 61564 tokens found in tier mp
# 61564 tokens found in tier mt
# 61564 tokens found in tier ntvr_ps_root

english.fmt = toolboxFormat (
"record" = c("ntvr_ref", "ntvr_language", "ntvr_file", "ntvr_number", "ref", "ELANBegin", "ELANEnd", "ELANParticipant", "topic", "sex", "year", "dialect"),
"word" = c("tx", "ph", "st", "WordBegin", "WordEnd", "PhonesBegin", "PhonesEnd", "ntvr_ps_word_old", "fldps", "ps", "le", "root", "ntvr_ps_root_old"),
"morpheme" = c("mb", "mg", "mp", "mt", "ntvr_ps_root")
)

english.corpus.pos.positiontracking = readToolbox(dir("English/UniqueRecordMarker/2017-07-19/", full.names=T), english.fmt)

length.corpus(english.corpus.pos.positiontracking, "record")
# [1] 6941

length.corpus(english.corpus.pos.positiontracking, "word")
# [1] 56138

length.corpus(english.corpus.pos.positiontracking, "morpheme")
# [1] 61564

# Problems detected in the corpus
english.parselog.pos.positiontracking = parse.log(english.corpus.pos.positiontracking)
write.parselog(english.parselog.pos.positiontracking,"parse.positiontracking.log")

# Convert corpus object to data.frame
english.corpus.pos.data.frame = as.data.frame(english.corpus.pos.positiontracking)

# Set correct encoding
english.corpus.pos.data.frame = set.encoding(english.corpus.pos.data.frame)

# Combine morphemes into words
english.corpus.pos.data.frame = combine.morphemes.into.words(english.corpus.pos.data.frame, c("mb","mg","mp","ntvr_ps_root","mt"))

table(english.corpus.pos.data.frame$ps)
#
#  ^CC      ^DT      ^GW      ^IN      ^JJ      ^NN     ^NNS ^NNS^POS     ^PRP      ^RB      ^RP      ^UH      ^VB     ^VBG     ^VBN
#    3        2        1        2        7        8       14        2        1       12        1        1        5        2        1
# ^VBZ      BES       CC       CD       DT       EX       FW       GW      HVS       IN       JJ      JJR      JJS       MD       NN
#    2     1058     2747      563     4658      180        9       34       48     4902     2805      171       83      766     5999
#  NNP     NNPS      NNS      PDT      POS      PRP     PRP$       RB      RBR      RBS       RP      SYM       TO       UH    UH|IN
#  655       43     3529       86       56     7696      652     5253       92       18      241       16     1041     3982        1
#   VB      VBD      VBG      VBN      VBP      VBZ      WDT       WP      WP$      WRB       XX
# 2590     1975     1936     1082     4013     1239      412      355        1      428       85

table(english.corpus.pos.data.frame$ntvr_ps_root)
#   - -AFFIX AFFIX-  FLDPS      N  OTHER    PRO      V
# 212   4591    411    227   7779  27635   7937  12772
#

# Add an empty translation column
english.corpus.pos.data.frame$translation = ""


## Even

# 73 files
#
# 6117 tokens found in tier id
# 41700 tokens found in tier tx
# 41700 tokens found in tier WordBegin
# 41700 tokens found in tier WordEnd
# 41700 tokens found in tier fldps
# 41700 tokens found in tier le
# 41700 tokens found in tier root
# 0 tokens found in tier ntvr_ps_word
# 76814 tokens found in tier mb
# 76814 tokens found in tier ge
# 76814 tokens found in tier ntvr_ps_orig
# 76814 tokens found in tier ntvr_ps_root
# 76814 tokens found in tier mt

even.fmt = toolboxFormat (
"record" = c("ntvr_ref", "ntvr_language", "ntvr_file", "ntvr_number", "id", "ELANBegin", "ELANEnd", "ref", "ELANParticipant", "ft", "ru", "ev", "nt", "gr", "ph", "ps", "qu", "lg"),
"word" = c("tx", "WordBegin", "WordEnd", "ntvr_ps_word", "fldps", "le", "root"),
"morpheme" = c("mb", "ge", "ntvr_ps_orig", "ntvr_ps_root", "mt")
)

even.corpus.pos.positiontracking = readToolbox(dir("Even/UniqueRecordMarker/2016-01-06/", full.names=T), even.fmt)

length.corpus(even.corpus.pos.positiontracking, "record")
# [1] 5782

length.corpus(even.corpus.pos.positiontracking, "word")
# [1] 41700

length.corpus(even.corpus.pos.positiontracking, "morpheme")
# [1] 76814

# Problems detected in the corpus
even.parselog.pos.positiontracking = parse.log(even.corpus.pos.positiontracking)
write.parselog(even.parselog.pos.positiontracking,"parse.positiontracking.log")

# Convert corpus object to data.frame
even.corpus.pos.data.frame = as.data.frame(even.corpus.pos.positiontracking)

# Set correct encoding
even.corpus.pos.data.frame = set.encoding(even.corpus.pos.data.frame)

# Combine morphemes into words
even.corpus.pos.data.frame = combine.morphemes.into.words(even.corpus.pos.data.frame, c("mb","ge","ntvr_ps_orig","ntvr_ps_root","mt"))

table(even.corpus.pos.data.frame$ntvr_ps_orig)
#
#          -                   -adj                  -advb                  -case           -case_marker                   -cvb                   -der                -epenth
#          9                    348                    161                   6583                     18                   3020                   5867                   1566
#       -nmb    -nominal_derivation                    -nr    -numeral_derivation            -participle                   -ptc                   -ptl              -subj.agr
#       1742                      7                    294                     59                     34                    697                     47                   8583
#  -subj_agr -subordinate_predicate                  -suff                   -TAM          -TAM_subj_agr               -UNKNOWN     -verbal_derivation                    -vr
#        113                      3                      3                   5506                     32                     19                      5                    177
#        ***                   =der                   =ptl                    adj                  adj|n                    adv                adv|adj                adv|ptl
#       2989                    126                   1048                   1167                      3                   2626                    900                     75
#  AMBIGUOUS                    aux                   conj                    cvb                    dem                    der                   excl            false_start
#          1                    666                    542                     20                   3300                      4                      1                     59
#  ideophone                 interj          interrogative     interrogative|conj                      n                   name                    num                  OTHER
#         30                    578                   1683                     27                   8784                    909                   1173                    344
# participle              poss_pron                postpos            predicative           predicative?                   prep                   pron               pron_dem
#          1                      2                    104                      1                      2                     92                   1669                     15
#  pron_pers                    ptc                    ptl                  quant                   refl                  rel.n                    TAM                UNKNOWN
#          3                      3                   1635                    530                    115                    420                      1                     38
#         vb                   vb|n
#      10232                      3

table(even.corpus.pos.data.frame$ntvr_ps_root)
#
# -    -AFFIX      -BPN      -BPP    =AFFIX AMBIGUOUS       AUX         N     OTHER       PRO   UNKNOWN         V
# 9     26156      6364      2364      1174         7       667      9693     18306      1804        38     10232


## Hoocąk

# 63 files
#
# 3692 tokens found in tier ref
# 23419 tokens found in tier tx
# 23419 tokens found in tier mo
# 23419 tokens found in tier gl
# 23419 tokens found in tier ps
# 23419 tokens found in tier WordBegin
# 23419 tokens found in tier WordEnd
# 0 tokens found in tier ntvr_ps_word
# 23419 tokens found in tier fldps
# 23419 tokens found in tier le
# 23419 tokens found in tier root
# 41386 tokens found in tier sep_mo
# 41386 tokens found in tier sep_gl
# 41386 tokens found in tier sep_ps
# 41386 tokens found in tier ntvr_ps_root
# 41386 tokens found in tier mt

hoocak.fmt = toolboxFormat (
"record" = c("ntvr_ref", "ntvr_language", "ntvr_file", "ntvr_number", "ref", "ELANBegin", "ELANEnd", "ELANParticipant", "cm", "comments_DA", "dt", "ed", "ft", "gl-old", "jl", "mo-old", "or", "ot", "pr", "so", "ts"),
"word" = c("tx","mo", "gl", "ps", "WordBegin", "WordEnd", "ntvr_ps_word", "fldps", "le", "root"),
"morpheme" = c("sep_mo", "sep_gl", "sep_ps", "ntvr_ps_root", "mt")
)

hoocak.corpus.pos.positiontracking = readToolbox(dir("Hoocak/UniqueRecordMarker/2016-01-06/", full.names=T), hoocak.fmt)

length.corpus(hoocak.corpus.pos.positiontracking, "record")
# [1] 2988

length.corpus(hoocak.corpus.pos.positiontracking, "word")
# [1] 23419

length.corpus(hoocak.corpus.pos.positiontracking, "morpheme")
# [1] 41386

# Problems detected in the corpus
hoocak.parselog.pos.positiontracking = parse.log(hoocak.corpus.pos.positiontracking)
write.parselog(hoocak.parselog.pos.positiontracking,"parse.positiontracking.log")

# Convert corpus object to data.frame
hoocak.corpus.pos.data.frame = as.data.frame(hoocak.corpus.pos.positiontracking)

# Set correct encoding
hoocak.corpus.pos.data.frame = set.encoding(hoocak.corpus.pos.data.frame)

# Combine morphemes into words
hoocak.corpus.pos.data.frame  = combine.morphemes.into.words(hoocak.corpus.pos.data.frame, c("ntvr_ps_root","mt"))

table(hoocak.corpus.pos.data.frame$sep_ps)
#
#                      -                  -adv.                 -affix                -affix-                  -num.             -pron_dem.                     -X                    -X-
#                   1491                     86                   6043                     49                    210                     10                      1                    167
#                    ***                      =                 =affix              =art_def.                  =aux.              =enclitic             =pron_dem.                 =ptcl.
#                      2                    103                    319                   1992                    842                    646                    412                    142
#                    adv                   adv.           adv./pron._?             adv./ptcl.                 affirm                 AFFIRM                  affix                 affix-
#                      5                   5601                      4                   1331                     30                      1                     17                   3828
# affix+adv.|ptcl.|affix               art_def.                   aux.             aux.|v.tr.                  chant                  conj. discontinuous_morpheme               enclitic
#                     34                      5                    383                    777                     39                   1766                    404                     32
#                ENGLISH                  hesit                interj.                     n.              n.|v.act.            n.|v.inact.               n.|v.tr.                   num.
#                    461                    578                    257                   3632                     12                      5                      8                    461
#                  OTHER                  pron.              pron_dem.        pron_dem.|pron.              pron_int.             pron_pers.                prop_n.                  ptcl.
#                     45                    537                    475                    429                      6                    231                    118                     84
#                 quant.                    rdp                   slip               UNKNOWN-                     v.                 v.act.        v.act./v.inact.                v.ditr.
#                      1                     39                    116                      1                     11                   2126                      2                     36
#               v.inact.          v.inact./adv.      v.inact._/_v.act.         v.inact.|v.tr.                v.intr.                  v.tr.                     X-
#                   1148                     27                      2                      1                     37                   3727                      1

table(hoocak.corpus.pos.data.frame$ntvr_ps_root)
#
#      -   -AFFIX  -AFFIX-     -BPN   -OTHER  -OTHER-     -PRO        =   =AFFIX     =AUX   =OTHER     =PRO    AFFIX   AFFIX-      AUX      BPN     BPN-     BPP-        N    OTHER
#   1491     4782       49     1261      297      167       10      103      319      842     2780      412        7      705     1160       10     2966      157     3750    11294
# OTHER-      PRO  UNKNOWN UNKNOWN-        V
#      1     1678        2        1     7142


## Nǁng
#
# 33 files
#
# 9732 tokens found in tier ref
# 31760 tokens found in tier tx
# 31760 tokens found in tier WordBegin
# 31760 tokens found in tier WordEnd
# 31760 tokens found in tier fldps
# 31760 tokens found in tier le
# 31760 tokens found in tier root
# 35797 tokens found in tier mb
# 35797 tokens found in tier ge
# 35797 tokens found in tier ps
# 35797 tokens found in tier so
# 35797 tokens found in tier lxid
# 35797 tokens found in tier ntvr_ps_root
# 35797 tokens found in tier mt

nuu.fmt = toolboxFormat (
"record" = c("ntvr_ref", "ntvr_language", "ntvr_file", "ntvr_number", "ref", "ELANBegin", "ELANEnd", "PAUSE", "ELANParticipant", "dt", "orig", "fta", "fte", "nt", "na", "ng", "np", "nq", "cfn", "et"),
"word" = c("tx", "WordBegin", "WordEnd", "ntvr_ps_word", "fldps", "le", "root"),
"morpheme" = c("mb", "ge", "ps", "so", "lxid", "ntvr_ps_root", "mt")
)

nuu.corpus.pos.positiontracking = readToolbox(dir("Nuu/UniqueRecordMarker/2016-01-06/", full.names=T), nuu.fmt)

length.corpus(nuu.corpus.pos.positiontracking, "record")
# [1] 9732

length.corpus(nuu.corpus.pos.positiontracking, "word")
# [1] 31760

length.corpus(nuu.corpus.pos.positiontracking, "morpheme")
# [1] 35797

# Problems detected in the corpus
nuu.parselog.pos.positiontracking = parse.log(nuu.corpus.pos.positiontracking)
write.parselog(nuu.parselog.pos.positiontracking,"parse.positiontracking.log")

# Convert corpus object to data.frame
nuu.corpus.pos.data.frame = as.data.frame(nuu.corpus.pos.positiontracking)

# Set correct encoding
nuu.corpus.pos.data.frame = set.encoding(nuu.corpus.pos.data.frame)

# Combine morphemes into words
nuu.corpus.pos.data.frame = combine.morphemes.into.words(nuu.corpus.pos.data.frame, c("mb","ge","ps","so","lxid","ntvr_ps_root","mt"))

table(nuu.corpus.pos.data.frame$ps)
#
#   - -adjsf   -nsf -prosf    -sf   -vsf    ***      ?    adj    adp    adv    art   conj    dei    ide interj      n   npf-   part    pro  quant   vatr   vitr  vpart   vpf-    vtr
# 114     46   2136     10     25   1219   1047    136    468     60   1466    234    252    600     15    856   5591    150   5149   7187     86   1851   3048     52    231   3768

table(nuu.corpus.pos.data.frame$ntvr_ps_root)
#
#   - -AFFIX AFFIX-      N  OTHER    PRO      V
# 114   3436    381   5500  10512   7187   8667


## Texistepec Popoluca

# 9 files # Some without audio and thus without word times
#
# 18993 tokens found in tier rf
# 24811 tokens found in tier tx
# 21604 tokens found in tier WordBegin
# 21604 tokens found in tier WordEnd
# 0 tokens found in tier ntvr_ps_word
# 24811 tokens found in tier fldps
# 24811 tokens found in tier le
# 24811 tokens found in tier root
# 46629 tokens found in tier mr
# 46629 tokens found in tier ge
# 46629 tokens found in tier ps
# 46629 tokens found in tier ntvr_ps_root
# 46629 tokens found in tier mt

popoluca.fmt = toolboxFormat (
"record" = c("ntvr_ref", "ntvr_language", "ntvr_file", "ntvr_number", "rf", "ELANBegin", "ELANEnd", "ELANParticipant", "tr", "sy"),
"word" = c("tx", "WordBegin", "WordEnd", "ntvr_ps_word", "fldps", "le", "root"),
"morpheme" = c("mr", "ge", "ps", "ntvr_ps_root", "mt")
)

popoluca.corpus.pos.positiontracking = readToolbox(dir("Popoluca/UniqueRecordMarker/2016-01-06/", full.names=T), popoluca.fmt)

length.corpus(popoluca.corpus.pos.positiontracking, "record")
# [1] 6480

length.corpus(popoluca.corpus.pos.positiontracking, "word")
# [1] 24811

length.corpus(popoluca.corpus.pos.positiontracking, "morpheme")
# [1] 46629

# Problems detected in the corpus
popoluca.parselog.pos.positiontracking = parse.log(popoluca.corpus.pos.positiontracking)
write.parselog(popoluca.parselog.pos.positiontracking,"parse.positiontracking.log")

# Convert corpus object to data.frame
popoluca.corpus.pos.data.frame = as.data.frame(popoluca.corpus.pos.positiontracking)

# Set correct encoding
popoluca.corpus.pos.data.frame = set.encoding(popoluca.corpus.pos.data.frame)

# Combine morphemes into words
popoluca.corpus.pos.data.frame = combine.morphemes.into.words(popoluca.corpus.pos.data.frame, c("mr","ge","ps","ntvr_ps_root","mt"))

table(popoluca.corpus.pos.data.frame$ps)
#
#           -               -affix         -affix/enclt                 -der             -der_adj             -der_num            -der_pron               -der_s
#        1358                 3884                   32                   65                  989                    1                   69                  195
#      -der_v              -der_vi        -der_vt/der_v               -enclt                -infl                  ***                  adj                  adv
#         158                   67                  659                  723                  867                   61                  946                 2063
#     adv/adj           adv/interr           adv/partcl               affix-                  aux                 conj               der_v-                infl-
#           1                   10                  162                11375                 2503                  532                   21                    3
#      interj               interr              nom_pro                  num               partcl        partcl$interr        partcl/interj        partcl_interr
#         542                  225                  148                  397                 2214                   10                    7                   58
#        pron             pron$adj          pron_interr pron_interr/pron_rel                    s                s$adj           s$interj$v                s_pos
#        1983                   39                  125                   56                 3071                   36                    5                  521
#     unknown                    v                 v/vt         v_imperativo                   vi              vi/vi_a                vi/vt                 vi_a
#           1                  440                    4                   40                 5907                    7                  208                    5
# vi_ap/vt/vi                 vi_e           vi_e$s_pos              vi_e/vt              vi_e_pl                   vt                vt/vi              vt/vi_a
#          15                  145                    3                   12                    1                 2569                  382                  209
#     vt/vi_p               vt_apl                 vt_c            vt_c/vi_p
#         486                    4                    7                    3

table(popoluca.corpus.pos.data.frame$ntvr_ps_root)
#
#    -    -AFFIX      -BPN    AFFIX- AMBIGUOUS       AUX      BPN-      BPP-         N     OTHER       PRO   UNKNOWN         V
# 1358      6708      1001      3414        83      2503      6953      1032      3740      9690      2164         1      7982

# Name the one and only speaker "SP1"
popoluca.corpus.pos.data.frame$ELANParticipant = "SP1"


## Map column names to common names
## Use: words, morph, gloss, language, id, ps, translation

# Baure
colnames(baure.corpus.pos.data.frame)
#  [1] "record.id"               "word.id"                 "morpheme.id"             "ntvr_ref"                "ntvr_language"           "ntvr_file"               "ntvr_number"
#  [8] "ref"                     "ELANBegin"               "ELANEnd"                 "ELANParticipant"         "nt"                      "ft"                      "ftE"
# [15] "tx2"                     "tx"                      "WordBegin"               "WordEnd"                 "ntvr_ps_word"            "fldps"                   "le"
# [22] "root"                    "mb"                      "ge"                      "ps"                      "lg"                      "ntvr_ps_root"            "mt"
# [29] "whole_word_mb"           "whole_word_ge"           "whole_word_ps"           "whole_word_lg"           "whole_word_ntvr_ps_root" "whole_word_mt"


colnames(baure.corpus.pos.data.frame) = c("utterance_id","word_id","morpheme_id","ntvr_ref","language_iso_code","text","ntvr_number",
"orig_ref","utterance_start_time","utterance_end_time","speaker","nt","ft","translation","tx2","word","word_start_time","word_end_time","ntvr_ps_word","disfluency","le","root",
"morph","gloss","ps","lg","word_class_all","mt","whole_word_morph","whole_word_gloss","whole_word_ps","whole_word_lg","whole_word_word_class_all","whole_word_mt")

# Bora
colnames(bora.corpus.pos.data.frame)
#  [1] "record.id"               "word.id"                 "morpheme.id"             "ntvr_ref"                "ntvr_language"           "ntvr_file"               "ntvr_number"
#  [8] "ref"                     "ELANBegin"               "ELANEnd"                 "ELANParticipant"         "com"                     "com_RB"                  "com_MO"
# [15] "f"                       "fe"                      "t"                       "ntvr_ps_word"            "WordBegin"               "WordEnd"                 "fldps"
# [22] "le"                      "root"                    "mb"                      "gl"                      "ps"                      "ntvr_ps_root"            "mt"
# [29] "whole_word_mb"           "whole_word_gl"           "whole_word_ps"           "whole_word_ntvr_ps_root" "whole_word_mt"

colnames(bora.corpus.pos.data.frame) = c("utterance_id","word_id","morpheme_id","ntvr_ref","language_iso_code","text","ntvr_number",
"orig_ref","utterance_start_time","utterance_end_time","speaker","com","com_RB","com_MO","f","translation","word","ntvr_ps_word","word_start_time","word_end_time",
"disfluency","le","root","morph","gloss","ps","word_class_all","mt","whole_word_morph","whole_word_gloss","whole_word_ps","whole_word_word_class_all",
"whole_word_mt")

# Chintang
colnames(chintang.corpus.pos.data.frame)
#  [1] "record.id"               "word.id"                 "morpheme.id"             "ntvr_ref"                "ntvr_language"           "ntvr_file"               "ntvr_number"
#  [8] "ref"                     "ELANBegin"               "ELANEnd"                 "ELANParticipant"         "comment"                 "dt"                      "eng"
# [15] "nep"                     "gw"                      "WordBegin"               "WordEnd"                 "ntvr_ps_word"            "fldps"                   "le"
# [22] "root"                    "mph"                     "mgl"                     "ps"                      "lg"                      "id"                      "ntvr_ps_root"
# [29] "mt"                      "whole_word_mph"          "whole_word_mgl"          "whole_word_lg"           "whole_word_ps"           "whole_word_id"           "whole_word_ntvr_ps_root"
# [36] "whole_word_mt"

colnames(chintang.corpus.pos.data.frame) = c("utterance_id","word_id","morpheme_id","ntvr_ref","language_iso_code","text","ntvr_number",
"orig_ref","utterance_start_time","utterance_end_time","speaker","comment","dt","translation","nep","word","word_start_time","word_end_time","ntvr_ps_word","disfluency",
"le","root","morph","gloss","ps","lg","id","word_class_all","mt","whole_word_morph","whole_word_gloss","whole_word_lg","whole_word_ps","whole_word_id",
"whole_word_word_class_all","whole_word_mt")

# Dutch
colnames(dutch.corpus.pos.data.frame)
#  [1] "record.id"               "word.id"                 "morpheme.id"             "ntvr_ref"                "ntvr_language"           "ntvr_file"               "ntvr_number"
#  [8] "ref"                     "ELANBegin"               "ELANEnd"                 "ELANParticipant"         "tx"                      "ph"                      "le"
# [15] "WordBegin"               "WordEnd"                 "ntvr_ps_word"            "fldps"                   "mr"                      "mg"                      "ps"
# [22] "sl"                      "rl"                      "ntvr_ps_root_old"        "mb"                      "ml"                      "mt"                      "ntvr_ps_root"
# [29] "whole_word_mb"           "whole_word_ml"           "whole_word_ntvr_ps_root" "whole_word_mt"           "translation"

# "gloss" is not really correct, it now contains the basic morpheme forms
# "ps" is still per word instead of per morpheme
colnames(dutch.corpus.pos.data.frame) = c("utterance_id","word_id","morpheme_id","ntvr_ref","language_iso_code","text","ntvr_number",
"orig_ref","utterance_start_time","utterance_end_time","speaker","word","phon","le","word_start_time","word_end_time","ntvr_ps_word","disfluency",
"mr","mg","ps","le","root","word_class_all_old","morph","gloss","mt","word_class_all","whole_word_morph","whole_word_gloss","whole_word_word_class_all",
"whole_word_mt","translation")

dutch.corpus.pos.data.frame$whole_word_ps = dutch.corpus.pos.data.frame$ps
dutch.corpus.pos.data.frame$root = NA
dutch.corpus.pos.data.frame$mt = NA
dutch.corpus.pos.data.frame$whole_word_mt = NA

# English
colnames(english.corpus.pos.data.frame)
#  [1] "record.id"               "word.id"                 "morpheme.id"             "ntvr_ref"                "ntvr_language"
#  [6] "ntvr_file"               "ntvr_number"             "ref"                     "ELANBegin"               "ELANEnd"
# [11] "ELANParticipant"         "topic"                   "sex"                     "year"                    "dialect"
# [16] "tx"                      "ph"                      "st"                      "WordBegin"               "WordEnd"
# [21] "PhonesBegin"             "PhonesEnd"               "ntvr_ps_word_old"        "fldps"                   "ps"
# [26] "le"                      "root"                    "ntvr_ps_root_old"        "mb"                      "mg"
# [31] "mp"                      "mt"                      "ntvr_ps_root"            "whole_word_mb"           "whole_word_mg"
# [36] "whole_word_mp"           "whole_word_ntvr_ps_root" "whole_word_mt"           "translation"

# "mg" is not really a gloss but rather the basic form of a morpheme
colnames(english.corpus.pos.data.frame) = c("utterance_id","word_id","morpheme_id","ntvr_ref","language_iso_code","text","ntvr_number",
"orig_ref","utterance_start_time","utterance_end_time","speaker","topic","sex","year","dialect","word","phon","stress","word_start_time",
"word_end_time", "PhonesBegin","PhonesEnd","ntvr_ps_word","disfluency","ps_orig","le","root","word_class_all_old","morph","gloss","ps",
"mt","word_class_all","whole_word_morph","whole_word_gloss","whole_word_ps","whole_word_word_class_all","whole_word_mt","translation")

# Even
colnames(even.corpus.pos.data.frame)
#  [1] "record.id"               "word.id"                 "morpheme.id"             "ntvr_ref"                "ntvr_language"           "ntvr_file"               "ntvr_number"
#  [8] "id"                      "ELANBegin"               "ELANEnd"                 "ref"                     "ELANParticipant"         "ft"                      "ru"
# [15] "ev"                      "nt"                      "gr"                      "ph"                      "ps"                      "qu"                      "lg"
# [22] "tx"                      "WordBegin"               "WordEnd"                 "ntvr_ps_word"            "fldps"                   "le"                      "root"
# [29] "mb"                      "ge"                      "ntvr_ps_orig"            "ntvr_ps_root"            "mt"                      "whole_word_mb"           "whole_word_ge"
# [36] "whole_word_ntvr_ps_orig" "whole_word_ntvr_ps_root" "whole_word_mt"

colnames(even.corpus.pos.data.frame) = c("utterance_id","word_id","morpheme_id","ntvr_ref","language_iso_code","text","ntvr_number",
"orig_ref","utterance_start_time","utterance_end_time","ref","speaker","translation","ru","ev","nt","gr","ph","ps_old","qu","lg","word",
"word_start_time","word_end_time","ntvr_ps_word","disfluency","le","root","morph","gloss","ps","word_class_all","mt","whole_word_morph","whole_word_gloss","whole_word_ps",
"whole_word_word_class_all","whole_word_mt")

# Hoocąk
colnames(hoocak.corpus.pos.data.frame)
#  [1] "record.id"               "word.id"                 "morpheme.id"             "ntvr_ref"                "ntvr_language"           "ntvr_file"               "ntvr_number"
#  [8] "ref"                     "ELANBegin"               "ELANEnd"                 "ELANParticipant"         "cm"                      "comments_DA"             "dt"
# [15] "ed"                      "ft"                      "gl-old"                  "jl"                      "mo-old"                  "or"                      "ot"
# [22] "pr"                      "so"                      "ts"                      "tx"                      "mo"                      "gl"                      "ps"
# [29] "WordBegin"               "WordEnd"                 "ntvr_ps_word"            "fldps"                   "le"                      "root"                    "sep_mo"
# [36] "sep_gl"                  "sep_ps"                  "ntvr_ps_root"            "mt"                      "whole_word_ntvr_ps_root" "whole_word_mt"

colnames(hoocak.corpus.pos.data.frame) = c("utterance_id","word_id","morpheme_id","ntvr_ref","language_iso_code","text","ntvr_number",
"orig_ref","utterance_start_time","utterance_end_time","speaker","cm","comments_DA","dt","ed","translation","gl-old","jl","mo-old","or",
"ot","pr","so","ts","word","whole_word_morph","whole_word_gloss","whole_word_ps","word_start_time","word_end_time","ntvr_ps_word","disfluency","le","root",
"morph","gloss","ps","word_class_all","mt","whole_word_word_class_all","whole_word_mt")

# Nǁng
colnames(nuu.corpus.pos.data.frame)
#  [1] "record.id"               "word.id"                 "morpheme.id"             "ntvr_ref"                "ntvr_language"           "ntvr_file"               "ntvr_number"
#  [8] "ref"                     "ELANBegin"               "ELANEnd"                 "PAUSE"                   "ELANParticipant"         "dt"                      "orig"
# [15] "fta"                     "fte"                     "nt"                      "na"                      "ng"                      "np"                      "nq"
# [22] "cfn"                     "et"                      "tx"                      "WordBegin"               "WordEnd"                 "ntvr_ps_word"            "fldps"
# [29] "le"                      "root"                    "mb"                      "ge"                      "ps"                      "so"                      "lxid"
# [36] "ntvr_ps_root"            "mt"                      "whole_word_mb"           "whole_word_ge"           "whole_word_ps"           "whole_word_so"           "whole_word_lxid"
# [43] "whole_word_ntvr_ps_root" "whole_word_mt"

colnames(nuu.corpus.pos.data.frame) = c("utterance_id","word_id","morpheme_id","ntvr_ref","language_iso_code","text","ntvr_number",
"orig_ref","utterance_start_time","utterance_end_time","PAUSE","speaker","dt","orig","fta","translation","nt","na","ng","np","nq","cfn","et",
"word","word_start_time","word_end_time","ntvr_ps_word","disfluency","le","root","morph","gloss","ps","lg","id","word_class_all","mt","whole_word_morph","whole_word_gloss",
"whole_word_ps","whole_word_lg","whole_word_id","whole_word_word_class_all","whole_word_mt")

# Texistepec Popoluca
colnames(popoluca.corpus.pos.data.frame)
#  [1] "record.id"               "word.id"                 "morpheme.id"             "ntvr_ref"                "ntvr_language"           "ntvr_file"               "ntvr_number"
#  [8] "rf"                      "ELANBegin"               "ELANEnd"                 "ELANParticipant"         "tr"                      "sy"                      "tx"
# [15] "WordBegin"               "WordEnd"                 "ntvr_ps_word"            "fldps"                   "le"                      "root"                    "mr"
# [22] "ge"                      "ps"                      "ntvr_ps_root"            "mt"                      "whole_word_mr"           "whole_word_ge"           "whole_word_ps"
# [29] "whole_word_ntvr_ps_root" "whole_word_mt"

colnames(popoluca.corpus.pos.data.frame) = c("utterance_id","word_id","morpheme_id","ntvr_ref","language_iso_code","text","ntvr_number",
"orig_ref","utterance_start_time","utterance_end_time","speaker","translation","sy","word","word_start_time","word_end_time","ntvr_ps_word","disfluency","le","root","morph","gloss",
"ps","word_class_all","mt","whole_word_morph","whole_word_gloss","whole_word_ps","whole_word_word_class_all","whole_word_mt")


### Corpus statistics of whole corpus (before excluding anything)

# Number of sessions
length(unique(na.omit(baure.corpus.pos.data.frame$text)))
# [1] 61

length(unique(na.omit(bora.corpus.pos.data.frame$text)))
# [1] 37

length(unique(na.omit(chintang.corpus.pos.data.frame$text)))
# [1] 55

length(unique(na.omit(dutch.corpus.pos.data.frame$text)))
# [1] 17

length(unique(na.omit(english.corpus.pos.data.frame$text)))
# [1] 47

length(unique(na.omit(even.corpus.pos.data.frame$text)))
# [1] 73

length(unique(na.omit(hoocak.corpus.pos.data.frame$text)))
# [1] 63

length(unique(na.omit(nuu.corpus.pos.data.frame$text)))
# [1] 33

length(unique(na.omit(popoluca.corpus.pos.data.frame$text)))
# [1] 9


# Number of speakers
length(unique(na.omit(baure.corpus.pos.data.frame$speaker)))
# [1] 18

length(unique(na.omit(bora.corpus.pos.data.frame$speaker)))
# [1] 47

length(unique(na.omit(chintang.corpus.pos.data.frame$speaker)))
# [1] 83

length(unique(na.omit(dutch.corpus.pos.data.frame$speaker)))
# [1] 42

length(unique(na.omit(english.corpus.pos.data.frame$speaker)))
# [1] 80

length(unique(na.omit(even.corpus.pos.data.frame$speaker)))
# [1] 44

length(unique(na.omit(hoocak.corpus.pos.data.frame$speaker)))
# [1] 31

length(unique(na.omit(nuu.corpus.pos.data.frame$speaker)))
# [1] 14

length(unique(na.omit(popoluca.corpus.pos.data.frame$speaker)))
# [1] 1


# Number of utterances (annotation units)
length(unique(na.omit(baure.corpus.pos.data.frame$ntvr_ref)))
# [1] 7967

length(unique(na.omit(bora.corpus.pos.data.frame$ntvr_ref)))
# [1] 4062

length(unique(na.omit(chintang.corpus.pos.data.frame$ntvr_ref)))
# [1] 12364

length(unique(na.omit(dutch.corpus.pos.data.frame$ntvr_ref)))
# [1] 5822

length(unique(na.omit(english.corpus.pos.data.frame$ntvr_ref)))
# [1] 6941

length(unique(na.omit(even.corpus.pos.data.frame$ntvr_ref)))
# [1] 5782

length(unique(na.omit(hoocak.corpus.pos.data.frame$ntvr_ref)))
# [1] 2988

length(unique(na.omit(nuu.corpus.pos.data.frame$ntvr_ref)))
# [1] 9732

length(unique(na.omit(popoluca.corpus.pos.data.frame$ntvr_ref)))
# [1] 6480


# Number of words
length(unique(na.omit(baure.corpus.pos.data.frame$word_id)))
# [1] 29771

length(unique(na.omit(bora.corpus.pos.data.frame$word_id)))
# [1] 30140

length(unique(na.omit(chintang.corpus.pos.data.frame$word_id)))
# [1] 47868

length(unique(na.omit(dutch.corpus.pos.data.frame$word_id)))
# [1] 39720

length(unique(na.omit(english.corpus.pos.data.frame$word_id)))
# [1] 56138

length(unique(na.omit(even.corpus.pos.data.frame$word_id)))
# [1] 41700

length(unique(na.omit(hoocak.corpus.pos.data.frame$word_id)))
# [1] 23419

length(unique(na.omit(nuu.corpus.pos.data.frame$word_id)))
# [1] 31760

length(unique(na.omit(popoluca.corpus.pos.data.frame$word_id)))
# [1] 24811


# Number of morphemes
length(unique(na.omit(baure.corpus.pos.data.frame$morpheme_id)))
# [1] 52707

length(unique(na.omit(bora.corpus.pos.data.frame$morpheme_id)))
# [1] 66470

length(unique(na.omit(chintang.corpus.pos.data.frame$morpheme_id)))
# [1] 82417

length(unique(na.omit(dutch.corpus.pos.data.frame$morpheme_id)))
# [1] 39720

length(unique(na.omit(english.corpus.pos.data.frame$morpheme_id)))
# [1] 61564

length(unique(na.omit(even.corpus.pos.data.frame$morpheme_id)))
# [1] 76814

length(unique(na.omit(hoocak.corpus.pos.data.frame$morpheme_id)))
# [1] 41386

length(unique(na.omit(nuu.corpus.pos.data.frame$morpheme_id)))
# [1] 35797

length(unique(na.omit(popoluca.corpus.pos.data.frame$morpheme_id)))
# [1] 46629


# Words per utterance (annotation unit)
length(unique(na.omit(baure.corpus.pos.data.frame$word_id))) / length(unique(na.omit(baure.corpus.pos.data.frame$ntvr_ref)))
# [1] 3.736789

length(unique(na.omit(bora.corpus.pos.data.frame$word_id))) / length(unique(na.omit(bora.corpus.pos.data.frame$ntvr_ref)))
# [1] 7.41999

length(unique(na.omit(chintang.corpus.pos.data.frame$word_id))) / length(unique(na.omit(chintang.corpus.pos.data.frame$ntvr_ref)))
# [1] 3.871563

length(unique(na.omit(dutch.corpus.pos.data.frame$word_id))) / length(unique(na.omit(dutch.corpus.pos.data.frame$ntvr_ref)))
# [1] 6.822398

length(unique(na.omit(english.corpus.pos.data.frame$word_id))) / length(unique(na.omit(english.corpus.pos.data.frame$ntvr_ref)))
# [1] 8.087884

length(unique(na.omit(even.corpus.pos.data.frame$word_id))) / length(unique(na.omit(even.corpus.pos.data.frame$ntvr_ref)))
# [1] 7.212037

length(unique(na.omit(hoocak.corpus.pos.data.frame$word_id))) / length(unique(na.omit(hoocak.corpus.pos.data.frame$ntvr_ref)))
# [1] 7.837684

length(unique(na.omit(nuu.corpus.pos.data.frame$word_id))) / length(unique(na.omit(nuu.corpus.pos.data.frame$ntvr_ref)))
# [1] 3.263461

length(unique(na.omit(popoluca.corpus.pos.data.frame$word_id))) / length(unique(na.omit(popoluca.corpus.pos.data.frame$ntvr_ref)))
# [1] 3.828858


# Morphemes per word
length(unique(na.omit(baure.corpus.pos.data.frame$morpheme_id))) / length(unique(na.omit(baure.corpus.pos.data.frame$word_id)))
# [1] 1.770414

length(unique(na.omit(bora.corpus.pos.data.frame$morpheme_id))) / length(unique(na.omit(bora.corpus.pos.data.frame$word_id)))
# [1] 2.205375

length(unique(na.omit(chintang.corpus.pos.data.frame$morpheme_id))) / length(unique(na.omit(chintang.corpus.pos.data.frame$word_id)))
# [1] 1.721756

length(unique(na.omit(dutch.corpus.pos.data.frame$morpheme_id))) / length(unique(na.omit(dutch.corpus.pos.data.frame$word_id)))
# [1] 1

length(unique(na.omit(english.corpus.pos.data.frame$morpheme_id))) / length(unique(na.omit(english.corpus.pos.data.frame$word_id)))
# [1] 1.096655

length(unique(na.omit(even.corpus.pos.data.frame$morpheme_id))) / length(unique(na.omit(even.corpus.pos.data.frame$word_id)))
# [1] 1.842062

length(unique(na.omit(hoocak.corpus.pos.data.frame$morpheme_id))) / length(unique(na.omit(hoocak.corpus.pos.data.frame$word_id)))
# [1] 1.767198

length(unique(na.omit(nuu.corpus.pos.data.frame$morpheme_id))) / length(unique(na.omit(nuu.corpus.pos.data.frame$word_id)))
# [1] 1.12711

length(unique(na.omit(popoluca.corpus.pos.data.frame$morpheme_id))) / length(unique(na.omit(popoluca.corpus.pos.data.frame$word_id)))
# [1] 1.879368


### Corpus annotation

## Set word times to numeric
baure.corpus.pos.data.frame$word_start_time = as.numeric(baure.corpus.pos.data.frame$word_start_time)
baure.corpus.pos.data.frame$word_end_time = as.numeric(baure.corpus.pos.data.frame$word_end_time)
bora.corpus.pos.data.frame$word_start_time = as.numeric(bora.corpus.pos.data.frame$word_start_time)
bora.corpus.pos.data.frame$word_end_time = as.numeric(bora.corpus.pos.data.frame$word_end_time)
chintang.corpus.pos.data.frame$word_start_time = as.numeric(chintang.corpus.pos.data.frame$word_start_time)
chintang.corpus.pos.data.frame$word_end_time = as.numeric(chintang.corpus.pos.data.frame$word_end_time)
dutch.corpus.pos.data.frame$word_start_time = as.numeric(dutch.corpus.pos.data.frame$word_start_time)
dutch.corpus.pos.data.frame$word_end_time = as.numeric(dutch.corpus.pos.data.frame$word_end_time)
english.corpus.pos.data.frame$word_start_time = as.numeric(english.corpus.pos.data.frame$word_start_time)
english.corpus.pos.data.frame$word_end_time = as.numeric(english.corpus.pos.data.frame$word_end_time)
even.corpus.pos.data.frame$word_start_time = as.numeric(even.corpus.pos.data.frame$word_start_time)
even.corpus.pos.data.frame$word_end_time = as.numeric(even.corpus.pos.data.frame$word_end_time)
hoocak.corpus.pos.data.frame$word_start_time = as.numeric(hoocak.corpus.pos.data.frame$word_start_time)
hoocak.corpus.pos.data.frame$word_end_time = as.numeric(hoocak.corpus.pos.data.frame$word_end_time)
nuu.corpus.pos.data.frame$word_start_time = as.numeric(nuu.corpus.pos.data.frame$word_start_time)
nuu.corpus.pos.data.frame$word_end_time = as.numeric(nuu.corpus.pos.data.frame$word_end_time)
popoluca.corpus.pos.data.frame$word_start_time = as.numeric(popoluca.corpus.pos.data.frame$word_start_time)
popoluca.corpus.pos.data.frame$word_end_time = as.numeric(popoluca.corpus.pos.data.frame$word_end_time)


## Set word midpoints
baure.corpus.pos.data.frame$word_mid_point = (baure.corpus.pos.data.frame$word_start_time + baure.corpus.pos.data.frame$word_end_time) / 2
bora.corpus.pos.data.frame$word_mid_point = (bora.corpus.pos.data.frame$word_start_time + bora.corpus.pos.data.frame$word_end_time) / 2
chintang.corpus.pos.data.frame$word_mid_point = (chintang.corpus.pos.data.frame$word_start_time + chintang.corpus.pos.data.frame$word_end_time) / 2
dutch.corpus.pos.data.frame$word_mid_point = (dutch.corpus.pos.data.frame$word_start_time + dutch.corpus.pos.data.frame$word_end_time) / 2
english.corpus.pos.data.frame$word_mid_point = (english.corpus.pos.data.frame$word_start_time + english.corpus.pos.data.frame$word_end_time) / 2
even.corpus.pos.data.frame$word_mid_point = (even.corpus.pos.data.frame$word_start_time + even.corpus.pos.data.frame$word_end_time) / 2
hoocak.corpus.pos.data.frame$word_mid_point = (hoocak.corpus.pos.data.frame$word_start_time + hoocak.corpus.pos.data.frame$word_end_time) / 2
nuu.corpus.pos.data.frame$word_mid_point = (nuu.corpus.pos.data.frame$word_start_time + nuu.corpus.pos.data.frame$word_end_time) / 2
popoluca.corpus.pos.data.frame$word_mid_point = (popoluca.corpus.pos.data.frame$word_start_time + popoluca.corpus.pos.data.frame$word_end_time) / 2


## Set word lengths
baure.corpus.pos.data.frame$word_length_seconds = baure.corpus.pos.data.frame$word_end_time - baure.corpus.pos.data.frame$word_start_time
bora.corpus.pos.data.frame$word_length_seconds = bora.corpus.pos.data.frame$word_end_time - bora.corpus.pos.data.frame$word_start_time
chintang.corpus.pos.data.frame$word_length_seconds = chintang.corpus.pos.data.frame$word_end_time - chintang.corpus.pos.data.frame$word_start_time
dutch.corpus.pos.data.frame$word_length_seconds = dutch.corpus.pos.data.frame$word_end_time - dutch.corpus.pos.data.frame$word_start_time
english.corpus.pos.data.frame$word_length_seconds = english.corpus.pos.data.frame$word_end_time - english.corpus.pos.data.frame$word_start_time
even.corpus.pos.data.frame$word_length_seconds = even.corpus.pos.data.frame$word_end_time - even.corpus.pos.data.frame$word_start_time
hoocak.corpus.pos.data.frame$word_length_seconds = hoocak.corpus.pos.data.frame$word_end_time - hoocak.corpus.pos.data.frame$word_start_time
nuu.corpus.pos.data.frame$word_length_seconds = nuu.corpus.pos.data.frame$word_end_time - nuu.corpus.pos.data.frame$word_start_time
popoluca.corpus.pos.data.frame$word_length_seconds = popoluca.corpus.pos.data.frame$word_end_time - popoluca.corpus.pos.data.frame$word_start_time


## Add language names
baure.corpus.pos.data.frame$language="Baure"
bora.corpus.pos.data.frame$language = "Bora"
chintang.corpus.pos.data.frame$language = "Chintang"
dutch.corpus.pos.data.frame$language = "Dutch"
english.corpus.pos.data.frame$language = "English"
even.corpus.pos.data.frame$language = "Even"
hoocak.corpus.pos.data.frame$language = "Hoocąk"
nuu.corpus.pos.data.frame$language = "Nǁng"
popoluca.corpus.pos.data.frame$language = "Texistepec"


## Add position of word in annotation unit

# Position from the beginning
baure.corpus.pos.data.frame$word_position = position.within.annotation.unit(baure.corpus.pos.data.frame)
bora.corpus.pos.data.frame$word_position = position.within.annotation.unit(bora.corpus.pos.data.frame)
chintang.corpus.pos.data.frame$word_position = position.within.annotation.unit(chintang.corpus.pos.data.frame)
dutch.corpus.pos.data.frame$word_position = position.within.annotation.unit(dutch.corpus.pos.data.frame)
english.corpus.pos.data.frame$word_position = position.within.annotation.unit(english.corpus.pos.data.frame)
even.corpus.pos.data.frame$word_position = position.within.annotation.unit(even.corpus.pos.data.frame)
hoocak.corpus.pos.data.frame$word_position = position.within.annotation.unit(hoocak.corpus.pos.data.frame)
nuu.corpus.pos.data.frame$word_position = position.within.annotation.unit(nuu.corpus.pos.data.frame)
popoluca.corpus.pos.data.frame$word_position = position.within.annotation.unit(popoluca.corpus.pos.data.frame)

# Relative position (from 0 to 1)
baure.corpus.pos.data.frame$word_position_normalized = position.within.annotation.unit.percentage(baure.corpus.pos.data.frame)
bora.corpus.pos.data.frame$word_position_normalized = position.within.annotation.unit.percentage(bora.corpus.pos.data.frame)
chintang.corpus.pos.data.frame$word_position_normalized = position.within.annotation.unit.percentage(chintang.corpus.pos.data.frame)
dutch.corpus.pos.data.frame$word_position_normalized = position.within.annotation.unit.percentage(dutch.corpus.pos.data.frame)
english.corpus.pos.data.frame$word_position_normalized = position.within.annotation.unit.percentage(english.corpus.pos.data.frame)
even.corpus.pos.data.frame$word_position_normalized = position.within.annotation.unit.percentage(even.corpus.pos.data.frame)
hoocak.corpus.pos.data.frame$word_position_normalized = position.within.annotation.unit.percentage(hoocak.corpus.pos.data.frame)
nuu.corpus.pos.data.frame$word_position_normalized = position.within.annotation.unit.percentage(nuu.corpus.pos.data.frame)
popoluca.corpus.pos.data.frame$word_position_normalized = position.within.annotation.unit.percentage(popoluca.corpus.pos.data.frame)


## Count word frequencies per language
## (Use morphological structure in order to potentially distinguish homographs)
## (Delete final punctuation marks)
baure.word.freqs = table(tolower(delete.final_punctuation(baure.corpus.pos.data.frame$whole_word_morph)))
bora.word.freqs = table(tolower(delete.final_punctuation(bora.corpus.pos.data.frame$whole_word_morph)))
chintang.word.freqs = table(tolower(delete.final_punctuation(chintang.corpus.pos.data.frame$whole_word_morph)))
dutch.word.freqs = table(tolower(delete.final_punctuation(dutch.corpus.pos.data.frame$whole_word_morph)))
english.word.freqs = table(tolower(delete.final_punctuation(english.corpus.pos.data.frame$whole_word_morph)))
even.word.freqs = table(tolower(delete.final_punctuation(even.corpus.pos.data.frame$whole_word_morph)))
hoocak.word.freqs = table(tolower(delete.final_punctuation(hoocak.corpus.pos.data.frame$whole_word_morph)))
nuu.word.freqs = table(tolower(delete.final_punctuation(nuu.corpus.pos.data.frame$whole_word_morph)))
popoluca.word.freqs = table(tolower(delete.final_punctuation(popoluca.corpus.pos.data.frame$whole_word_morph)))


## Add information about word type to all data frames
baure.corpus.pos.data.frame$word_type = tolower(delete.final_punctuation(baure.corpus.pos.data.frame$whole_word_morph))
bora.corpus.pos.data.frame$word_type = tolower(delete.final_punctuation(bora.corpus.pos.data.frame$whole_word_morph))
chintang.corpus.pos.data.frame$word_type = tolower(delete.final_punctuation(chintang.corpus.pos.data.frame$whole_word_morph))
dutch.corpus.pos.data.frame$word_type = tolower(delete.final_punctuation(dutch.corpus.pos.data.frame$whole_word_morph))
english.corpus.pos.data.frame$word_type = tolower(delete.final_punctuation(english.corpus.pos.data.frame$whole_word_morph))
even.corpus.pos.data.frame$word_type = tolower(delete.final_punctuation(even.corpus.pos.data.frame$whole_word_morph))
hoocak.corpus.pos.data.frame$word_type = tolower(delete.final_punctuation(hoocak.corpus.pos.data.frame$whole_word_morph))
nuu.corpus.pos.data.frame$word_type = tolower(delete.final_punctuation(nuu.corpus.pos.data.frame$whole_word_morph))
popoluca.corpus.pos.data.frame$word_type = tolower(delete.final_punctuation(popoluca.corpus.pos.data.frame$whole_word_morph))


## Add word frequency to each word token
baure.corpus.pos.data.frame$word_frequency = as.numeric(baure.word.freqs[baure.corpus.pos.data.frame$word_type])
bora.corpus.pos.data.frame$word_frequency = as.numeric(bora.word.freqs[bora.corpus.pos.data.frame$word_type])
chintang.corpus.pos.data.frame$word_frequency = as.numeric(chintang.word.freqs[chintang.corpus.pos.data.frame$word_type])
dutch.corpus.pos.data.frame$word_frequency = as.numeric(dutch.word.freqs[dutch.corpus.pos.data.frame$word_type])
english.corpus.pos.data.frame$word_frequency = as.numeric(english.word.freqs[english.corpus.pos.data.frame$word_type])
even.corpus.pos.data.frame$word_frequency = as.numeric(even.word.freqs[even.corpus.pos.data.frame$word_type])
hoocak.corpus.pos.data.frame$word_frequency = as.numeric(hoocak.word.freqs[hoocak.corpus.pos.data.frame$word_type])
nuu.corpus.pos.data.frame$word_frequency = as.numeric(nuu.word.freqs[nuu.corpus.pos.data.frame$word_type])
popoluca.corpus.pos.data.frame$word_frequency = as.numeric(popoluca.word.freqs[popoluca.corpus.pos.data.frame$word_type])


## Add lengths of characters to each word
## The default chars that are ignored are: ignore_chars="[])=,?!¿¡.*:;\"\'([-]"
baure.corpus.pos.data.frame$word_length_characters = count.characterlength.perword(baure.corpus.pos.data.frame, "word", ignore_chars="[])=,?!¿¡.*:;\"([-]")
bora.corpus.pos.data.frame$word_length_characters = count.characterlength.perword(bora.corpus.pos.data.frame, "word", normalize = normalize_bora, type="width")
chintang.corpus.pos.data.frame$word_length_characters = count.characterlength.perword(chintang.corpus.pos.data.frame, "word", normalize = normalize_chintang, type="width")
dutch.corpus.pos.data.frame$word_length_characters = count.characterlength.perword(dutch.corpus.pos.data.frame, "word", ignore_chars="[])=,?!¿¡.*:;\"\'([-]")
english.corpus.pos.data.frame$word_length_characters = count.characterlength.perword(english.corpus.pos.data.frame, "word", ignore_chars="[])=,?!¿¡.*:;\"\'([-]")
even.corpus.pos.data.frame$word_length_characters = count.characterlength.perword(even.corpus.pos.data.frame, "word")
hoocak.corpus.pos.data.frame$word_length_characters = count.characterlength.perword(hoocak.corpus.pos.data.frame, "word", ignore_chars="[])=,?!¿¡.*:;\"<>_([-]", type="width", normalize=normalize_hoocak)
nuu.corpus.pos.data.frame$word_length_characters = count.characterlength.perword(nuu.corpus.pos.data.frame, "word", ignore_chars="[])=,?¿¡.*:;\"([-]")
popoluca.corpus.pos.data.frame$word_length_characters = count.characterlength.perword(popoluca.corpus.pos.data.frame, "word", ignore_chars="[])=,?!¿¡.*:;\"([-]")


## Add number of morphemes to each word
baure.corpus.pos.data.frame$morphemes_in_word = count.morphemes.perword(baure.corpus.pos.data.frame, "morph")
bora.corpus.pos.data.frame$morphemes_in_word = count.morphemes.perword(bora.corpus.pos.data.frame, "morph")
chintang.corpus.pos.data.frame$morphemes_in_word = count.morphemes.perword(chintang.corpus.pos.data.frame, "morph")
# No morphological analysis for Dutch yet
dutch.corpus.pos.data.frame$morphemes_in_word = count.morphemes.perword(dutch.corpus.pos.data.frame, "morph")
english.corpus.pos.data.frame$morphemes_in_word = count.morphemes.perword(english.corpus.pos.data.frame, "morph")
even.corpus.pos.data.frame$morphemes_in_word = count.morphemes.perword(even.corpus.pos.data.frame, "morph")
hoocak.corpus.pos.data.frame$morphemes_in_word = count.morphemes.perword(hoocak.corpus.pos.data.frame, "morph")
nuu.corpus.pos.data.frame$morphemes_in_word = count.morphemes.perword(nuu.corpus.pos.data.frame, "morph")
popoluca.corpus.pos.data.frame$morphemes_in_word = count.morphemes.perword(popoluca.corpus.pos.data.frame, "morph")


## Add length of utterances (annotation units)

# Length in words
baure.corpus.pos.data.frame$words_in_utterance = length.of.annotation.units.in.words(baure.corpus.pos.data.frame)
bora.corpus.pos.data.frame$words_in_utterance = length.of.annotation.units.in.words(bora.corpus.pos.data.frame)
chintang.corpus.pos.data.frame$words_in_utterance = length.of.annotation.units.in.words(chintang.corpus.pos.data.frame)
dutch.corpus.pos.data.frame$words_in_utterance = length.of.annotation.units.in.words(dutch.corpus.pos.data.frame)
english.corpus.pos.data.frame$words_in_utterance = length.of.annotation.units.in.words(english.corpus.pos.data.frame)
even.corpus.pos.data.frame$words_in_utterance = length.of.annotation.units.in.words(even.corpus.pos.data.frame)
hoocak.corpus.pos.data.frame$words_in_utterance = length.of.annotation.units.in.words(hoocak.corpus.pos.data.frame)
nuu.corpus.pos.data.frame$words_in_utterance = length.of.annotation.units.in.words(nuu.corpus.pos.data.frame)
popoluca.corpus.pos.data.frame$words_in_utterance = length.of.annotation.units.in.words(popoluca.corpus.pos.data.frame)


## Add information about pre-word context windows

# Set target length of pre-word window
preword_window = 0.5

# Length of pre-word window in words
baure.corpus.pos.data.frame$words_in_pre_word_window = length.of.preword.window.in.words(baure.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
bora.corpus.pos.data.frame$words_in_pre_word_window = length.of.preword.window.in.words(bora.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
chintang.corpus.pos.data.frame$words_in_pre_word_window = length.of.preword.window.in.words(chintang.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
dutch.corpus.pos.data.frame$words_in_pre_word_window = length.of.preword.window.in.words(dutch.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
english.corpus.pos.data.frame$words_in_pre_word_window = length.of.preword.window.in.words(english.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
even.corpus.pos.data.frame$words_in_pre_word_window = length.of.preword.window.in.words(even.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
hoocak.corpus.pos.data.frame$words_in_pre_word_window = length.of.preword.window.in.words(hoocak.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
nuu.corpus.pos.data.frame$words_in_pre_word_window = length.of.preword.window.in.words(nuu.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
popoluca.corpus.pos.data.frame$words_in_pre_word_window = length.of.preword.window.in.words(popoluca.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)

# Length of pre-word window in characters
baure.corpus.pos.data.frame$pre_word_window_length_characters = length.of.preword.window.in.characters(baure.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
bora.corpus.pos.data.frame$pre_word_window_length_characters = length.of.preword.window.in.characters(bora.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
chintang.corpus.pos.data.frame$pre_word_window_length_characters = length.of.preword.window.in.characters(chintang.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
dutch.corpus.pos.data.frame$pre_word_window_length_characters = length.of.preword.window.in.characters(dutch.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
english.corpus.pos.data.frame$pre_word_window_length_characters = length.of.preword.window.in.characters(english.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
even.corpus.pos.data.frame$pre_word_window_length_characters = length.of.preword.window.in.characters(even.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
hoocak.corpus.pos.data.frame$pre_word_window_length_characters = length.of.preword.window.in.characters(hoocak.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
nuu.corpus.pos.data.frame$pre_word_window_length_characters = length.of.preword.window.in.characters(nuu.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
popoluca.corpus.pos.data.frame$pre_word_window_length_characters = length.of.preword.window.in.characters(popoluca.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)

# Start time of pre-word windows
baure.corpus.pos.data.frame$pre_word_window_begin = begin.of.preword.window(baure.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
bora.corpus.pos.data.frame$pre_word_window_begin = begin.of.preword.window(bora.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
chintang.corpus.pos.data.frame$pre_word_window_begin = begin.of.preword.window(chintang.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
dutch.corpus.pos.data.frame$pre_word_window_begin = begin.of.preword.window(dutch.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
english.corpus.pos.data.frame$pre_word_window_begin = begin.of.preword.window(english.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
even.corpus.pos.data.frame$pre_word_window_begin = begin.of.preword.window(even.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
hoocak.corpus.pos.data.frame$pre_word_window_begin = begin.of.preword.window(hoocak.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
nuu.corpus.pos.data.frame$pre_word_window_begin = begin.of.preword.window(nuu.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
popoluca.corpus.pos.data.frame$pre_word_window_begin = begin.of.preword.window(popoluca.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)

# Length in seconds (including pauses) of pre-word windows
baure.corpus.pos.data.frame$pre_word_window_length_seconds = length.of.preword.window.in.seconds(baure.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
bora.corpus.pos.data.frame$pre_word_window_length_seconds = length.of.preword.window.in.seconds(bora.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
chintang.corpus.pos.data.frame$pre_word_window_length_seconds = length.of.preword.window.in.seconds(chintang.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
dutch.corpus.pos.data.frame$pre_word_window_length_seconds = length.of.preword.window.in.seconds(dutch.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
english.corpus.pos.data.frame$pre_word_window_length_seconds = length.of.preword.window.in.seconds(english.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
even.corpus.pos.data.frame$pre_word_window_length_seconds = length.of.preword.window.in.seconds(even.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
hoocak.corpus.pos.data.frame$pre_word_window_length_seconds = length.of.preword.window.in.seconds(hoocak.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
nuu.corpus.pos.data.frame$pre_word_window_length_seconds = length.of.preword.window.in.seconds(nuu.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
popoluca.corpus.pos.data.frame$pre_word_window_length_seconds = length.of.preword.window.in.seconds(popoluca.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)

# Length in seconds (sum of word times = excluding pauses)
baure.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses = length.of.preword.window.from.wordtimes(baure.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
bora.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses = length.of.preword.window.from.wordtimes(bora.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
chintang.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses = length.of.preword.window.from.wordtimes(chintang.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
dutch.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses = length.of.preword.window.from.wordtimes(dutch.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
english.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses = length.of.preword.window.from.wordtimes(english.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
even.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses = length.of.preword.window.from.wordtimes(even.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
hoocak.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses = length.of.preword.window.from.wordtimes(hoocak.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
nuu.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses = length.of.preword.window.from.wordtimes(nuu.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)
popoluca.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses = length.of.preword.window.from.wordtimes(popoluca.corpus.pos.data.frame, preword_window, ignore_filled_pauses=F, ignore_false_starts=F)

# Length of pauses
baure.corpus.pos.data.frame$silent_pause_length_in_pre_word_window = baure.corpus.pos.data.frame$pre_word_window_length_seconds - baure.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
bora.corpus.pos.data.frame$silent_pause_length_in_pre_word_window = bora.corpus.pos.data.frame$pre_word_window_length_seconds - bora.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
chintang.corpus.pos.data.frame$silent_pause_length_in_pre_word_window = chintang.corpus.pos.data.frame$pre_word_window_length_seconds - chintang.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
dutch.corpus.pos.data.frame$silent_pause_length_in_pre_word_window = dutch.corpus.pos.data.frame$pre_word_window_length_seconds - dutch.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
english.corpus.pos.data.frame$silent_pause_length_in_pre_word_window = english.corpus.pos.data.frame$pre_word_window_length_seconds - english.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
even.corpus.pos.data.frame$silent_pause_length_in_pre_word_window = even.corpus.pos.data.frame$pre_word_window_length_seconds - even.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
hoocak.corpus.pos.data.frame$silent_pause_length_in_pre_word_window = hoocak.corpus.pos.data.frame$pre_word_window_length_seconds - hoocak.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
nuu.corpus.pos.data.frame$silent_pause_length_in_pre_word_window = nuu.corpus.pos.data.frame$pre_word_window_length_seconds - nuu.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
popoluca.corpus.pos.data.frame$silent_pause_length_in_pre_word_window = popoluca.corpus.pos.data.frame$pre_word_window_length_seconds - popoluca.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses

# Manual correction needed because of floating point problems!
english.corpus.pos.data.frame$silent_pause_length_in_pre_word_window[english.corpus.pos.data.frame$word_id=="36017"]
# [1] 5.551115e-17
english.corpus.pos.data.frame$silent_pause_length_in_pre_word_window[english.corpus.pos.data.frame$word_id=="36017"] = 0

# Relative length of pauses
baure.corpus.pos.data.frame$silent_pause_length_in_pre_word_window_percentage = baure.corpus.pos.data.frame$silent_pause_length_in_pre_word_window * 100 / baure.corpus.pos.data.frame$pre_word_window_length_seconds
bora.corpus.pos.data.frame$silent_pause_length_in_pre_word_window_percentage = bora.corpus.pos.data.frame$silent_pause_length_in_pre_word_window * 100 / bora.corpus.pos.data.frame$pre_word_window_length_seconds
chintang.corpus.pos.data.frame$silent_pause_length_in_pre_word_window_percentage = chintang.corpus.pos.data.frame$silent_pause_length_in_pre_word_window * 100 / chintang.corpus.pos.data.frame$pre_word_window_length_seconds
dutch.corpus.pos.data.frame$silent_pause_length_in_pre_word_window_percentage = dutch.corpus.pos.data.frame$silent_pause_length_in_pre_word_window * 100 / dutch.corpus.pos.data.frame$pre_word_window_length_seconds
english.corpus.pos.data.frame$silent_pause_length_in_pre_word_window_percentage = english.corpus.pos.data.frame$silent_pause_length_in_pre_word_window * 100 / english.corpus.pos.data.frame$pre_word_window_length_seconds
even.corpus.pos.data.frame$silent_pause_length_in_pre_word_window_percentage = even.corpus.pos.data.frame$silent_pause_length_in_pre_word_window * 100 / even.corpus.pos.data.frame$pre_word_window_length_seconds
hoocak.corpus.pos.data.frame$silent_pause_length_in_pre_word_window_percentage = hoocak.corpus.pos.data.frame$silent_pause_length_in_pre_word_window * 100 / hoocak.corpus.pos.data.frame$pre_word_window_length_seconds
nuu.corpus.pos.data.frame$silent_pause_length_in_pre_word_window_percentage = nuu.corpus.pos.data.frame$silent_pause_length_in_pre_word_window * 100 / nuu.corpus.pos.data.frame$pre_word_window_length_seconds
popoluca.corpus.pos.data.frame$silent_pause_length_in_pre_word_window_percentage = popoluca.corpus.pos.data.frame$silent_pause_length_in_pre_word_window * 100 / popoluca.corpus.pos.data.frame$pre_word_window_length_seconds

# Pause factor with threshold (of 150 ms)
baure.corpus.pos.data.frame$silent_pause_in_pre_word_window_factor = factor(ifelse(baure.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15, "yes", "no"),levels=c("no","yes"))
bora.corpus.pos.data.frame$silent_pause_in_pre_word_window_factor = factor(ifelse(bora.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15, "yes", "no"),levels=c("no","yes"))
chintang.corpus.pos.data.frame$silent_pause_in_pre_word_window_factor = factor(ifelse(chintang.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15, "yes", "no"),levels=c("no","yes"))
dutch.corpus.pos.data.frame$silent_pause_in_pre_word_window_factor = factor(ifelse(dutch.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15, "yes", "no"),levels=c("no","yes"))
english.corpus.pos.data.frame$silent_pause_in_pre_word_window_factor = factor(ifelse(english.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15, "yes", "no"),levels=c("no","yes"))
even.corpus.pos.data.frame$silent_pause_in_pre_word_window_factor = factor(ifelse(even.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15, "yes", "no"),levels=c("no","yes"))
hoocak.corpus.pos.data.frame$silent_pause_in_pre_word_window_factor = factor(ifelse(hoocak.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15, "yes", "no"),levels=c("no","yes"))
nuu.corpus.pos.data.frame$silent_pause_in_pre_word_window_factor = factor(ifelse(nuu.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15, "yes", "no"),levels=c("no","yes"))
popoluca.corpus.pos.data.frame$silent_pause_in_pre_word_window_factor = factor(ifelse(popoluca.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15, "yes", "no"),levels=c("no","yes"))

# Number of filled pauses
baure.corpus.pos.data.frame$filled_pauses_in_pre_word_window = filled.pauses.per.preword.window(baure.corpus.pos.data.frame, preword_window)
bora.corpus.pos.data.frame$filled_pauses_in_pre_word_window = filled.pauses.per.preword.window(bora.corpus.pos.data.frame, preword_window)
chintang.corpus.pos.data.frame$filled_pauses_in_pre_word_window = filled.pauses.per.preword.window(chintang.corpus.pos.data.frame, preword_window)
dutch.corpus.pos.data.frame$filled_pauses_in_pre_word_window = filled.pauses.per.preword.window(dutch.corpus.pos.data.frame, preword_window)
english.corpus.pos.data.frame$filled_pauses_in_pre_word_window = filled.pauses.per.preword.window(english.corpus.pos.data.frame, preword_window)
even.corpus.pos.data.frame$filled_pauses_in_pre_word_window = filled.pauses.per.preword.window(even.corpus.pos.data.frame, preword_window)
hoocak.corpus.pos.data.frame$filled_pauses_in_pre_word_window = filled.pauses.per.preword.window(hoocak.corpus.pos.data.frame, preword_window)
nuu.corpus.pos.data.frame$filled_pauses_in_pre_word_window = filled.pauses.per.preword.window(nuu.corpus.pos.data.frame, preword_window)
popoluca.corpus.pos.data.frame$filled_pauses_in_pre_word_window = filled.pauses.per.preword.window(popoluca.corpus.pos.data.frame, preword_window)

# Filled pauses factor
baure.corpus.pos.data.frame$filled_pause_in_pre_word_window_factor = factor(ifelse(baure.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
bora.corpus.pos.data.frame$filled_pause_in_pre_word_window_factor = factor(ifelse(bora.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
chintang.corpus.pos.data.frame$filled_pause_in_pre_word_window_factor = factor(ifelse(chintang.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
dutch.corpus.pos.data.frame$filled_pause_in_pre_word_window_factor = factor(ifelse(dutch.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
english.corpus.pos.data.frame$filled_pause_in_pre_word_window_factor = factor(ifelse(english.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
even.corpus.pos.data.frame$filled_pause_in_pre_word_window_factor = factor(ifelse(even.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
hoocak.corpus.pos.data.frame$filled_pause_in_pre_word_window_factor = factor(ifelse(hoocak.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
nuu.corpus.pos.data.frame$filled_pause_in_pre_word_window_factor = factor(ifelse(nuu.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
popoluca.corpus.pos.data.frame$filled_pause_in_pre_word_window_factor = factor(ifelse(popoluca.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))

# Pause factor (filled pause or silent pause with threshold of 150 ms)
baure.corpus.pos.data.frame$pause_in_pre_word_window_factor = factor(ifelse(baure.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15 | baure.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
bora.corpus.pos.data.frame$pause_in_pre_word_window_factor = factor(ifelse(bora.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15 | bora.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
chintang.corpus.pos.data.frame$pause_in_pre_word_window_factor = factor(ifelse(chintang.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15 | chintang.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
dutch.corpus.pos.data.frame$pause_in_pre_word_window_factor = factor(ifelse(dutch.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15 | dutch.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
english.corpus.pos.data.frame$pause_in_pre_word_window_factor = factor(ifelse(english.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15 | english.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
even.corpus.pos.data.frame$pause_in_pre_word_window_factor = factor(ifelse(even.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15 | even.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
hoocak.corpus.pos.data.frame$pause_in_pre_word_window_factor = factor(ifelse(hoocak.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15 | hoocak.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
nuu.corpus.pos.data.frame$pause_in_pre_word_window_factor = factor(ifelse(nuu.corpus.pos.data.frame$silent_pause_length_in_pre_word_window >= 0.15 | nuu.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
popoluca.corpus.pos.data.frame$pause_in_pre_word_window_factor = factor(ifelse(popoluca.corpus.pos.data.frame$silent_pause_length_in_pre_word_window>= 0.15 | popoluca.corpus.pos.data.frame$filled_pauses_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))

# Number of false starts
baure.corpus.pos.data.frame$false_starts_in_pre_word_window = false.starts.per.preword.window(baure.corpus.pos.data.frame, preword_window)
bora.corpus.pos.data.frame$false_starts_in_pre_word_window = false.starts.per.preword.window(bora.corpus.pos.data.frame, preword_window)
chintang.corpus.pos.data.frame$false_starts_in_pre_word_window = false.starts.per.preword.window(chintang.corpus.pos.data.frame, preword_window)
dutch.corpus.pos.data.frame$false_starts_in_pre_word_window = false.starts.per.preword.window(dutch.corpus.pos.data.frame, preword_window)
english.corpus.pos.data.frame$false_starts_in_pre_word_window = false.starts.per.preword.window(english.corpus.pos.data.frame, preword_window)
even.corpus.pos.data.frame$false_starts_in_pre_word_window = false.starts.per.preword.window(even.corpus.pos.data.frame, preword_window)
hoocak.corpus.pos.data.frame$false_starts_in_pre_word_window = false.starts.per.preword.window(hoocak.corpus.pos.data.frame, preword_window)
nuu.corpus.pos.data.frame$false_starts_in_pre_word_window = false.starts.per.preword.window(nuu.corpus.pos.data.frame, preword_window)
popoluca.corpus.pos.data.frame$false_starts_in_pre_word_window = false.starts.per.preword.window(popoluca.corpus.pos.data.frame, preword_window)

# False start factor
baure.corpus.pos.data.frame$false_start_in_pre_word_window_factor = factor(ifelse(baure.corpus.pos.data.frame$false_starts_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
bora.corpus.pos.data.frame$false_start_in_pre_word_window_factor = factor(ifelse(bora.corpus.pos.data.frame$false_starts_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
chintang.corpus.pos.data.frame$false_start_in_pre_word_window_factor = factor(ifelse(chintang.corpus.pos.data.frame$false_starts_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
dutch.corpus.pos.data.frame$false_start_in_pre_word_window_factor = factor(ifelse(dutch.corpus.pos.data.frame$false_starts_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
english.corpus.pos.data.frame$false_start_in_pre_word_window_factor = factor(ifelse(english.corpus.pos.data.frame$false_starts_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
even.corpus.pos.data.frame$false_start_in_pre_word_window_factor = factor(ifelse(even.corpus.pos.data.frame$false_starts_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
hoocak.corpus.pos.data.frame$false_start_in_pre_word_window_factor = factor(ifelse(hoocak.corpus.pos.data.frame$false_starts_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
nuu.corpus.pos.data.frame$false_start_in_pre_word_window_factor = factor(ifelse(nuu.corpus.pos.data.frame$false_starts_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))
popoluca.corpus.pos.data.frame$false_start_in_pre_word_window_factor = factor(ifelse(popoluca.corpus.pos.data.frame$false_starts_in_pre_word_window > 0, "yes", "no"),levels=c("no","yes"))

# Check if a preword window contains an empty word (0 characters)
baure.corpus.pos.data.frame$empty_word_in_prewindow = check.preword.window.for.empty.words(baure.corpus.pos.data.frame, preword_window)
bora.corpus.pos.data.frame$empty_word_in_prewindow = check.preword.window.for.empty.words(bora.corpus.pos.data.frame, preword_window, additional_pattern="xx+")
chintang.corpus.pos.data.frame$empty_word_in_prewindow = check.preword.window.for.empty.words(chintang.corpus.pos.data.frame, preword_window)
dutch.corpus.pos.data.frame$empty_word_in_prewindow = check.preword.window.for.empty.words(dutch.corpus.pos.data.frame, preword_window, additional_pattern="xx+")
english.corpus.pos.data.frame$empty_word_in_prewindow = check.preword.window.for.empty.words(english.corpus.pos.data.frame, preword_window)
even.corpus.pos.data.frame$empty_word_in_prewindow = check.preword.window.for.empty.words(even.corpus.pos.data.frame, preword_window, additional_pattern="(xx+|XX+|\\[|\\])")
hoocak.corpus.pos.data.frame$empty_word_in_prewindow = check.preword.window.for.empty.words(hoocak.corpus.pos.data.frame, preword_window)
nuu.corpus.pos.data.frame$empty_word_in_prewindow = check.preword.window.for.empty.words(nuu.corpus.pos.data.frame, preword_window)
popoluca.corpus.pos.data.frame$empty_word_in_prewindow = check.preword.window.for.empty.words(popoluca.corpus.pos.data.frame, preword_window)

# Calculate articulation_rate of prewindow - without pauses
baure.corpus.pos.data.frame$pre_word_window_articulation_rate = baure.corpus.pos.data.frame$pre_word_window_length_characters / baure.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
bora.corpus.pos.data.frame$pre_word_window_articulation_rate = bora.corpus.pos.data.frame$pre_word_window_length_characters / bora.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
chintang.corpus.pos.data.frame$pre_word_window_articulation_rate = chintang.corpus.pos.data.frame$pre_word_window_length_characters / chintang.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
dutch.corpus.pos.data.frame$pre_word_window_articulation_rate = dutch.corpus.pos.data.frame$pre_word_window_length_characters / dutch.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
english.corpus.pos.data.frame$pre_word_window_articulation_rate = english.corpus.pos.data.frame$pre_word_window_length_characters / english.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
even.corpus.pos.data.frame$pre_word_window_articulation_rate = even.corpus.pos.data.frame$pre_word_window_length_characters / even.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
hoocak.corpus.pos.data.frame$pre_word_window_articulation_rate = hoocak.corpus.pos.data.frame$pre_word_window_length_characters / hoocak.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
nuu.corpus.pos.data.frame$pre_word_window_articulation_rate = nuu.corpus.pos.data.frame$pre_word_window_length_characters / nuu.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
popoluca.corpus.pos.data.frame$pre_word_window_articulation_rate = popoluca.corpus.pos.data.frame$pre_word_window_length_characters / popoluca.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses
sakha.corpus.pos.data.frame$pre_word_window_articulation_rate = sakha.corpus.pos.data.frame$pre_word_window_length_characters / sakha.corpus.pos.data.frame$pre_word_window_length_seconds_no_pauses


## Annotate code-switching

baure.corpus.pos.data.frame$code_switching = calculate.code.switching.per.annotation.unit(baure.corpus.pos.data.frame, "lg", c("-spa","?spa","eng","spa","spa-","spa?","spn"))
chintang.corpus.pos.data.frame$code_switching = calculate.code.switching.per.annotation.unit(chintang.corpus.pos.data.frame, "lg", c("-N","E","N","N-","N/E"))
hoocak.corpus.pos.data.frame$code_switching = calculate.code.switching.per.annotation.unit(hoocak.corpus.pos.data.frame, "ps", c("ENGLISH"))
nuu.corpus.pos.data.frame$code_switching = calculate.code.switching.per.annotation.unit(nuu.corpus.pos.data.frame, "lg", c("-A","A","A-","E"))

# No significant code-switching in the other languages


### Combine data frames of all languages into one

## Add missing columns to some subcorpora
baure.corpus.pos.data.frame$id = NA
baure.corpus.pos.data.frame$whole_word_id = NA

bora.corpus.pos.data.frame$id = NA
bora.corpus.pos.data.frame$whole_word_id = NA
bora.corpus.pos.data.frame$lg = NA
bora.corpus.pos.data.frame$whole_word_lg = NA
bora.corpus.pos.data.frame$code_switching = 0

dutch.corpus.pos.data.frame$id = NA
dutch.corpus.pos.data.frame$whole_word_id = NA
dutch.corpus.pos.data.frame$lg = NA
dutch.corpus.pos.data.frame$whole_word_lg = NA
dutch.corpus.pos.data.frame$code_switching = 0
dutch.corpus.pos.data.frame$root = NA
dutch.corpus.pos.data.frame$mt = NA
dutch.corpus.pos.data.frame$whole_word_mt = NA

english.corpus.pos.data.frame$id = NA
english.corpus.pos.data.frame$whole_word_id = NA
english.corpus.pos.data.frame$lg = NA
english.corpus.pos.data.frame$whole_word_lg = NA
english.corpus.pos.data.frame$code_switching = 0

even.corpus.pos.data.frame$id = NA
even.corpus.pos.data.frame$whole_word_id = NA
even.corpus.pos.data.frame$whole_word_lg = NA
even.corpus.pos.data.frame$code_switching = 0

hoocak.corpus.pos.data.frame$lg = NA
hoocak.corpus.pos.data.frame$whole_word_lg = NA
hoocak.corpus.pos.data.frame$id = NA
hoocak.corpus.pos.data.frame$whole_word_id = NA

popoluca.corpus.pos.data.frame$id = NA
popoluca.corpus.pos.data.frame$whole_word_id = NA
popoluca.corpus.pos.data.frame$lg = NA
popoluca.corpus.pos.data.frame$whole_word_lg = NA
popoluca.corpus.pos.data.frame$code_switching = 0


## Make speakers unique by prefixing with the language ISO-code
baure.corpus.pos.data.frame$speaker = paste(baure.corpus.pos.data.frame$language_iso_code,baure.corpus.pos.data.frame$speaker,sep=" ")
bora.corpus.pos.data.frame$speaker = paste(bora.corpus.pos.data.frame$language_iso_code,bora.corpus.pos.data.frame$speaker,sep=" ")
chintang.corpus.pos.data.frame$speaker = paste(chintang.corpus.pos.data.frame$language_iso_code,chintang.corpus.pos.data.frame$speaker,sep=" ")
dutch.corpus.pos.data.frame$speaker = paste(dutch.corpus.pos.data.frame$language_iso_code,dutch.corpus.pos.data.frame$speaker,sep=" ")
english.corpus.pos.data.frame$speaker = paste(english.corpus.pos.data.frame$language_iso_code,english.corpus.pos.data.frame$speaker,sep=" ")
even.corpus.pos.data.frame$speaker = paste(even.corpus.pos.data.frame$language_iso_code,even.corpus.pos.data.frame$speaker,sep=" ")
hoocak.corpus.pos.data.frame$speaker = paste(hoocak.corpus.pos.data.frame$language_iso_code,hoocak.corpus.pos.data.frame$speaker,sep=" ")
nuu.corpus.pos.data.frame$speaker = paste(nuu.corpus.pos.data.frame$language_iso_code,nuu.corpus.pos.data.frame$speaker,sep=" ")
popoluca.corpus.pos.data.frame$speaker = paste(popoluca.corpus.pos.data.frame$language_iso_code,popoluca.corpus.pos.data.frame$speaker,sep=" ")


## Make texts (recording sessions) unique by prefixing with the language ISO-code
baure.corpus.pos.data.frame$text = paste(baure.corpus.pos.data.frame$language_iso_code,baure.corpus.pos.data.frame$text,sep=" ")
bora.corpus.pos.data.frame$text = paste(bora.corpus.pos.data.frame$language_iso_code,bora.corpus.pos.data.frame$text,sep=" ")
chintang.corpus.pos.data.frame$text = paste(chintang.corpus.pos.data.frame$language_iso_code,chintang.corpus.pos.data.frame$text,sep=" ")
dutch.corpus.pos.data.frame$text = paste(dutch.corpus.pos.data.frame$language_iso_code,dutch.corpus.pos.data.frame$text,sep=" ")
english.corpus.pos.data.frame$text = paste(english.corpus.pos.data.frame$language_iso_code,english.corpus.pos.data.frame$text,sep=" ")
even.corpus.pos.data.frame$text = paste(even.corpus.pos.data.frame$language_iso_code,even.corpus.pos.data.frame$text,sep=" ")
hoocak.corpus.pos.data.frame$text = paste(hoocak.corpus.pos.data.frame$language_iso_code,hoocak.corpus.pos.data.frame$text,sep=" ")
nuu.corpus.pos.data.frame$text = paste(nuu.corpus.pos.data.frame$language_iso_code,nuu.corpus.pos.data.frame$text,sep=" ")
popoluca.corpus.pos.data.frame$text = paste(popoluca.corpus.pos.data.frame$language_iso_code,popoluca.corpus.pos.data.frame$text,sep=" ")


## Make utterance_id, word_id, morpheme_id unique by adding the maximal value from the previous subcorpus to the following subcorpus
bora.corpus.pos.data.frame$word_id = bora.corpus.pos.data.frame$word_id + max(na.omit(baure.corpus.pos.data.frame$word_id))
bora.corpus.pos.data.frame$utterance_id = bora.corpus.pos.data.frame$utterance_id + max(na.omit(baure.corpus.pos.data.frame$utterance_id))
bora.corpus.pos.data.frame$morpheme_id = bora.corpus.pos.data.frame$morpheme_id + max(na.omit(baure.corpus.pos.data.frame$morpheme_id))

chintang.corpus.pos.data.frame$word_id = chintang.corpus.pos.data.frame$word_id + max(na.omit(bora.corpus.pos.data.frame$word_id))
chintang.corpus.pos.data.frame$utterance_id = chintang.corpus.pos.data.frame$utterance_id + max(na.omit(bora.corpus.pos.data.frame$utterance_id))
chintang.corpus.pos.data.frame$morpheme_id = chintang.corpus.pos.data.frame$morpheme_id + max(na.omit(bora.corpus.pos.data.frame$morpheme_id))

dutch.corpus.pos.data.frame$word_id = dutch.corpus.pos.data.frame$word_id + max(na.omit(chintang.corpus.pos.data.frame$word_id))
dutch.corpus.pos.data.frame$utterance_id = dutch.corpus.pos.data.frame$utterance_id + max(na.omit(chintang.corpus.pos.data.frame$utterance_id))
dutch.corpus.pos.data.frame$morpheme_id = dutch.corpus.pos.data.frame$morpheme_id + max(na.omit(chintang.corpus.pos.data.frame$morpheme_id))

english.corpus.pos.data.frame$word_id = english.corpus.pos.data.frame$word_id + max(na.omit(dutch.corpus.pos.data.frame$word_id))
english.corpus.pos.data.frame$utterance_id = english.corpus.pos.data.frame$utterance_id + max(na.omit(dutch.corpus.pos.data.frame$utterance_id))
english.corpus.pos.data.frame$morpheme_id = english.corpus.pos.data.frame$morpheme_id + max(na.omit(dutch.corpus.pos.data.frame$morpheme_id))

even.corpus.pos.data.frame$word_id = even.corpus.pos.data.frame$word_id + max(na.omit(english.corpus.pos.data.frame$word_id))
even.corpus.pos.data.frame$utterance_id = even.corpus.pos.data.frame$utterance_id + max(na.omit(english.corpus.pos.data.frame$utterance_id))
even.corpus.pos.data.frame$morpheme_id = even.corpus.pos.data.frame$morpheme_id + max(na.omit(english.corpus.pos.data.frame$morpheme_id))

hoocak.corpus.pos.data.frame$word_id = hoocak.corpus.pos.data.frame$word_id + max(na.omit(even.corpus.pos.data.frame$word_id))
hoocak.corpus.pos.data.frame$utterance_id = hoocak.corpus.pos.data.frame$utterance_id + max(na.omit(even.corpus.pos.data.frame$utterance_id))
hoocak.corpus.pos.data.frame$morpheme_id = hoocak.corpus.pos.data.frame$morpheme_id + max(na.omit(even.corpus.pos.data.frame$morpheme_id))

nuu.corpus.pos.data.frame$word_id = nuu.corpus.pos.data.frame$word_id + max(na.omit(hoocak.corpus.pos.data.frame$word_id))
nuu.corpus.pos.data.frame$utterance_id = nuu.corpus.pos.data.frame$utterance_id + max(na.omit(hoocak.corpus.pos.data.frame$utterance_id))
nuu.corpus.pos.data.frame$morpheme_id = nuu.corpus.pos.data.frame$morpheme_id + max(na.omit(hoocak.corpus.pos.data.frame$morpheme_id))

popoluca.corpus.pos.data.frame$word_id = popoluca.corpus.pos.data.frame$word_id + max(na.omit(nuu.corpus.pos.data.frame$word_id))
popoluca.corpus.pos.data.frame$utterance_id = popoluca.corpus.pos.data.frame$utterance_id + max(na.omit(nuu.corpus.pos.data.frame$utterance_id))
popoluca.corpus.pos.data.frame$morpheme_id = popoluca.corpus.pos.data.frame$morpheme_id + max(na.omit(nuu.corpus.pos.data.frame$morpheme_id))


### Exclude data

## Baure

length(unique(baure.corpus.pos.data.frame$word_id))
# [1] 29772

# Exclude researchers
table(baure.corpus.pos.data.frame$speaker)
#
#      AD      AM      CL      CS      DC      FS      FX      GP      HC      II       L      LO      MC      PO      RP       S      SD
#    2178     213       6     455   11054      66       4     974    1137     627     323     342     495      11   24332    7100     176
# unknown
#    3253

# S=Swintha, SD=Swintha (?) and L=Lena
baure.corpus.pos.data.frame.excluded = subset(baure.corpus.pos.data.frame,subset=baure.corpus.pos.data.frame$speaker!="L" & baure.corpus.pos.data.frame$speaker!="S" & baure.corpus.pos.data.frame$speaker!="SD")

length(unique(baure.corpus.pos.data.frame.excluded$word_id))
# [1] 24472

# Code Switching
# Exclude annotation units with more than 50% Spanish words
baure.corpus.pos.data.frame.excluded = subset(baure.corpus.pos.data.frame.excluded,subset=baure.corpus.pos.data.frame.excluded$code_switching <= 0.5)

length(unique(baure.corpus.pos.data.frame.excluded$word_id))
# [1] 22657

# Exclude certain sessions (elicitations, semi-speakers, etc.), following Swintha Danielsen's suggestions
baure.exclude.always = c("DC-081105S.txt", "DC-P081201L.tbt", "HC-D120509S-2.tbt", "HC-D120514S.tbt", "HC-P030913S-3.txt", "II-P081210L.txt", "MD-120507S-1.tbt", "MD-N030824S-1.txt", "MD-N081128LF.tbt", "MD-N081213L.tbt", "MD-P081112L.tbt", "MD-P081117L.tbt", "MD-P081127L-2.tbt", "MD-P081211LF.tbt", "RP-101206S-1.tbt", "RP-110901S-4.tbt", "RP-N081212LF.tbt", "RP-P081126L.tbt", "RP-P030819S-1.txt")

baure.corpus.pos.data.frame.excluded = subset(baure.corpus.pos.data.frame.excluded,subset=!baure.corpus.pos.data.frame.excluded$text %in% baure.exclude.always)

length(unique(baure.corpus.pos.data.frame.excluded$word_id))
# [1] 19281

# Exclude songs etc.
unique(baure.corpus.pos.data.frame$text[baure.corpus.pos.data.frame$plannedness=="0" | is.na(baure.corpus.pos.data.frame$plannedness)])
#  [1] "DC-081105S.txt"    "DC-S090914S-1.tbt" "DC-S090914S-2.txt" "DC-S090914S-3.txt" "JP-S040709S-2.tbt" "JP-S040709S-4.tbt" "JP-S040709S-5.tbt" "JP-S040709S-6.tbt" "JP-S040709S-7.tbt"
# [10] "RP-101206S-1.tbt"  "RP-S081126L-1.tbt" "RP-S081126L-2.tbt"
  
baure.corpus.pos.data.frame.excluded = subset(baure.corpus.pos.data.frame.excluded,subset=!baure.corpus.pos.data.frame.excluded$text %in% unique(baure.corpus.pos.data.frame$text[baure.corpus.pos.data.frame$plannedness=="0" | is.na(baure.corpus.pos.data.frame$plannedness)]))

length(unique(baure.corpus.pos.data.frame.excluded$word_id))
# [1] 19105

# Blacklist for incorrect annotation units (for example, with incomplete transcription)
baure.annotation_unit.blacklist = c("brg_AD-090807S_0105", "brg_AD-090807S_0277", "brg_AD_DC-C060401S_0030", "brg_AD_DC-C060401S_0035",
"brg_AD_DC-C060401S_0040", "brg_AD_DC-C060401S_0060", "brg_AD_DC-C060401S_0066", "brg_AD_DC-C060401S_0068", "brg_AD_DC-C060401S_0146",
"brg_AD_DC-C060401S_0148", "brg_AD_DC-C060401S_0155", "brg_AD_DC-C060401S_0168", "brg_AD_DC-C060401S_0231", "brg_AD_DC-C060401S_0281",
"brg_DC-C081111SL_0035", "brg_DC-C081111SL_0671", "brg_RP-N040721S_0038", "brg_RP-N040721S_0191", "brg_RP-N040721S_0201",
"brg_RP-P090810S_0025")

baure.corpus.pos.data.frame.excluded = subset(baure.corpus.pos.data.frame.excluded,subset=!baure.corpus.pos.data.frame.excluded$ntvr_ref %in% baure.annotation_unit.blacklist)

length(unique(baure.corpus.pos.data.frame.excluded$word_id))
# [1] 19067

# Exclude empty annotation units
baure.corpus.pos.data.frame.excluded = subset(baure.corpus.pos.data.frame.excluded,subset=!baure.corpus.pos.data.frame.excluded$ntvr_ref %in% baure.corpus.pos.data.frame.excluded$ntvr_ref[baure.corpus.pos.data.frame.excluded$words_in_utterance == 0])

length(unique(baure.corpus.pos.data.frame.excluded$word_id))
# [1] 19066

# Omit records without morphological annotation
baure.corpus.pos.data.frame.excluded = subset(baure.corpus.pos.data.frame.excluded,subset=!baure.corpus.pos.data.frame.excluded$ntvr_ref %in% baure.corpus.pos.data.frame.excluded$ntvr_ref[is.na(baure.corpus.pos.data.frame.excluded$morpheme_id)])

length(unique(baure.corpus.pos.data.frame.excluded$word_id))
# [1] 19066

# Exclude further sessions of low quality from the analysis of word times following Swintha Danielsen's suggestion
baure.exclude.timeseries = unique(baure.corpus.pos.data.frame.excluded$text[baure.corpus.pos.data.frame.excluded$plannedness=="0" | is.na(baure.corpus.pos.data.frame.excluded$plannedness)])
baure.exclude.timeseries
character(0)

baure.exclude.timeseries = c(baure.exclude.timeseries, "DC-P090914S-4.tbt", "RP-P081120L.tbt", "SIL3-N.txt")
baure.exclude.timeseries
# [1] "DC-P090914S-4.tbt" "RP-P081120L.tbt"   "SIL3-N.txt"       

baure.corpus.pos.data.frame.wordtimes = subset(baure.corpus.pos.data.frame.excluded,subset=!baure.corpus.pos.data.frame.excluded$text %in% baure.exclude.timeseries)

length(unique(baure.corpus.pos.data.frame.wordtimes$word_id))
# [1] 17652

# Omit words with empty or unclear words in the preceding context for pre-word-window-based study
baure.corpus.pos.data.frame.wordtimes.prewindows = subset(baure.corpus.pos.data.frame.wordtimes,subset=!baure.corpus.pos.data.frame.wordtimes$word_id %in% as.vector(na.omit(baure.corpus.pos.data.frame.wordtimes$word_id[baure.corpus.pos.data.frame.wordtimes$empty_word_in_prewindow==TRUE])))

length(unique(baure.corpus.pos.data.frame.wordtimes.prewindows$word_id))
# [1] 17652


## Bora

length(unique(bora.corpus.pos.data.frame$word_id))
# [1] 30141

# Exclude researchers (FS?)
table(bora.corpus.pos.data.frame$speaker)
#
#  AAR      AC      AF      AL     ALF      AM      AP     ARR     CAP     CAV      CP     DRS     ELP      EP      ES     ESI     FEB      FS     GPE     HIC     INE       J      JN
#  233    7995      22      33     422     114    4713      91    2707      41     131      19      23       2     173      11      18      38      54      63      29      28      24
#   JP      JR     JUM     JUN     LBP     LIR     LUR     MAM      MM     MVP      OL     OLO      RA      RO     ROR      RR     RUF     RYP     SEC      SV unknown       V     VIR
# 1193      39   13400      42      23      27       3      22   20456       5     165      31     672     147    1393     200     290      19      40     173    8745    2293     264
#  YOS
#    7

# Exclude FS=Frank Seifart
bora.corpus.pos.data.frame.excluded = subset(bora.corpus.pos.data.frame,subset=bora.corpus.pos.data.frame$speaker!="FS")

length(unique(bora.corpus.pos.data.frame.excluded$word_id))
# [1] 30119

# Exclude songs etc.
unique(bora.corpus.pos.data.frame$text[bora.corpus.pos.data.frame$plannedness=="0" | is.na(bora.corpus.pos.data.frame$plannedness)])
character(0)

bora.exclude.timeseries = c()

bora.corpus.pos.data.frame.excluded = subset(bora.corpus.pos.data.frame.excluded, subset=!bora.corpus.pos.data.frame.excluded$text %in% bora.exclude.timeseries)

length(unique(bora.corpus.pos.data.frame.excluded$word_id))
# [1] 30119

# Remove song parts embedded in other texts / recording sessions
bora.corpus.pos.data.frame.excluded = subset(bora.corpus.pos.data.frame.excluded, subset=!(bora.corpus.pos.data.frame.excluded$text=="llijchu_ine_I.txt" & bora.corpus.pos.data.frame.excluded$orig_ref %in% c("219","549","554")))

length(unique(bora.corpus.pos.data.frame.excluded$word_id))
# [1] 30112

bora.corpus.pos.data.frame.excluded = subset(bora.corpus.pos.data.frame.excluded, subset=!(bora.corpus.pos.data.frame.excluded$text=="niivuwa.txt" & bora.corpus.pos.data.frame.excluded$orig_ref %in% c("004","033","042")))

length(unique(bora.corpus.pos.data.frame.excluded$word_id))
# [1] 30084

bora.corpus.pos.data.frame.excluded = subset(bora.corpus.pos.data.frame.excluded, subset=!(bora.corpus.pos.data.frame.excluded$text=="piivyeebe_ajyu.txt" & bora.corpus.pos.data.frame.excluded$orig_ref %in% c("188")))

length(unique(bora.corpus.pos.data.frame.excluded$word_id))
# [1] 30072

bora.corpus.pos.data.frame.excluded = subset(bora.corpus.pos.data.frame.excluded, subset=!(bora.corpus.pos.data.frame.excluded$text=="taava_meewa.txt" & bora.corpus.pos.data.frame.excluded$orig_ref %in% c("094","115")))

length(unique(bora.corpus.pos.data.frame.excluded$word_id))
# [1] 30054

bora.corpus.pos.data.frame.excluded = subset(bora.corpus.pos.data.frame.excluded, subset=!(bora.corpus.pos.data.frame.excluded$text=="vuurihii.txt" & bora.corpus.pos.data.frame.excluded$orig_ref %in% c("117")))

length(unique(bora.corpus.pos.data.frame.excluded$word_id))
# [1] 30049

bora.corpus.pos.data.frame.excluded = subset(bora.corpus.pos.data.frame.excluded, subset=!(bora.corpus.pos.data.frame.excluded$text=="warEhko_mEE.txt" & bora.corpus.pos.data.frame.excluded$orig_ref %in% c("112")))

length(unique(bora.corpus.pos.data.frame.excluded$word_id))
# [1] 30034

bora.corpus.pos.data.frame.excluded = subset(bora.corpus.pos.data.frame.excluded, subset=!(bora.corpus.pos.data.frame.excluded$text=="wakyu_cant_1.txt" & bora.corpus.pos.data.frame.excluded$orig_ref %in% c("16","17","18","19","20","21","22","23","24","25","26")))

length(unique(bora.corpus.pos.data.frame.excluded$word_id))
# [1] 29997

# Exclude incompletely or incorrectly transcribed annotation units
bora.annotation_unit.blacklist = c("boa_llijchu_ine_I_0056", "boa_llijchu_ine_I_0057", "boa_llijchu_ine_I_0060", "boa_llijchu_ine_I_0281", "boa_llijchu_ine_I_0294", "boa_meenujkatsi_0072")

bora.corpus.pos.data.frame.excluded = subset(bora.corpus.pos.data.frame.excluded,subset=!bora.corpus.pos.data.frame.excluded$ntvr_ref %in% bora.annotation_unit.blacklist)

length(unique(bora.corpus.pos.data.frame.excluded$word_id))
# [1] 29941

# Exclude empty annotation units
bora.corpus.pos.data.frame.excluded = subset(bora.corpus.pos.data.frame.excluded,subset=!bora.corpus.pos.data.frame.excluded$ntvr_ref %in% bora.corpus.pos.data.frame.excluded$ntvr_ref[bora.corpus.pos.data.frame.excluded$words_in_utterance == 0])

length(unique(bora.corpus.pos.data.frame.excluded$word_id))
# [1] 29940

# Omit records without morphological annotation (one recording session was only partly annotated)
bora.corpus.pos.data.frame.excluded$ntvr_ref[is.na(bora.corpus.pos.data.frame.excluded$morpheme_id)]

bora.corpus.pos.data.frame.excluded = subset(bora.corpus.pos.data.frame.excluded,subset=!bora.corpus.pos.data.frame.excluded$ntvr_ref %in% bora.corpus.pos.data.frame.excluded$ntvr_ref[is.na(bora.corpus.pos.data.frame.excluded$morpheme_id)])

length(unique(bora.corpus.pos.data.frame.excluded$word_id))
# [1] 29802

bora.corpus.pos.data.frame.wordtimes = bora.corpus.pos.data.frame.excluded

# Omit words with empty or unclear words in the preceding context for pre-word-window-based study
bora.corpus.pos.data.frame.wordtimes.prewindows = subset(bora.corpus.pos.data.frame.wordtimes,subset=!bora.corpus.pos.data.frame.wordtimes$word_id %in% as.vector(na.omit(bora.corpus.pos.data.frame.wordtimes$word_id[bora.corpus.pos.data.frame.wordtimes$empty_word_in_prewindow==TRUE])))

length(unique(bora.corpus.pos.data.frame.wordtimes.prewindows$word_id))
# [1] 29802


## Chintang

length(unique(chintang.corpus.pos.data.frame$word_id))
# [1] 47869

# Exclude researchers
table(chintang.corpus.pos.data.frame$speaker)
#
#  AbinasR                 AWR                 BBR                 BBS                  BH                 BhB               BIRKU                 BJR                 CAK
#       21                 116                5869                 261                  97                1339                1117                2008                  13
#      CBR              child1              child2                  CK             comment                 DBR                 DDR                 DHY                 DKR
#     1122                  15                   5                1355                  82                 662                2233                6805                  19
#       DR                 DRR                 DSR DurgaDevi Rai (DVR)                 DVR                 GAR                 GIT                 GPR                 GUM
#      546                 778                 555                   6                2932                 804                 459                1144                1109
#      HBH                 JBS                 JBT                  JK                Junu                 KRM                 KSR                  LK                 Lok
#      201                 443                3730                1325                   3                2111                   8                1281                2058
#      LTR             Mal ser              Malser                  MG                 MKU                MOKR                 MOR                 MYR                NARR
#     3501                 541                 462                  10                2803                 221                1424                 615                1787
#    Nisha                  NP                PCMR                 PPK                  PR                 PRB                PUDR                PUMR             Rajemma
#      730                  47                 432                1167                  13                  14                 492                 120                 819
#      RAP                 RBK                RCHR                 RDR                  RM                 ROS          Sanchamaya                SHAM                 SMR
#      140                1188                 744                4080                3427                 296                 645                  16                  18
#       SR                 SRW                 SUK                 SWR                  TD                 UMR             unknown             UNKNOWN            unknown1
#     1209                 331                  70                8724                 256                1784                  37                  54                 240
# UNKNOWN1            unknown2            UNKNOWN2            unknown3            unknown4            unknown5            unknown6            unknown7            unknown8
#       63                 245                  22                  64                  30                   5                   7                  15                  20
#      VKR                 YRP
#     1280                   6

# Exclude MG=Martin Gaenszle
chintang.corpus.pos.data.frame.excluded = subset(chintang.corpus.pos.data.frame,subset=chintang.corpus.pos.data.frame$speaker!="MG")

length(unique(chintang.corpus.pos.data.frame.excluded$word_id))
# [1] 47860

# Code switching
# Exclude annotation units with more than 50% Nepali or English words
chintang.corpus.pos.data.frame.excluded = subset(chintang.corpus.pos.data.frame.excluded,subset=chintang.corpus.pos.data.frame.excluded$code_switching <= 0.5)

length(unique(chintang.corpus.pos.data.frame.excluded$word_id))
# [1] 42695

# Ritual language and songs
chintang.exclude.always = c("bhale_song.txt","Burhahang_01.txt","celi_azik_01.txt","comolung_song.txt","ctn_song_RM01.txt","hutlung_1.txt","kholamang.txt","pani_panca.txt","rajdeo_02.txt","rajdeu_wal01.txt","sudhar_cuwa.txt","sudhar_daijo.txt","sudhar_pakuwa.txt","sudhar_palawa.txt","tupla_phema_1.txt")

unique(chintang.corpus.pos.data.frame$text[chintang.corpus.pos.data.frame$plannedness=="0" | is.na(chintang.corpus.pos.data.frame$plannedness)])
#  [1] "bhale_song.txt"    "Burhahang_01.txt"  "celi_azik_01.txt"  "comolung_song.txt" "ctn_song_RM01.txt" "hutlung_1.txt"     "kholamang.txt"     "pani_panca.txt"    "rajdeo_02.txt"
# [10] "rajdeu_wal01.txt"  "sudhar_cuwa.txt"   "sudhar_daijo.txt"  "sudhar_pakuwa.txt" "sudhar_palawa.txt" "tupla_phema_1.txt"

chintang.corpus.pos.data.frame.excluded = subset(chintang.corpus.pos.data.frame.excluded,subset=!chintang.corpus.pos.data.frame.excluded$text %in% chintang.exclude.always)

length(unique(chintang.corpus.pos.data.frame.excluded$word_id))
# [1] 37825

# Exclude incorrectly or incompletely transcribed annotation units
chintang.annotation_unit.blacklist = c("ctn_pear_8-2_0417","ctn_pear_11-1_0118")

chintang.corpus.pos.data.frame.excluded = subset(chintang.corpus.pos.data.frame.excluded,subset=!chintang.corpus.pos.data.frame.excluded$ntvr_ref %in% chintang.annotation_unit.blacklist)

length(unique(chintang.corpus.pos.data.frame.excluded$word_id))
# [1] 37818

# Exclude empty annotation units
chintang.corpus.pos.data.frame.excluded = subset(chintang.corpus.pos.data.frame.excluded,subset=!chintang.corpus.pos.data.frame.excluded$ntvr_ref %in% chintang.corpus.pos.data.frame.excluded$ntvr_ref[chintang.corpus.pos.data.frame.excluded$words_in_utterance == 0])

length(unique(chintang.corpus.pos.data.frame.excluded$word_id))
# [1] 37817

# Omit records without morphological annotation
chintang.corpus.pos.data.frame.excluded = subset(chintang.corpus.pos.data.frame.excluded,subset=!chintang.corpus.pos.data.frame.excluded$ntvr_ref %in% chintang.corpus.pos.data.frame.excluded$ntvr_ref[is.na(chintang.corpus.pos.data.frame.excluded$morpheme_id)])

length(unique(chintang.corpus.pos.data.frame.excluded$word_id))
# [1] 37737

chintang.corpus.pos.data.frame.wordtimes = chintang.corpus.pos.data.frame.excluded

length(unique(chintang.corpus.pos.data.frame.wordtimes$word_id))
# [1] 37737

# Omit words with empty or unclear words in the preceding context for pre-word-window-based study
chintang.corpus.pos.data.frame.wordtimes.prewindows = subset(chintang.corpus.pos.data.frame.wordtimes,subset=!chintang.corpus.pos.data.frame.wordtimes$word_id %in% as.vector(na.omit(chintang.corpus.pos.data.frame.wordtimes$word_id[chintang.corpus.pos.data.frame.wordtimes$empty_word_in_prewindow==TRUE])))

length(unique(chintang.corpus.pos.data.frame.wordtimes.prewindows$word_id))
# [1] 37737


## Dutch

length(unique(dutch.corpus.pos.data.frame$word_id))
# [1] 39720

dutch.corpus.pos.data.frame.excluded = dutch.corpus.pos.data.frame

length(unique(dutch.corpus.pos.data.frame.excluded$word_id))
# [1] 39720

dutch.corpus.pos.data.frame.wordtimes = dutch.corpus.pos.data.frame.excluded

length(unique(dutch.corpus.pos.data.frame.wordtimes$word_id))
# [1] 39720

# Omit words with empty or unclear words in the preceding context for pre-word-window-based study
dutch.corpus.pos.data.frame.wordtimes.prewindows = subset(dutch.corpus.pos.data.frame.wordtimes,subset=!dutch.corpus.pos.data.frame.wordtimes$word_id %in% as.vector(na.omit(dutch.corpus.pos.data.frame.wordtimes$word_id[dutch.corpus.pos.data.frame.wordtimes$empty_word_in_prewindow==TRUE])))

length(unique(dutch.corpus.pos.data.frame.wordtimes.prewindows$word_id))
# [1] 39519


## English

length(unique(english.corpus.pos.data.frame$word_id))
# [1] 56138

english.corpus.pos.data.frame.excluded = english.corpus.pos.data.frame

length(unique(english.corpus.pos.data.frame.excluded$word_id))
# [1] 56138

english.corpus.pos.data.frame.wordtimes = english.corpus.pos.data.frame.excluded

length(unique(english.corpus.pos.data.frame.wordtimes$word_id))
# [1] 56138

# Omit words with empty or unclear words in the preceding context for pre-word-window-based study
english.corpus.pos.data.frame.wordtimes.prewindows = subset(english.corpus.pos.data.frame.wordtimes,subset=!english.corpus.pos.data.frame.wordtimes$word_id %in% as.vector(na.omit(english.corpus.pos.data.frame.wordtimes$word_id[english.corpus.pos.data.frame.wordtimes$empty_word_in_prewindow==TRUE])))

length(unique(english.corpus.pos.data.frame.wordtimes.prewindows$word_id))
# [1] 56135


## Even

length(unique(even.corpus.pos.data.frame$word_id))
# [1] 41701

# Exclude researchers
table(even.corpus.pos.data.frame$speaker)
#
#  AAK         AAS         AEK         AEN         AVK         AVZ         AXK          BP    children     comment          EE         EKK         IDB         INK         IVK
# 1865        1250        1209         922        1315        1664        6364        1884           2         147          68         658        2729         442        4886
#  JPZ         KKK         KNK         LAT         LNZ          MK         MKK          MN          NA         NAS         NEN         NPZ     NPZ IVK NPZ IVK LNZ          OS
#  346        4068         154        3623          36         291        2351         572         330        2780          13         102           3         296         670
#  PDN         RDA          rh         SEN          SK         SPK         TDA         TPK         TVK         VAK         VNZ         XAK         ZAS          ZZ
# 4515       13447          81        1166        1352        1442           6        1777        1845          23        1134        1224        8378         345

# Exclude BP=Brigitte Pakendorf, NA=Natalia Aralova, rh=reindeer herders, EE=only Russian, XAK, and comment
even.corpus.pos.data.frame.excluded = subset(even.corpus.pos.data.frame,subset=!even.corpus.pos.data.frame$speaker %in% c("BP","NA","rh","EE","XAK","comment","children"))

length(unique(even.corpus.pos.data.frame.excluded$word_id))
# [1] 38972

# Exclude code-switching
table(even.corpus.pos.data.frame$lg)
      
# 77775

even.corpus.pos.data.frame.excluded = subset(even.corpus.pos.data.frame.excluded,subset=even.corpus.pos.data.frame.excluded$lg=="")

length(unique(even.corpus.pos.data.frame.excluded$word_id))
# [1] 38972

# Songs and semi-speaker
even.exclude.always = ... # Information removed for anonymization purposes

even.corpus.pos.data.frame.excluded = subset(even.corpus.pos.data.frame.excluded,subset=!even.corpus.pos.data.frame.excluded$text %in% even.exclude.always)

length(unique(even.corpus.pos.data.frame.excluded$word_id))
# [1] 37775

# Exclude empty annotation units
even.corpus.pos.data.frame.excluded = subset(even.corpus.pos.data.frame.excluded,subset=!even.corpus.pos.data.frame.excluded$ntvr_ref %in% even.corpus.pos.data.frame.excluded$ntvr_ref[even.corpus.pos.data.frame.excluded$words_in_utterance == 0])

length(unique(even.corpus.pos.data.frame.excluded$word_id))
# [1] 37775

# Omit records without morphological annotation
even.corpus.pos.data.frame.excluded = subset(even.corpus.pos.data.frame.excluded,subset=!even.corpus.pos.data.frame.excluded$ntvr_ref %in% even.corpus.pos.data.frame.excluded$ntvr_ref[is.na(even.corpus.pos.data.frame.excluded$morpheme_id)])

length(unique(even.corpus.pos.data.frame.excluded$word_id))
# [1] 37517

even.corpus.pos.data.frame.wordtimes = even.corpus.pos.data.frame.excluded

length(unique(even.corpus.pos.data.frame.wordtimes$word_id))
# [1] 37517

# Omit words with empty or unclear words in the preceding context for pre-word-window-based study
even.corpus.pos.data.frame.wordtimes.prewindows = subset(even.corpus.pos.data.frame.wordtimes,subset=!even.corpus.pos.data.frame.wordtimes$word_id %in% as.vector(na.omit(even.corpus.pos.data.frame.wordtimes$word_id[even.corpus.pos.data.frame.wordtimes$empty_word_in_prewindow==TRUE])))

length(unique(even.corpus.pos.data.frame.wordtimes.prewindows$word_id))
# [1] 37430


## Hoocąk

length(unique(hoocak.corpus.pos.data.frame$word_id))
# [1] 23420

# Exclude researchers
table(hoocak.corpus.pos.data.frame$speaker)
    #
    # FS12      FS5      FS6      FS7      FS9     FS99       IH      MS1     MS10     MS12     MS13     MS15     MS19      MS2     MS23     MS27     MS28     MS30     MS31     MS32
    #  439     5060      275      337      465      682        3     1681      423     1297      168       65      834      583     1595     1071     1059     3113     2078     8189
    #  MS4      MS7     MS98     MS99 UNKNOWN1 UNKNOWN2 UNKNOWN3 UNKNOWN4 UNKNOWN5 UNKNOWN6 UNKNOWN7
    # 1939     2621     2955     2084        4       14       11     2020      310        3        9

# Exclude IH=Iren Hartmann
hoocak.corpus.pos.data.frame.excluded = subset(hoocak.corpus.pos.data.frame,subset=!hoocak.corpus.pos.data.frame$speaker %in% c("IH"))

length(unique(hoocak.corpus.pos.data.frame.excluded$word_id))
# [1] 23417

# Code-Switching
# Exclude annotation units with more than 50% English words
hoocak.corpus.pos.data.frame.excluded = subset(hoocak.corpus.pos.data.frame.excluded,subset=hoocak.corpus.pos.data.frame.excluded$code_switching <= 0.5)

length(unique(hoocak.corpus.pos.data.frame.excluded$word_id))
# [1] 23281

# Exclude ritual language and songs
hoocak.exclude.always = unique(hoocak.corpus.pos.data.frame.excluded$text[hoocak.corpus.pos.data.frame.excluded$plannedness=="0" | is.na(hoocak.corpus.pos.data.frame.excluded$plannedness)])
hoocak.exclude.always
# [1] "Saved_By_Grace.txt"

hoocak.corpus.pos.data.frame.excluded = subset(hoocak.corpus.pos.data.frame.excluded,subset=!hoocak.corpus.pos.data.frame.excluded$text %in% hoocak.exclude.always)

length(unique(hoocak.corpus.pos.data.frame.excluded$word_id))
# [1] 23198

# Exclude incorrectly or incompletely transcribed annotation units
hoocak.annotation_unit.blacklist = c("win_caa_worak_0029", "win_gilbert_0017", "win_giving_directions_0059")

hoocak.corpus.pos.data.frame.excluded = subset(hoocak.corpus.pos.data.frame.excluded,subset=!hoocak.corpus.pos.data.frame.excluded$ntvr_ref %in% hoocak.annotation_unit.blacklist)

length(unique(hoocak.corpus.pos.data.frame.excluded$word_id))
# [1] 23195

# Exclude empty annotation units
hoocak.corpus.pos.data.frame.excluded$ntvr_ref[hoocak.corpus.pos.data.frame.excluded$words_in_utterance == 0]
character(0)

hoocak.corpus.pos.data.frame.excluded = subset(hoocak.corpus.pos.data.frame.excluded,subset=!hoocak.corpus.pos.data.frame.excluded$ntvr_ref %in% hoocak.corpus.pos.data.frame.excluded$ntvr_ref[hoocak.corpus.pos.data.frame.excluded$words_in_utterance == 0])

length(unique(hoocak.corpus.pos.data.frame.excluded$word_id))
# [1] 23195

# Omit records without morphological annotation
hoocak.corpus.pos.data.frame.excluded = subset(hoocak.corpus.pos.data.frame.excluded,subset=!hoocak.corpus.pos.data.frame.excluded$ntvr_ref %in% hoocak.corpus.pos.data.frame.excluded$ntvr_ref[is.na(hoocak.corpus.pos.data.frame.excluded$morpheme_id)])

length(unique(hoocak.corpus.pos.data.frame.excluded$word_id))
# [1] 23195

# Omit words with empty or unclear words in the preceding context for pre-word-window-based study
hoocak.corpus.pos.data.frame.wordtimes.prewindows = subset(hoocak.corpus.pos.data.frame.wordtimes,subset=!hoocak.corpus.pos.data.frame.wordtimes$word_id %in% as.vector(na.omit(hoocak.corpus.pos.data.frame.wordtimes$word_id[hoocak.corpus.pos.data.frame.wordtimes$empty_word_in_prewindow==TRUE])))

length(unique(hoocak.corpus.pos.data.frame.wordtimes.prewindows$word_id))
# [1] 23191


## Nǁng

length(unique(nuu.corpus.pos.data.frame$word_id))
# [1] 31760

# Exclude researchers ER, GU, SI, visitor, WI
table(nuu.corpus.pos.data.frame$speaker)
      #
      # ?       B       C       D       E      ER       F       G      GU       I      NA      SI visitor      WI
      # 8   12783    7057     581    3516     310    3631    5623      47    2169      43      22       1       6

# Also exclude ? and NA according to e-mail from Alena Witzlack-Makarevich (18.06.2014)
nuu.corpus.pos.data.frame.excluded = subset(nuu.corpus.pos.data.frame,subset=!nuu.corpus.pos.data.frame$speaker %in% c("ER","GU","SI","visitor","WI","?","NA"))

length(unique(nuu.corpus.pos.data.frame.excluded$word_id))
# [1] 31352

# Code-Switching
# Exclude annotation units with more than 50% Afrikaans or English words
nuu.corpus.pos.data.frame.excluded = subset(nuu.corpus.pos.data.frame.excluded,subset=nuu.corpus.pos.data.frame.excluded$code_switching <= 0.5)

length(unique(nuu.corpus.pos.data.frame.excluded$word_id))
# [1] 26730

# No songs or ritual speech
unique(nuu.corpus.pos.data.frame.excluded$text[nuu.corpus.pos.data.frame.excluded$plannedness=="0" | is.na(nuu.corpus.pos.data.frame.excluded$plannedness)])
character(0)

# Exclude incorrectly or incompletely transcribed annotation units
nuu.annotation_unit.blacklist = c("ngh_NC080903-01_A_0355", "ngh_NM071109-01_A_till_270_0174")

nuu.corpus.pos.data.frame.excluded = subset(nuu.corpus.pos.data.frame.excluded, subset=!nuu.corpus.pos.data.frame.excluded$ntvr_ref %in% nuu.annotation_unit.blacklist)

length(unique(nuu.corpus.pos.data.frame.excluded$word_id))
# [1] 26727

# Omit empty annotation units
nuu.corpus.pos.data.frame.excluded$ntvr_ref[nuu.corpus.pos.data.frame.excluded$words_in_utterance == 0]
character(0)

nuu.corpus.pos.data.frame.excluded = subset(nuu.corpus.pos.data.frame.excluded,subset=!nuu.corpus.pos.data.frame.excluded$ntvr_ref %in% nuu.corpus.pos.data.frame.excluded$ntvr_ref[nuu.corpus.pos.data.frame.excluded$words_in_utterance == 0])

length(unique(nuu.corpus.pos.data.frame.excluded$word_id))
# [1] 26727

# Omit records without morphological annotation
nuu.corpus.pos.data.frame.excluded$ntvr_ref[is.na(nuu.corpus.pos.data.frame.excluded$morpheme_id)]
character(0)

nuu.corpus.pos.data.frame.excluded = subset(nuu.corpus.pos.data.frame.excluded,subset=!nuu.corpus.pos.data.frame.excluded$ntvr_ref %in% nuu.corpus.pos.data.frame.excluded$ntvr_ref[is.na(nuu.corpus.pos.data.frame.excluded$morpheme_id)])

length(unique(nuu.corpus.pos.data.frame.excluded$word_id))
# [1] 26727

nuu.corpus.pos.data.frame.wordtimes = nuu.corpus.pos.data.frame.excluded

length(unique(nuu.corpus.pos.data.frame.wordtimes$word_id))
# [1] 26727

# Omit words with empty or unclear words in the preceding context for pre-word-window-based study
nuu.corpus.pos.data.frame.wordtimes.prewindows = subset(nuu.corpus.pos.data.frame.wordtimes,subset=!nuu.corpus.pos.data.frame.wordtimes$word_id %in% as.vector(na.omit(nuu.corpus.pos.data.frame.wordtimes$word_id[nuu.corpus.pos.data.frame.wordtimes$empty_word_in_prewindow==TRUE])))

length(unique(nuu.corpus.pos.data.frame.wordtimes.prewindows$word_id))
# [1] 26061


## Texistepec Popoluca

length(unique(popoluca.corpus.pos.data.frame$word_id))
# [1] 24811

# Exclude researchers
table(popoluca.corpus.pos.data.frame$speaker)
#
#   SP1
# 46629

# No information about code-switching contained in corpus, relatively rare

# No songs or ritual speech

# Blacklist for incorrectly or incompletely transcribed annotation units
popoluca.annotation_unit.blacklist = c("Blancaflor 043", "Blancaflor 143", "Blancaflor 160", "Blancaflor 193", "Blancaflor 218", "Blancaflor 361",
"Blancaflor 427", "Blancaflor 506", "Blancaflor 549", "Blancaflor 583", "Blancaflor 593", "Blancaflor 615",
"Blancaflor 616", "Blancaflor 694", "Blancaflor 715", "Blancaflor 732", "Blancaflor 771",
"Blancaflor 802", "Blancaflor 819", "Blancaflor 871", "Blancaflor 881", "Blancaflor 922", "Blancaflor 931",
"Blancaflor 996", "Blancaflor 997", "Blancaflor 998", "Blancaflor 999", "Blancaflor 1 000",
"Blancaflor 1 001", "Blancaflor 1 027", "Blancaflor 1 061", "Blancaflor 1 068", "Blancaflor 1 071", "Blancaflor 1 074", "Blancaflor 1 109",
"Blancaflor 1 119", "Blancaflor 1 166", "Blancaflor 1 174", "Blancaflor 1 184", "Blancaflor 1 185",
"Blancaflor 1 187", "Blancaflor 1 188", "Blancaflor 1 219", "Blancaflor 1 229", "Blancaflor 1 231",
"Juan Flojo 000", "Juan Flojo 1 205", "Juan Flojo 1 206", "Juan Flojo 1 207", "Juan Flojo 1 208", "Juan Flojo 1 209",
"Juan Flojo 1 210", "Juan Flojo 1 211", "Juan Flojo 1 212", "Juan Flojo 1 213", "Jesus 000", "Juan Ratoncito 000", "Chichimeca 000",
"Muchacha Floja 000", "Pepito 000", "Pepito 001", "Pepito 003", "Pepito 014")

popoluca.corpus.pos.data.frame.excluded = subset(popoluca.corpus.pos.data.frame,subset=!popoluca.corpus.pos.data.frame$orig_ref %in% popoluca.annotation_unit.blacklist)

length(unique(popoluca.corpus.pos.data.frame.excluded$word_id))
# [1] 24526

# Omit empty records
popoluca.corpus.pos.data.frame.excluded = subset(popoluca.corpus.pos.data.frame.excluded,subset=!popoluca.corpus.pos.data.frame.excluded$ntvr_ref %in% popoluca.corpus.pos.data.frame.excluded$ntvr_ref[popoluca.corpus.pos.data.frame.excluded$words_in_utterance == 0])

length(unique(popoluca.corpus.pos.data.frame.excluded$word_id))
# [1] 24526

# Omit records without morphological annotation
popoluca.corpus.pos.data.frame.excluded = subset(popoluca.corpus.pos.data.frame.excluded,subset=!popoluca.corpus.pos.data.frame.excluded$ntvr_ref %in% popoluca.corpus.pos.data.frame.excluded$ntvr_ref[is.na(popoluca.corpus.pos.data.frame.excluded$morpheme_id)])

length(unique(popoluca.corpus.pos.data.frame.excluded$word_id))
# [1] 24526

# Throw out sessions without wordtimes (recordings were not available)
popoluca.exclude.timeseries = c("JesusQuevedo.txt","LosGatos.txt","NicolasitoyNicolason.txt")

popoluca.corpus.pos.data.frame.wordtimes = subset(popoluca.corpus.pos.data.frame.excluded,subset=!popoluca.corpus.pos.data.frame.excluded$text %in% popoluca.exclude.timeseries)

length(unique(popoluca.corpus.pos.data.frame.wordtimes$word_id))
# [1] 21321

# Omit words with empty or unclear words in the preceding context for pre-word-window-based study
popoluca.corpus.pos.data.frame.wordtimes.prewindows = subset(popoluca.corpus.pos.data.frame.wordtimes,subset=!popoluca.corpus.pos.data.frame.wordtimes$word_id %in% as.vector(na.omit(popoluca.corpus.pos.data.frame.wordtimes$word_id[popoluca.corpus.pos.data.frame.wordtimes$empty_word_in_prewindow==TRUE])))

length(unique(popoluca.corpus.pos.data.frame.wordtimes.prewindows$word_id))
# [1] 21321


### Corpus statistics of part actually used in study of pre-word context windows

## Number of sessions
length(unique(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$text)))
# [1] 37

length(unique(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$text)))
# [1] 37

length(unique(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$text)))
# [1] 40

length(unique(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$text)))
# [1] 17

length(unique(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$text)))
# [1] 47

length(unique(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$text)))
# [1] 67

length(unique(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$text)))
# [1] 62

length(unique(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$text)))
# [1] 33

length(unique(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$text)))
# [1] 6


## Number of speakers
length(unique(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$speaker)))
# [1] 12

length(unique(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$speaker)))
# [1] 46

length(unique(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$speaker)))
# [1] 74

length(unique(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$speaker)))
# [1] 42

length(unique(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$speaker)))
# [1] 80

length(unique(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$speaker)))
# [1] 32

length(unique(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$speaker)))
# [1] 28

length(unique(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$speaker)))
# [1] 7

length(unique(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$speaker)))
# [1] 1


## Number of pre-word windows
length(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(baure.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 13309

length(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(bora.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 25823

length(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(chintang.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 28711

length(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(dutch.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 33697

length(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(english.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 49194

length(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(even.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 32591

length(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(hoocak.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 20255

length(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(nuu.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 18071

length(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(popoluca.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 15860


## Number of utterances (annotation units / records)
length(unique(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 4343

length(unique(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 3979

length(unique(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 9026

length(unique(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 5822

length(unique(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 6941

length(unique(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 4839

length(unique(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 2936

length(unique(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 7990

length(unique(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 5461


## Pre-word windows per utterance (annotation unit / record)
length(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(baure.corpus.pos.data.frame.wordtimes.prewindows$word_id)])) / length(unique(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 3.064472

length(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(bora.corpus.pos.data.frame.wordtimes.prewindows$word_id)])) / length(unique(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 6.489822

length(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(chintang.corpus.pos.data.frame.wordtimes.prewindows$word_id)])) / length(unique(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 3.180922

length(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(dutch.corpus.pos.data.frame.wordtimes.prewindows$word_id)])) / length(unique(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 5.787874

length(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(english.corpus.pos.data.frame.wordtimes.prewindows$word_id)])) / length(unique(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 7.087451

length(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(even.corpus.pos.data.frame.wordtimes.prewindows$word_id)])) / length(unique(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 6.735069

length(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(hoocak.corpus.pos.data.frame.wordtimes.prewindows$word_id)])) / length(unique(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 6.898842

length(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(nuu.corpus.pos.data.frame.wordtimes.prewindows$word_id)])) / length(unique(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 2.261702

length(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$pre_word_window_begin[!duplicated(popoluca.corpus.pos.data.frame.wordtimes.prewindows$word_id)])) / length(unique(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 2.90423


## Number of words
length(unique(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 17652

length(unique(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 29802

length(unique(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 37737

length(unique(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 39519

length(unique(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 56135

length(unique(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 37430

length(unique(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 23191

length(unique(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 26061

length(unique(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 21321


## Number of morphemes
length(unique(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id)))
# [1] 33116

length(unique(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id)))
# [1] 66049

length(unique(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id)))
# [1] 68501

length(unique(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id)))
# [1] 39519

length(unique(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id)))
# [1] 61560

length(unique(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id)))
# [1] 71268

length(unique(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id)))
# [1] 41045
 
length(unique(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id)))
# [1] 29530
 
length(unique(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id)))
# [1] 39688
 

## Morphemes per word
length(unique(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id))) / length(unique(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 1.876048

length(unique(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id))) / length(unique(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 2.216261

length(unique(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id))) / length(unique(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 1.815221

# Artifact of lack of morphological analysis
length(unique(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id))) / length(unique(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 1

length(unique(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id))) / length(unique(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 1.096642

length(unique(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id))) / length(unique(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 1.904034

length(unique(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id))) / length(unique(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 1.769868

length(unique(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id))) / length(unique(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 1.133111

length(unique(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$morpheme_id))) / length(unique(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$word_id)))
# [1] 1.861451


## Words per utterance (annotation unit / record)
length(unique(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$word_id))) / length(unique(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 4.064472

length(unique(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$word_id))) / length(unique(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 7.489822

length(unique(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$word_id))) / length(unique(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 4.180922

length(unique(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$word_id))) / length(unique(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 6.787874

length(unique(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$word_id))) / length(unique(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 8.087451

length(unique(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$word_id))) / length(unique(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 7.735069

length(unique(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$word_id))) / length(unique(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 7.898842

length(unique(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$word_id))) / length(unique(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 3.261702

length(unique(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$word_id))) / length(unique(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$ntvr_ref)))
# [1] 3.90423


## Words per pre-word window
mean(na.omit(baure.corpus.pos.data.frame.wordtimes.prewindows$words_in_pre_word_window[!duplicated(baure.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 1.124427

mean(na.omit(bora.corpus.pos.data.frame.wordtimes.prewindows$words_in_pre_word_window[!duplicated(bora.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 0.9455137

mean(na.omit(chintang.corpus.pos.data.frame.wordtimes.prewindows$words_in_pre_word_window[!duplicated(chintang.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 1.375048

mean(na.omit(dutch.corpus.pos.data.frame.wordtimes.prewindows$words_in_pre_word_window[!duplicated(dutch.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 2.190937

mean(na.omit(english.corpus.pos.data.frame.wordtimes.prewindows$words_in_pre_word_window[!duplicated(english.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 2.039029

mean(na.omit(even.corpus.pos.data.frame.wordtimes.prewindows$words_in_pre_word_window[!duplicated(even.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 0.9482066

mean(na.omit(hoocak.corpus.pos.data.frame.wordtimes.prewindows$words_in_pre_word_window[!duplicated(hoocak.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 0.7764009

mean(na.omit(nuu.corpus.pos.data.frame.wordtimes.prewindows$words_in_pre_word_window[!duplicated(nuu.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 1.639754

mean(na.omit(popoluca.corpus.pos.data.frame.wordtimes.prewindows$words_in_pre_word_window[!duplicated(popoluca.corpus.pos.data.frame.wordtimes.prewindows$word_id)]))
# [1] 1.427932


### Combine data frame for word times - pre-word windows

common.columns.wordtimes.prewindows = c("language","language_iso_code","text","speaker","utterance_id","utterance_start_time",
"utterance_end_time","words_in_utterance","word_id","word_start_time","word_end_time","word_mid_point","word_length_seconds",
"disfluency","word_class_all","whole_word_word_class_all","word_position","word_position_normalized","word_type","word_frequency", "word_length_characters",
"morphemes_in_word","pre_word_window_begin","pre_word_window_length_seconds","pre_word_window_length_seconds_no_pauses",
"words_in_pre_word_window","silent_pause_length_in_pre_word_window","silent_pause_in_pre_word_window_factor",
"filled_pauses_in_pre_word_window","filled_pause_in_pre_word_window_factor","false_starts_in_pre_word_window",
"false_start_in_pre_word_window_factor","pause_in_pre_word_window_factor","pre_word_window_length_characters",
"pre_word_window_articulation_rate")

## Combine columns into new data frame
combined.wordtimes.prewindows.publish = rbind(baure.corpus.pos.data.frame.wordtimes.prewindows[,common.columns.wordtimes.prewindows],
bora.corpus.pos.data.frame.wordtimes.prewindows[,common.columns.wordtimes.prewindows],
chintang.corpus.pos.data.frame.wordtimes.prewindows[,common.columns.wordtimes.prewindows],
dutch.corpus.pos.data.frame.wordtimes.prewindows[,common.columns.wordtimes.prewindows],
english.corpus.pos.data.frame.wordtimes.prewindows[,common.columns.wordtimes.prewindows],
even.corpus.pos.data.frame.wordtimes.prewindows[,common.columns.wordtimes.prewindows],
hoocak.corpus.pos.data.frame.wordtimes.prewindows[,common.columns.wordtimes.prewindows],
nuu.corpus.pos.data.frame.wordtimes.prewindows[,common.columns.wordtimes.prewindows],
popoluca.corpus.pos.data.frame.wordtimes.prewindows[,common.columns.wordtimes.prewindows])

## Convert variable types
combined.wordtimes.prewindows.publish$language_iso_code = as.factor(combined.wordtimes.prewindows.publish$language_iso_code)
combined.wordtimes.prewindows.publish$language = as.factor(combined.wordtimes.prewindows.publish$language)
combined.wordtimes.prewindows.publish$text = as.factor(combined.wordtimes.prewindows.publish$text)
combined.wordtimes.prewindows.publish$utterance_start_time = as.numeric(combined.wordtimes.prewindows.publish$utterance_start_time)
combined.wordtimes.prewindows.publish$utterance_end_time = as.numeric(combined.wordtimes.prewindows.publish$utterance_end_time)
combined.wordtimes.prewindows.publish$speaker = as.factor(combined.wordtimes.prewindows.publish$speaker)
combined.wordtimes.prewindows.publish$disfluency = as.factor(combined.wordtimes.prewindows.publish$disfluency)
combined.wordtimes.prewindows.publish$word_class_all = as.factor(combined.wordtimes.prewindows.publish$word_class_all)
combined.wordtimes.prewindows.publish$word_type = as.factor(combined.wordtimes.prewindows.publish$word_type)


## Create a simplified version of word class for the pre-word window analysis

table(combined.wordtimes.prewindows.publish$word_class_all)
#
#      -    -AFFIX   -AFFIX-      -BPN      -BPP        -N    -OTHER   -OTHER-      -PRO -subj_agr        -V       ***         =
#   3178    117660        49     19513      3683        39       302       165        12       163         6       363       103
# =AFFIX      =AUX      =BPN    =OTHER      =PRO     AFFIX    AFFIX- AMBIGUOUS       AUX       BPN      BPN-      BPN=      BPP-
#   1443       840      1882      3808       412         7      5901        87      4392      1125     12076      4979      3178
#  FLDPS         N        N-     OTHER    OTHER-       PRO      PRO-   UNKNOWN  UNKNOWN-         V        V-     V-BPN
#   2247     56064         1    140854         1     38042         4        32         1     74990        81      4962

combined.wordtimes.prewindows.publish$word_class_relevant = as.character(combined.wordtimes.prewindows.publish$word_class_all)
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="-"] = NA
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="-AFFIX"] = NA
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="-AFFIX-"] = NA
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="-BPN"] = "BPN"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="BPP"] = "BPP"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="BPP-"] = "BPP"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="-BPP"] = "BPP"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="-N"] = "N"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="-OTHER"] = "OTHER"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="-OTHER-"] = "OTHER"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="-PRO"] = "PRO"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="-subj_agr"] = NA
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="-V"] = "V"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="***"] = "FLDPS"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="-"] = NA
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="="] = NA
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="=AFFIX"] = NA
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="=AUX"] = "AUX"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="=BPN"] = "BPN"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="=OTHER"] = "OTHER"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="=PRO"] = "PRO"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="AFFIX"] = NA
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="AFFIX-"] = NA
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="AMBIGUOUS"] = "OTHER"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="AUX"] = "AUX"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="BPN"] = "BPN"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="BPN-"] = "BPN"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="BPN="] = "BPN"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="FLDPS"] = "FLDPS"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="N"] = "N"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="N-"] = "N"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="OTHER"] = "OTHER"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="OTHER-"] = "OTHER"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="PRO"] = "PRO"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="PRO-"] = "PRO"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="UNKNOWN"] = "OTHER"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="UNKNOWN-"] = "OTHER"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="V"] = "V"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="V-"] = "V"
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$word_class_relevant=="V-BPN"] = "V"

# Restore the category auxiliary (AUX) for English
combined.wordtimes.prewindows.publish$word_class_relevant[combined.wordtimes.prewindows.publish$language_iso_code=="eng" & combined.wordtimes.prewindows.publish$ntvr_ps_word=="AUX"] = "AUX"

table(combined.wordtimes.prewindows.publish$word_class_relevant)
#
#  AUX    BPN    BPP  FLDPS      N  OTHER    PRO      V
# 7106  39575   6861   2607  56104 145248  38470  78170

# Combine AUX and OTHER for main analysis
combined.wordtimes.prewindows.publish$word_class_relevant_no_aux = combined.wordtimes.prewindows.publish$word_class_relevant
combined.wordtimes.prewindows.publish$word_class_relevant_no_aux[combined.wordtimes.prewindows.publish$word_class_relevant_no_aux=="AUX"] = "OTHER"

# Combine AUX and V for alternative analysis
combined.wordtimes.prewindows.publish$word_class_relevant_aux = combined.wordtimes.prewindows.publish$word_class_relevant
combined.wordtimes.prewindows.publish$word_class_relevant_aux[combined.wordtimes.prewindows.publish$word_class_relevant_aux=="AUX"] = "V"

# Convert to factors
combined.wordtimes.prewindows.publish$word_class_relevant = as.factor(combined.wordtimes.prewindows.publish$word_class_relevant)
combined.wordtimes.prewindows.publish$word_class_relevant_aux = as.factor(combined.wordtimes.prewindows.publish$word_class_relevant_aux)
combined.wordtimes.prewindows.publish$word_class_relevant_no_aux = as.factor(combined.wordtimes.prewindows.publish$word_class_relevant_no_aux)


## Create centered and scaled version of word length (z-scores)
## (Note: We included additional (mostly short) samples of memorized speech such as songs, rituals, or poems during the calculation
## of the normalized word lengths in order to be able to compare spontaneous speech to memorized speech in further studies.
## However, these additional samples of memorized speech were excluded from the study reported in this paper.)

# Baure
baure.word_length_characters.mean = mean(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="brg"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="brg"]))
baure.word_length_characters.mean
# [1] 5.739555

baure.word_length_characters.sd = sd(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="brg"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="brg"]))
baure.word_length_characters.sd
# [1] 3.216632

combined.wordtimes.prewindows.publish$word_length_characters_normalized[combined.wordtimes.prewindows.publish$language_iso_code=="brg"] = (combined.wordtimes.prewindows.publish$word_length_characters[combined.wordtimes.prewindows.publish$language_iso_code=="brg"] - baure.word_length_characters.mean) / baure.word_length_characters.sd

# Bora
bora.word_length_characters.mean = mean(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="boa"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="boa"]))
bora.word_length_characters.mean
# [1] 7.132307

bora.word_length_characters.sd = sd(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="boa"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="boa"]))
bora.word_length_characters.sd
# [1] 3.48124

combined.wordtimes.prewindows.publish$word_length_characters_normalized[combined.wordtimes.prewindows.publish$language_iso_code=="boa"] = (combined.wordtimes.prewindows.publish$word_length_characters[combined.wordtimes.prewindows.publish$language_iso_code=="boa"] - bora.word_length_characters.mean) / bora.word_length_characters.sd

# Chintang
chintang.word_length_characters.mean = mean(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="ctn"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="ctn"]))
chintang.word_length_characters.mean
# [1] 5.17419

chintang.word_length_characters.sd = sd(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="ctn"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="ctn"]))
chintang.word_length_characters.sd
# [1] 2.647925

combined.wordtimes.prewindows.publish$word_length_characters_normalized[combined.wordtimes.prewindows.publish$language_iso_code=="ctn"] = (combined.wordtimes.prewindows.publish$word_length_characters[combined.wordtimes.prewindows.publish$language_iso_code=="ctn"] - chintang.word_length_characters.mean) / chintang.word_length_characters.sd

# Dutch
dutch.word_length_characters.mean = mean(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="nld"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="nld"]))
dutch.word_length_characters.mean
# [1] 3.839343

dutch.word_length_characters.sd = sd(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="nld"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="nld"]))
dutch.word_length_characters.sd
# [1] 2.316754

combined.wordtimes.prewindows.publish$word_length_characters_normalized[combined.wordtimes.prewindows.publish$language_iso_code=="nld"] = (combined.wordtimes.prewindows.publish$word_length_characters[combined.wordtimes.prewindows.publish$language_iso_code=="nld"] - dutch.word_length_characters.mean) / dutch.word_length_characters.sd

# English
english.word_length_characters.mean = mean(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="eng"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="eng"]))
english.word_length_characters.mean
# [1] 3.697355

english.word_length_characters.sd = sd(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="eng"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="eng"]))
english.word_length_characters.sd
# [1] 2.034894

combined.wordtimes.prewindows.publish$word_length_characters_normalized[combined.wordtimes.prewindows.publish$language_iso_code=="eng"] = (combined.wordtimes.prewindows.publish$word_length_characters[combined.wordtimes.prewindows.publish$language_iso_code=="eng"] - english.word_length_characters.mean) / english.word_length_characters.sd

# Even
even.word_length_characters.mean = mean(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="eve"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="eve"]))
even.word_length_characters.mean
# [1] 5.791184

even.word_length_characters.sd = sd(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="eve"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="eve"]))
even.word_length_characters.sd
# [1] 2.777782

combined.wordtimes.prewindows.publish$word_length_characters_normalized[combined.wordtimes.prewindows.publish$language_iso_code=="eve"] = (combined.wordtimes.prewindows.publish$word_length_characters[combined.wordtimes.prewindows.publish$language_iso_code=="eve"] - even.word_length_characters.mean) / even.word_length_characters.sd

# Hoocąk
hoocak.word_length_characters.mean = mean(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="win"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="win"]))
hoocak.word_length_characters.mean
# [1] 6.637176

hoocak.word_length_characters.sd = sd(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="win"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="win"]))
hoocak.word_length_characters.sd
# [1] 3.204288

combined.wordtimes.prewindows.publish$word_length_characters_normalized[combined.wordtimes.prewindows.publish$language_iso_code=="win"] = (combined.wordtimes.prewindows.publish$word_length_characters[combined.wordtimes.prewindows.publish$language_iso_code=="win"] - hoocak.word_length_characters.mean) / hoocak.word_length_characters.sd

# Nǁng
nuu.word_length_characters.mean = mean(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="ngh"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="ngh"]))
nuu.word_length_characters.mean
# [1] 3.323932

nuu.word_length_characters.sd = sd(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="ngh"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="ngh"]))
nuu.word_length_characters.sd
# [1] 1.896369

combined.wordtimes.prewindows.publish$word_length_characters_normalized[combined.wordtimes.prewindows.publish$language_iso_code=="ngh"] = (combined.wordtimes.prewindows.publish$word_length_characters[combined.wordtimes.prewindows.publish$language_iso_code=="ngh"] - nuu.word_length_characters.mean) / nuu.word_length_characters.sd

# Texistepec Popoluca
popoluca.word_length_characters.mean = mean(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="poq"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="poq"]))
popoluca.word_length_characters.mean
# [1] 5.142958

popoluca.word_length_characters.sd = sd(c(combined.wordtimes.prewindows.publish$word_length_characters[!duplicated(combined.wordtimes.prewindows.publish$word_id) & combined.wordtimes.prewindows.publish$language_iso_code=="poq"],combined.memorized.wordtimes.prewindows$word_length_characters[!duplicated(combined.memorized.wordtimes.prewindows$word_id) & combined.memorized.wordtimes.prewindows$language_iso_code=="poq"]))
popoluca.word_length_characters.sd
# [1] 2.555191

combined.wordtimes.prewindows.publish$word_length_characters_normalized[combined.wordtimes.prewindows.publish$language_iso_code=="poq"] = (combined.wordtimes.prewindows.publish$word_length_characters[combined.wordtimes.prewindows.publish$language_iso_code=="poq"] - popoluca.word_length_characters.mean) / popoluca.word_length_characters.sd


### Clean the data

# Eliminate words that do not have a pre-word window (first word in an annotation unit)
combined.wordtimes.prewindows.publish.clean = subset(combined.wordtimes.prewindows.publish,subset=!is.na(combined.wordtimes.prewindows.publish$pre_word_window_begin))

length(unique(combined.wordtimes.prewindows.publish.clean$word_id))
# [1] 264760

# Eliminate words with a pre-word window of length 0 seconds
combined.wordtimes.prewindows.publish.clean = subset(combined.wordtimes.prewindows.publish.clean,subset=combined.wordtimes.prewindows.publish.clean$pre_word_window_length_seconds > 0)

length(unique(combined.wordtimes.prewindows.publish.clean$word_id))
# [1] 262607

# Throw out words with missing word frequency information (mostly unclear words in the Nǁng corpus)
combined.wordtimes.prewindows.publish.clean = subset(combined.wordtimes.prewindows.publish.clean,subset=!is.na(combined.wordtimes.prewindows.publish.clean$word_frequency))

length(unique(combined.wordtimes.prewindows.publish.clean$word_id))
# [1] 262578

# Throw out pre-word windows before filled pauses and false starts
combined.wordtimes.prewindows.publish.clean = subset(combined.wordtimes.prewindows.publish.clean,subset=combined.wordtimes.prewindows.publish.clean$disfluency=="*")

length(unique(combined.wordtimes.prewindows.publish.clean$word_id))
# [1] 253274


# Only keep relevant roots - excluding auxiliaries (main version of the study)
combined.wordtimes.prewindows.publish.pause_probability.no_aux = subset(combined.wordtimes.prewindows.clean,subset=!is.na(combined.wordtimes.prewindows.clean$word_class_relevant_no_aux) & combined.wordtimes.prewindows.clean$word_class_relevant_no_aux %in% c("N","V"))

length(unique(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_id))
# [1] 119717

# Throw out words with multiple ambiguous roots (noun and verb roots)
combined.wordtimes.prewindows.publish.pause_probability.no_aux = subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=!word_id %in% with(combined.wordtimes.prewindows.publish.pause_probability.no_aux,intersect(word_id[word_class_relevant_no_aux=="N"],word_id[word_class_relevant_no_aux=="V"])))

length(unique(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_id))
# [1] 119420

# Only keep one root per word
combined.wordtimes.prewindows.publish.pause_probability.no_aux = subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=!duplicated(word_id))

length(unique(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_id))
# [1] 119420

# Exclude words containing an auxiliary (AUX) root
combined.wordtimes.prewindows.publish.pause_probability.no_aux = subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=!grepl("AUX",whole_word_ntvr_ps_root))

length(unique(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_id))
# [1] 118949

# Select only non-empty pre-word windows for articulation rate analyses
combined.wordtimes.prewindows.publish.articulation_rate.no_aux = subset(combined.wordtimes.prewindows.publish.pause_probability.no_aux,subset=combined.wordtimes.prewindows.publish.pause_probability.no_aux$pre_word_window_length_characters > 0)

length(unique(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_id))
# [1] 106220

# Exclude pre-word windows with disfluencies for articulation rate analysis
combined.wordtimes.prewindows.publish.articulation_rate.no_aux = subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=combined.wordtimes.prewindows.publish.articulation_rate.no_aux$filled_pauses_in_pre_word_window == 0)

length(unique(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_id))
# [1] 103715

combined.wordtimes.prewindows.publish.articulation_rate.no_aux = subset(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,subset=combined.wordtimes.prewindows.publish.articulation_rate.no_aux$false_starts_in_pre_word_window == 0)

length(unique(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_id))
# [1] 101885


# Only keep relevant roots - including auxiliaries (alternative version of the study)
combined.wordtimes.prewindows.publish.pause_probability.aux = subset(combined.wordtimes.prewindows.clean,subset=!is.na(combined.wordtimes.prewindows.clean$word_class_relevant_aux) & combined.wordtimes.prewindows.clean$word_class_relevant_aux %in% c("N","V"))

length(unique(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id))
# [1] 125045

# Throw out words with multiple ambiguous roots (noun and verb roots)
combined.wordtimes.prewindows.publish.pause_probability.aux = subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=!word_id %in% with(combined.wordtimes.prewindows.publish.pause_probability.aux,intersect(word_id[word_class_relevant_aux=="N"],word_id[word_class_relevant_aux=="V"])))

length(unique(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id))
# [1] 124735

# In cases, with a V and AUX root, only keep V root
combined.wordtimes.prewindows.publish.pause_probability.aux = subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=!word_id %in% with(combined.wordtimes.prewindows.publish.pause_probability.aux,intersect(word_id[word_class_relevant=="V"],word_id[word_class_relevant=="AUX"])) | word_class_relevant!="AUX")

length(unique(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id))
# [1] 124735

# Only keep one root per word
combined.wordtimes.prewindows.publish.pause_probability.aux = subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=!duplicated(word_id))

length(unique(combined.wordtimes.prewindows.publish.pause_probability.aux$word_id))
# [1] 124735

# Select only non-empty pre-word windows for articulation rate analyses
combined.wordtimes.prewindows.publish.articulation_rate.aux = subset(combined.wordtimes.prewindows.publish.pause_probability.aux,subset=combined.wordtimes.prewindows.publish.pause_probability.aux$pre_word_window_length_characters > 0)

length(unique(combined.wordtimes.prewindows.publish.articulation_rate.aux$word_id))
# [1] 111619

# Exclude pre-word windows with disfluencies for articulation rate analysis
combined.wordtimes.prewindows.publish.articulation_rate.aux = subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=combined.wordtimes.prewindows.publish.articulation_rate.aux$filled_pauses_in_pre_word_window == 0)

length(unique(combined.wordtimes.prewindows.publish.articulation_rate.aux$word_id))
# [1] 109058

combined.wordtimes.prewindows.publish.articulation_rate.aux = subset(combined.wordtimes.prewindows.publish.articulation_rate.aux,subset=combined.wordtimes.prewindows.publish.articulation_rate.aux$false_starts_in_pre_word_window == 0)

length(unique(combined.wordtimes.prewindows.publish.articulation_rate.aux$word_id))
# [1] 107188


### Omit unnecessary levels and delete unnecessary columns

combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant = factor(as.character(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant))
combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux = factor(as.character(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_aux))
combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant_no_aux = NULL

combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant = factor(as.character(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant))
combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_aux = NULL
combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux = factor(as.character(combined.wordtimes.prewindows.publish.pause_probability.no_aux$word_class_relevant_no_aux))

combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant = factor(as.character(combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant))
combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux = factor(as.character(combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_aux))
combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant_no_aux = NULL

combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant = factor(as.character(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant))
combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_aux = NULL
combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux = factor(as.character(combined.wordtimes.prewindows.publish.articulation_rate.no_aux$word_class_relevant_no_aux))


### Change order of part-of-speech levels ###

combined.wordtimes.prewindows.publish$word_class_relevant = factor(combined.wordtimes.prewindows.publish$word_class_relevant,levels=c("N","V","AUX","PRO","OTHER","FLDPS","BPN","BPP"))
combined.wordtimes.prewindows.publish$word_class_relevant_aux = factor(combined.wordtimes.prewindows.publish$word_class_relevant_aux,levels=c("N","V","PRO","OTHER","FLDPS","BPN","BPP"))
combined.wordtimes.prewindows.publish$word_class_relevant_no_aux = factor(combined.wordtimes.prewindows.publish$word_class_relevant_no_aux,levels=c("N","V","PRO","OTHER","FLDPS","BPN","BPP"))
 
combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant = factor(combined.wordtimes.prewindows.publish.articulation_rate.aux$word_class_relevant,levels=c("N","V","AUX"))
combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant = factor(combined.wordtimes.prewindows.publish.pause_probability.aux$word_class_relevant,levels=c("N","V","AUX"))


### Create a distributable version of data - partly anonymized ###

# Assume that most data is kept
combined.wordtimes.prewindows.publish$excluded_why = NA
combined.wordtimes.prewindows.publish$excluded = "no"

# Only keep N, V and AUX
combined.wordtimes.prewindows.publish$excluded_why[(!combined.wordtimes.prewindows.publish$word_class_relevant %in% c("N","V","AUX")) & combined.wordtimes.prewindows.publish$excluded=="no"] = "irrelevant word class"
combined.wordtimes.prewindows.publish$excluded[(!combined.wordtimes.prewindows.publish$word_class_relevant %in% c("N","V","AUX")) & combined.wordtimes.prewindows.publish$excluded=="no"] = "both"

# Exclude pre-word windows that include multiple different roots at the same time
ambiguous.words = with(subset(combined.wordtimes.prewindows.publish,subset=word_class_relevant %in% c("N","V","AUX")),intersect(word_id[word_class_relevant_aux=="N"],word_id[word_class_relevant_aux=="V"]))

combined.wordtimes.prewindows.publish$excluded_why[combined.wordtimes.prewindows.publish$word_id %in% ambiguous.words & combined.wordtimes.prewindows.publish$excluded=="no"] = "ambiguous word class"
combined.wordtimes.prewindows.publish$excluded[combined.wordtimes.prewindows.publish$word_id %in% ambiguous.words & combined.wordtimes.prewindows.publish$excluded=="no"] = "both"

# Excluding words without a pre-word window (first words in annotation units)
combined.wordtimes.prewindows.publish$excluded_why[is.na(combined.wordtimes.prewindows.publish$pre_word_window_begin) & combined.wordtimes.prewindows.publish$excluded=="no"] = "first word in utterance"
combined.wordtimes.prewindows.publish$excluded[is.na(combined.wordtimes.prewindows.publish$pre_word_window_begin) & combined.wordtimes.prewindows.publish$excluded=="no"] = "both"

# Eliminate words with missing word frequency information
# Only happens in Nǁng. Only occurs with (acoustically) doubtful words or false starts (count as disfluencies for paper!)
combined.wordtimes.prewindows.publish$excluded_why[is.na(combined.wordtimes.prewindows.publish$word_frequency) & combined.wordtimes.prewindows.publish$excluded=="no"] = "target word disfluent"
combined.wordtimes.prewindows.publish$excluded[is.na(combined.wordtimes.prewindows.publish$word_frequency) & combined.wordtimes.prewindows.publish$excluded=="no"] = "both"

# Throw out pre-word windows before filled pauses and false starts
combined.wordtimes.prewindows.publish$excluded_why[combined.wordtimes.prewindows.publish$disfluency!="*" & combined.wordtimes.prewindows.publish$excluded=="no"] = "target word disfluent"
combined.wordtimes.prewindows.publish$excluded[combined.wordtimes.prewindows.publish$disfluency!="*" & combined.wordtimes.prewindows.publish$excluded=="no"] = "both"

# Eliminate words with a pre-word window of length 0 seconds
combined.wordtimes.prewindows.publish$excluded_why[combined.wordtimes.prewindows.publish$pre_word_window_length_seconds <= 0 & combined.wordtimes.prewindows.publish$excluded=="no"] = "context window of length zero"
combined.wordtimes.prewindows.publish$excluded[combined.wordtimes.prewindows.publish$pre_word_window_length_seconds <= 0 & combined.wordtimes.prewindows.publish$excluded=="no"] = "both"

# Throw out empty pre-word windows
combined.wordtimes.prewindows.publish$excluded_why[combined.wordtimes.prewindows.publish$pre_word_window_length_characters <= 0 & combined.wordtimes.prewindows.publish$excluded=="no"] = "empty context window"
combined.wordtimes.prewindows.publish$excluded[combined.wordtimes.prewindows.publish$pre_word_window_length_characters <= 0 & combined.wordtimes.prewindows.publish$excluded=="no"] = "articulation rate"

# Throw out pre-word windows containing disfluencies
combined.wordtimes.prewindows.publish$excluded_why[combined.wordtimes.prewindows.publish$filled_pauses_in_pre_word_window > 0 & combined.wordtimes.prewindows.publish$excluded=="no"] = "disfluency in context window"
combined.wordtimes.prewindows.publish$excluded[combined.wordtimes.prewindows.publish$filled_pauses_in_pre_word_window > 0 & combined.wordtimes.prewindows.publish$excluded=="no"] = "articulation rate"

combined.wordtimes.prewindows.publish$excluded_why[combined.wordtimes.prewindows.publish$false_starts_in_pre_word_window > 0 & combined.wordtimes.prewindows.publish$excluded=="no"] = "disfluency in context window"
combined.wordtimes.prewindows.publish$excluded[combined.wordtimes.prewindows.publish$false_starts_in_pre_word_window > 0 & combined.wordtimes.prewindows.publish$excluded=="no"] = "articulation rate"

# Add information about auxiliaries
# Necessary for English
combined.wordtimes.prewindows.publish$excluded_aux = "no"
combined.wordtimes.prewindows.publish$excluded_aux[grepl("AUX",combined.wordtimes.prewindows.publish$whole_word_word_class_all)] = "yes"
combined.wordtimes.prewindows.publish$excluded_aux[combined.wordtimes.prewindows.publish$word_class_relevant=="AUX"] = "yes"

# Make factors of new metadata columns
combined.wordtimes.prewindows.publish$excluded_why = factor(combined.wordtimes.prewindows.publish$excluded_why,levels=c("irrelevant word class","ambiguous word class","first word in utterance","target word disfluent","context window of length zero","empty context window","disfluency in context window"))
combined.wordtimes.prewindows.publish$excluded = factor(combined.wordtimes.prewindows.publish$excluded,levels=c("no","articulation rate","both"))
combined.wordtimes.prewindows.publish$excluded_aux = factor(combined.wordtimes.prewindows.publish$excluded_aux,levels=c("no","yes"))

# Anonymize sensitive columns speaker and word_type
combined.wordtimes.prewindows.publish$speaker = factor(paste(combined.wordtimes.prewindows.publish$language_iso_code,as.character(as.numeric(combined.wordtimes.prewindows.publish$speaker))))
combined.wordtimes.prewindows.publish$word_type = factor(paste(combined.wordtimes.prewindows.publish$language_iso_code,as.character(as.numeric(factor(combined.wordtimes.prewindows.publish$word_type)))))


## Create minimal data sets for the four different studies: articulation rate (exluding and including auxiliaries) and pause probability
## (excluding and including auxiliaries)

# Omit cases that are excluded in all versions of the study
combined.wordtimes.prewindows.publish.minimal = droplevels(subset(combined.wordtimes.prewindows.publish,subset=excluded!="both"))

# Omit words duplicated because of multiple roots
combined.wordtimes.prewindows.publish.minimal = droplevels(subset(combined.wordtimes.prewindows.publish.minimal,subset=!duplicated(word_id)))

# Correct words containing both V and AUX roots to make sure their ntvr_ps_root.simplified value is "V" and not "AUX"
combined.wordtimes.prewindows.publish.minimal$word_class_relevant[grepl("V",combined.wordtimes.prewindows.publish.minimal$whole_word_word_class_all) & grepl("AUX",combined.wordtimes.prewindows.publish.minimal$whole_word_word_class_all) & combined.wordtimes.prewindows.publish.minimal$word_class_relevant=="AUX"] = "V"

# Create data sets for the four variant studies
combined.wordtimes.prewindows.publish.articulation_rate.no_aux = droplevels(subset(combined.wordtimes.prewindows.publish.minimal,subset=excluded=="no" & excluded_aux=="no"))
combined.wordtimes.prewindows.publish.articulation_rate.aux = droplevels(subset(combined.wordtimes.prewindows.publish.minimal,subset=excluded=="no"))
combined.wordtimes.prewindows.publish.pause_probability.no_aux = droplevels(subset(combined.wordtimes.prewindows.publish.minimal,subset=excluded %in% c("no","articulation rate") & excluded_aux=="no"))
combined.wordtimes.prewindows.publish.pause_probability.aux = droplevels(subset(combined.wordtimes.prewindows.publish.minimal,subset=excluded %in% c("no","articulation rate")))

# Delete superfluous columns
combined.wordtimes.prewindows.publish.articulation_rate.no_aux$excluded <- NULL
combined.wordtimes.prewindows.publish.articulation_rate.no_aux$excluded_why <- NULL
combined.wordtimes.prewindows.publish.articulation_rate.no_aux$excluded_aux <- NULL

combined.wordtimes.prewindows.publish.articulation_rate.aux$excluded <- NULL
combined.wordtimes.prewindows.publish.articulation_rate.aux$excluded_why <- NULL
combined.wordtimes.prewindows.publish.articulation_rate.aux$excluded_aux <- NULL

combined.wordtimes.prewindows.publish.pause_probability.no_aux$excluded <- NULL
combined.wordtimes.prewindows.publish.pause_probability.no_aux$excluded_why <- NULL
combined.wordtimes.prewindows.publish.pause_probability.no_aux$excluded_aux <- NULL

combined.wordtimes.prewindows.publish.pause_probability.aux$excluded <- NULL
combined.wordtimes.prewindows.publish.pause_probability.aux$excluded_why <- NULL
combined.wordtimes.prewindows.publish.pause_probability.aux$excluded_aux <- NULL


## Save data sets

# Save data sets as R object and as tab separated value file, under Linux

# Complete data set
save(combined.wordtimes.prewindows.publish,file="pre_word_windows.data.RData")
write.table(combined.wordtimes.prewindows.publish,file="pre_word_windows.data.tsv",quote=F,sep="\t",row.names=F,fileEncoding="utf-8")

# Additional data sets for the four individual studies
save(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,file="pre_word_windows.articulation_rate.no_aux.data.RData")
write.table(combined.wordtimes.prewindows.publish.articulation_rate.no_aux,file="pre_word_windows.articulation_rate.no_aux.data.tsv",quote=F,sep="\t",row.names=F,fileEncoding="utf-8")

save(combined.wordtimes.prewindows.publish.articulation_rate.aux,file="pre_word_windows.articulation_rate.aux.data.RData")
write.table(combined.wordtimes.prewindows.publish.articulation_rate.aux,file="pre_word_windows.articulation_rate.aux.data.tsv",quote=F,sep="\t",row.names=F,fileEncoding="utf-8")

save(combined.wordtimes.prewindows.publish.pause_probability.no_aux,file="pre_word_windows.pause_probability.no_aux.data.RData")
write.table(combined.wordtimes.prewindows.publish.pause_probability.no_aux,file="pre_word_windows.pause_probability.no_aux.data.tsv",quote=F,sep="\t",row.names=F,fileEncoding="utf-8")

save(combined.wordtimes.prewindows.publish.pause_probability.aux,file="pre_word_windows.pause_probability.aux.data.RData")
write.table(combined.wordtimes.prewindows.publish.pause_probability.aux,file="pre_word_windows.pause_probability.aux.data.tsv",quote=F,sep="\t",row.names=F,fileEncoding="utf-8")
